#!/usr/bin/env python
# -*- coding: ISO-8859-15 -*-
#
# pdf2swf.py
# graphical user interface for pdf2swf
#
# Part of the swftools package.
# 
# Copyright (c) 2008,2009 Matthias Kramm <kramm@quiss.org> 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */


import sys
import wx
import os
sys.path+=["../lib/python"]
import gfx
import images
import stat

basedir = os.getcwd()

gfx.verbose(3)

#try:
#    gfx.setparameter("wxwindowparams", "1")
#except:
#    gfx.setoption("wxwindowparams", "1")

class StaticData:
    def __init__(self):
        self.simpleviewer_bitmap = wx.BitmapFromImage(wx.ImageFromData(images.simpleviewer_width,images.simpleviewer_height,images.simpleviewer_data))
        self.raw_bitmap = wx.BitmapFromImage(wx.ImageFromData(images.raw_width,images.raw_height,images.raw_data))
        self.motionpaper_bitmap = wx.BitmapFromImage(wx.ImageFromData(images.motionpaper_width,images.motionpaper_height,images.motionpaper_data))
        self.rfxview_bitmap = wx.BitmapFromImage(wx.ImageFromData(images.rfxview_width,images.rfxview_height,images.rfxview_data))
staticdata = None

HTMLTEMPLATE = """<html>
<body style="padding: 0px; margin: 0px">
<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
        width="%(width)s"
        height="%(height)s"
        codebase="http://active.macromedia.com/flash5/cabs/swflash.cab#version=%(version)d,0,0,0">
        <param name="MOVIE" value="%(swffilename)s">
        <param name="PLAY" value="true">
        <param name="LOOP" value="true">
        <param name="QUALITY" value="high">
        <param name="FLASHVARS" value="%(flashvars)s">
          <embed src="%(swffilename)s" width="%(width)s" height="%(height)s"
                 play="true" ALIGN="" loop="true" quality="high"
                 type="application/x-shockwave-flash"
                 flashvars="%(flashvars)s"
                 pluginspage="http://www.macromedia.com/go/getflashplayer">
          </embed>
</object>
</body>
</html>
"""

def error(msg):
    dlg = wx.MessageDialog(None, msg, "Error", style=wx.OK, pos=wx.DefaultPosition)
    dlg.ShowModal()
    dlg.Destroy()

def savefilestatus(msg):
    dlg = wx.MessageDialog(None, msg, "Save file status", style=wx.OK, pos=wx.DefaultPosition)
    dlg.ShowModal()
    dlg.Destroy()

def swfcombine(params):
    exe = "swfcombine"
    if os.path.sep == '/':
        locations = [os.path.join(basedir, "swfcombine"), 
                     "/usr/local/bin/swfcombine",
                     "/usr/bin/swfcombine"
                    ]
    else:
        locations = [os.path.join(basedir, "swfcombine.exe"), 
                     "c:\\swftools\\swfcombine.exe"]
        params = ['"'+p+'"' for p in params]

    for e in locations:
        if os.path.isfile(e):
            exe = e
            break

    if hasattr(os,"spawnv"):
        print "spawnv",exe,params
        ret = -1
        try:
            ret = os.spawnv(os.P_WAIT, exe, ["swfcombine"]+params)
        except:
            ret = -1
        if not ret:
            return

    cmd = '"' + exe + '"' + " " + (" ".join(params))
    print "system",cmd
    ret = os.system(cmd)
    if ret&0xff00:
        error("Couldn't execute swfcombine.exe- error code "+str(ret))

ICON_SIZE = 64

EVENT_PAGE_CHANGE = 1
EVENT_FILE_CHANGE = 2
EVENT_STATUS_TEXT = 4

class ProgressFrame(wx.Dialog):
    def __init__(self, parent, message=""):
        wx.Dialog.__init__(self, parent, -1, "Progress", size=(350, 150))
        panel = wx.Panel(self, -1)
        self.count = 0
        
        self.msg = wx.StaticText(panel, -1, message, (20,25))
        self.gauge = wx.Gauge(panel, -1, 100, (20, 50), (250, 25))

        self.gauge.SetBezelFace(3)
        self.gauge.SetShadowWidth(3)

        self.Bind(wx.EVT_WINDOW_DESTROY, self.close, id=wx.ID_CLOSE)

    def setProgress(self, num):
        self.gauge.SetValue(int(num))

    def close(self, event):
        print "close"


def swapextension(filename,newext):
    basename,ext = os.path.splitext(filename)
    return basename + "." + newext

def has_different_size_pages(doc):
    width,height = 0,0
    for i in range(1,doc.pages+1):
        page = doc.getPage(i)
        if i==1:
            width,height = page.width,page.height
        else:
            if abs(width-page.width)>2 or \
               abs(height-page.height)>2:
                   return 1
    return 0


options = []
gfx_options = {}

class Option:
    def __init__(self, parameter, text, options, default, mapping=None):
        self.parameter = parameter
        self.text = text
        self.options = options
        self.default = default
        self.mapping = mapping
        self.control = None
        self.enabled = 1
        self.register()

    def generateControl(self, panel):
        if type(self.options) == type((0,)):
            control = wx.Choice(panel, -1, choices=self.options)
            control.SetSelection(self.default)
        elif self.options == "slider":
            control = wx.Slider(panel, -1, self.default, 0, 100, size=(100, -1), style=wx.SL_HORIZONTAL|wx.SL_LABELS|wx.SL_TOP)
        elif self.options == "spinner":
            control = wx.SpinCtrl(panel, -1, str(self.default))
        else:
            control = wx.Choice(panel, -1, choices=["broken"])
            control.SetSelection(0)

        self.control = control
        return self.control

    def getSettings(self):
        value = ""
        if type(self.options) == type((0,)):
            value = self.options[self.control.GetCurrentSelection()]
            if self.mapping and value in self.mapping:
                value = str(self.mapping[value])
            if value == "yes": 
                value = "1"
            elif value == "no":
                value = "0"
            return {self.parameter:value}
        elif self.options == "slider" or self.options == "spinner":
            value = str(self.control.GetValue())
            return {self.parameter:value}

    def register(self):
        global options
        options += [self]

class Option2(Option):

    def __init__(self, parameter, text, options, default, mapping=None):
        Option.__init__(self, parameter, text, options, default, mapping)
        self.enabled = 0

    def generateControl(self, panel):
        p = wx.Panel(panel, -1)
        #p.SetOwnBackgroundColour('#ff0000')
        h = wx.BoxSizer(wx.HORIZONTAL)
        control = wx.Choice(p, -1, choices=self.options)
        control.SetSelection(self.default)
        text = wx.StaticText(p, -1, self.text)
        h.Add(text,1,wx.EXPAND|wx.ALIGN_LEFT|wx.TOP, 5)
        h.Add(control,1,wx.EXPAND|wx.ALIGN_RIGHT|wx.ALIGN_TOP)
        self.control = control
        if self.enabled:
            control.Enable()
        else:
            control.Disable()
        p.SetSizer(h)
        p.Fit()
        return p 
    
    def Disable(self):
        self.enabled=0
        if self.control:
            self.control.Disable()

    def Enable(self):
        self.enabled=1
        if self.control:
            self.control.Enable()
    
    def getSettings(self):
        if not self.enabled:
            return {}
        return Option.getSettings(self)

class ChooseAndText(Option):
    def __init__(self, parameter, text, options, default, editselection, textvalue=""):
        Option.__init__(self, parameter, text, options, default)
        self.editselection = editselection
        self.selection = default
        self.textvalue = textvalue
        self.enabled = 0
        self.choice = None

    def generateControl(self, panel):
        p = wx.Panel(panel, -1)
        h = wx.BoxSizer(wx.HORIZONTAL)
        control = wx.Choice(p, -1, choices=self.options)
        p.Bind(wx.EVT_CHOICE, self.OnChoice, control)
        control.SetSelection(self.default)
        text = wx.StaticText(p, -1, self.text)
        if self.selection == self.editselection:
            edittext = wx.TextCtrl(p, -1, self.textvalue)
            self.textvalue = ""
        else:
            edittext = wx.TextCtrl(p, -1, "")
            edittext.Disable()
        p.Bind(wx.EVT_TEXT, self.OnText, edittext)
        h.Add(text,1,wx.EXPAND|wx.ALIGN_LEFT|wx.TOP, 5)
        h.Add(control,1,wx.EXPAND|wx.ALIGN_RIGHT)
        h.Add(edittext,1,wx.EXPAND|wx.ALIGN_RIGHT)
        self.choice = control
        self.edittext = edittext
        if self.enabled:
            control.Enable()
        else:
            control.Disable()
        p.SetSizer(h)
        p.Fit()
        return p 

    def OnText(self, event):
        text = self.edittext.GetValue()
        text2 = "".join(c for c in text if c.isdigit())
        if text2!=text:
            self.edittext.SetValue(text2)

    def OnChoice(self, event):
        self.selection = self.choice.GetCurrentSelection()
        if self.selection != self.editselection:
            if not self.textvalue and self.edittext.GetValue():
                self.textvalue = self.edittext.GetValue()
            self.edittext.SetValue("")
            self.edittext.Disable()
        else:
            if self.textvalue and not self.edittext.GetValue():
                self.edittext.SetValue(self.textvalue)
                self.textvalue = ""
            self.edittext.Enable()
    
    def Disable(self):
        self.enabled=0
        if not self.choice:
            return
        self.choice.Disable()
        self.edittext.Disable()

    def Enable(self):
        self.enabled=1
        if not self.choice:
            return
        self.choice.Enable()
        if self.choice.GetCurrentSelection() == self.editselection:
            if self.textvalue and not self.edittext.GetValue():
                self.edittext.SetValue(self.textvalue)
                self.textvalue = ""
            self.edittext.Enable()
        else:
            self.edittext.Disable()
    
    def getSettings(self):
        if not self.enabled:
            return {}
        if self.choice.GetCurrentSelection() != self.editselection:
            value = self.options[self.choice.GetCurrentSelection()]
        else:
            value = self.edittext.GetValue().strip()
        return {self.parameter:value}

class TextOption:
    def __init__(self, parameter, label, default=""):
        self.parameter = parameter
        self.label = label
        self.default = default
        self.register()

    def generateControl(self, panel):
        v = wx.BoxSizer(wx.VERTICAL)
        self.control = wx.TextCtrl(panel, -1, self.default, size=(250, -1))
        self.control.Fit()
        return self.control

    def getSettings(self):
        settings = {}
        for items in self.control.GetValue().split(" "):
            if "=" in items:
                l = items.split("=")
                if len(l) == 2:
                    settings[l[0]] = l[1]
        return settings

    def register(self):
        global options
        options += [self]

class RadioOption(Option):
    def __init__(self, text, options):
        self.text = text
        self.options = options
        self.selected = "==nothing=="
        self.radios = []
        self.register()
        
    def generateControl(self, panel):
        control = wx.Panel(panel, -1)
        vsplit = wx.BoxSizer(wx.VERTICAL)
        for i in range(len(self.options)/2):
            text = self.options[i*2]
            if i == 0:
                c = wx.RadioButton(control, -1, text, style=wx.RB_GROUP)
            else:
                c = wx.RadioButton(control, -1, text)
            control.Bind(wx.EVT_RADIOBUTTON, self.OnRadio, c)
            self.radios += [c]
            vsplit.Add(c)
        control.SetSizer(vsplit)
        control.Fit()
        self.control = control
        return control

    def OnRadio(self, event):
        self.selected = event.GetEventObject().GetLabel()

    def getSettings(self):
        for i in range(len(self.options)/2):
            if self.options[i*2] == self.selected:
                return self.options[i*2+1]
        return self.options[1]

class BitmapWindow(wx.Window):
    def __init__(self, parent, image):
        wx.Window.__init__(self, parent, -1)
        self.image = image
        self.SetMinSize((image.GetWidth()+2, image.GetHeight()+2))
        self.SetMaxSize((image.GetWidth()+2, image.GetHeight()+2))
        self.SetSize((image.GetWidth()+2, image.GetHeight()+2))
        self.Bind(wx.EVT_PAINT, self.OnPaint)
        self.Update()
    def OnPaint(self, event):
        dc = wx.PaintDC(self)
        self.Draw(dc)
    def Draw(self,dc=None):
        if not dc:
            dc = wx.ClientDC(self)
        dc.DrawRectangleRect((0, 0, self.image.GetWidth()+2, self.image.GetHeight()+2))
        dc.DrawBitmap(self.image, 1, 1, False)

class ImageRadioOption(Option):
    def __init__(self, text, options):
        self.text = text
        self.options = options
        self.selected = "==nothing=="
        self.radios = []
        self.register()
        self.ids = []
        
    def generateControl(self, panel):
        control = wx.Panel(panel, -1)
        vsplit = wx.BoxSizer(wx.VERTICAL)
        first = 1
        for image,text,params,selected,extraoptions in self.options:
            hsplit = wx.BoxSizer(wx.HORIZONTAL)

            v = wx.BoxSizer(wx.VERTICAL)

            name,text = text.split("- ")

            c = wx.CheckBox(control, -1, name)
            control.Bind(wx.EVT_CHECKBOX, self.OnRadio, c)

            # radio buttons crash windows when clicked on- even without event bindings.
            # This is caused by the subpanel which is created for extra options
            # (I tried this with a empty Panel(), and even that crashed)
            #if first:
            #    c = wx.RadioButton(control, -1, name, style=wx.RB_GROUP)
            #else:
            #    c = wx.RadioButton(control, -1, name)
            #control.Bind(wx.EVT_RADIOBUTTON, self.OnRadio, c)

            self.ids += [c.GetId()]

            first = 0

            if "disable" in text:
                c.Enable(False)
            if selected:
                self.selected = c.GetId()
                c.SetValue(True)
            else:
                c.SetValue(False)
            self.radios += [c]

            bitmap = BitmapWindow(control, image)
            t = wx.StaticText(control, -1, text, size=(400,50))
            
            v.Add(c, 0, wx.EXPAND)
            v.Add(t, 0, wx.EXPAND|wx.LEFT, 20)
           
            for o in extraoptions:
                cx = o.generateControl(control)
                if selected:
                    o.Enable()
                else:
                    o.Disable()
                v.Add(cx, 0, wx.EXPAND|wx.LEFT, 20)
            
            v.SetMinSize((330,170))
            
            hsplit.Add(bitmap, 0, wx.LEFT|wx.RIGHT|wx.BOTTOM|wx.ALIGN_TOP, 5)
            hsplit.Add(v, 0, wx.EXPAND)
            vsplit.Add(hsplit, 0, wx.EXPAND)

        control.SetSizer(vsplit)
        control.Fit()
        self.control = control
        return vsplit

    def OnRadio(self, event):
        self.selected = event.GetEventObject().GetId()
        for c in self.radios:
            if c.GetId() == self.selected:
                c.SetValue(1)
            else:
                c.SetValue(0)
        i = 0
        for image,text,params,selected,extraoptions in self.options:
            if self.ids[i] == self.selected:
                for xo in extraoptions:
                    xo.Enable()
                pass
            else:
                for xo in extraoptions:
                    xo.Disable()
                pass
            i = i + 1
        event.ResumePropagation(0)

    def getSettings(self):
        i = 0
        for image,text,params,s,extraoptions in self.options:
            id = self.ids[i]
            i = i + 1
            if id == self.selected:
                return params
        return {}


class OptionFrame(wx.Dialog):

    def __init__(self, parent):
        wx.Dialog.__init__(self, parent, -1, "Options")

        #self.nb = wx.Notebook(self, -1)#, wx.Point(0,0), wx.Size(0,0), wxNB_FIXEDWIDTH)
        self.nb = wx.Notebook(self, -1)

        self.needreload = 0
        
        options0 = [RadioOption('Rendering mode', 
                        ["Convert polygons to polygons and fonts to fonts", {},
                         "Convert fonts to fonts, everything else to bitmaps", {"poly2bitmap":"1"},
                         "Convert everthing to bitmaps", {"poly2bitmap":"1", "bitmapfonts":"1"}
                        ])]

        mp_options = []
        sv_options = [Option2('flashversion', 'Flash version:', ('4','5','6','7','8'), 2),
                      Option2('transparent', 'Make SWF file transparent:', ('no','yes'), 0),
                     ]

        raw_options = [Option2('flashversion', 'Flash version:', ('4','5','6','7','8','9'), 2),
                       Option2('insertstop', 'Insert stop after each frame:', ('no','yes'), 0),
                       Option2('transparent', 'Make SWF file transparent:', ('no','yes'), 0),
                      ]
        rfxview_options = [ChooseAndText('rfxwidth', 'Width:', ('same as PDF','fullscreen','custom'),1,2,"600"),
                           ChooseAndText('rfxheight', 'Height:', ('same as PDF','fullscreen','custom'),1,2,"800"),
                           Option2('rfxzoomtype', 'Initial zoom level:', ('Original resolution','Show all','Maximum width/height'),2),
                          ]

        options4 = [ImageRadioOption('Select Paging GUI', 
                        [(staticdata.raw_bitmap, "No Viewer- The SWF will be in \"raw\" format, with each page a seperate frame. Use this if you want to add a viewer yourself afterwards.", {}, 0, raw_options),
                         (staticdata.simpleviewer_bitmap, "SimpleViewer- A tiny viewer, which attaches directly to the SWF, and provides small previous/next buttons in the upper left corner", {"simpleviewer":"1", "insertstop":"1"}, 0, sv_options),
                         (staticdata.rfxview_bitmap, "rfxView- A more sophisticated viewer with zooming and scrolling.", {"rfxview":"1", "flashversion":"8"}, 1, rfxview_options),
                         #(staticdata.motionpaper_bitmap, "MotionPaper- A highly sophisticated viewer with page flipping. (disabled in this evaluation version)", {}, 0, mp_options),
                         #(staticdata.motionpaper_bitmap, "Your advertisement here- Are you are company who developed a viewer for pdf2swf, or who offers commercial PDF hosting service? Place your advertisement or demo viewer here, or allow pdf2swf to upload SWFs directly to your site! contact sales@swftools.org for details.", {}, 0, mp_options),
                        ])]

        options1 = [Option('zoom', 'Resolution (in dpi):', "spinner", 72),
                    Option('fontquality', 'Font quality:', "slider", 20),
                    Option('storeallcharacters', 'Insert full fonts in SWF file:', ('no','yes'), 0),
                    Option('splinequality', 'Polygon quality:', "slider", 100),
                    Option('jpegquality', 'JPEG quality:', "slider", 75),
                    Option('jpegsubpixels', 'JPEG image resolution:', ('same as in PDF', '1x', '2x', '4x'), 0, {"same as in PDF": 0, "1x": 1, "2x": 2, "3x": 3}),
                    Option('ppmsubpixels', 'non-JPEG image resolution:', ('same as in PDF', '1x', '2x', '4x'), 0, {"same as in PDF": 0, "1x": 1, "2x": 2, "3x": 3}),
                   ]
        
        
        options3 = [TextOption('_additional_', 'Additional options')]

        panel1 = [('Rendering options', options0,''),
                  ('Quality',options1,'v')]
        panel3 = [('Select paging GUI', options4,'')]
        panel4 = [('Additional options', options3,'')]

        panels = [('Quality', panel1),
                  ('Viewer', panel3),
                  ('Advanced', panel4)]

        for name,poptions in panels:
            panel = wx.Panel(self.nb, -1)
            self.nb.AddPage(panel, name)
        
            vsplit = wx.BoxSizer(wx.VERTICAL)
      
            for name,options,align in poptions:
                optiongroup = wx.StaticBox(panel, -1, name)
                optiongroupsizer= wx.StaticBoxSizer(optiongroup, wx.VERTICAL)
                optiongroup.SetSizer(optiongroupsizer)

                if align == 'v':
                    grid = wx.GridSizer(rows=len(options), cols=2, hgap=3, vgap=3)
                    optiongroupsizer.Add(grid, 1, wx.EXPAND, 0)
                else:
                    grid = wx.GridSizer(rows=len(options), cols=1, hgap=3, vgap=3)
                    optiongroupsizer.Add(grid, 1, wx.EXPAND, 0)

                for option in options:
                    if align=='v':
                        t = wx.StaticText(panel, -1, option.text)
                        grid.Add(t, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT)
                    optionbox = option.generateControl(panel)
                    grid.Add(optionbox, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_LEFT)

                vsplit.Add(optiongroupsizer, 0, wx.EXPAND, 0)

            #hs = wx.BoxSizer(wx.HORIZONTAL)
            #hs.Add(gobutton, 0, wx.ALIGN_CENTER, 0)
            gobutton = wx.Button(panel, -1, "Apply")
            self.Bind(wx.EVT_BUTTON, self.Apply, gobutton)

            vsplit.Add(gobutton, 0, wx.ALIGN_CENTER|wx.ALL, 0)
            
            panel.SetSizer(vsplit)
            panel.Fit()

        self.nb.Fit()

        self.Fit()
        

    def updateOptions(self):
        global options,gfx_options
        a = []

        # FIXME: we clear *our* options- but gfx will still have
        #        stored the old ones. Critical for options in the "imageradio" section.
        gfx_options.clear()
        i = 0
        print "----- options ------"
        for option in options:
            for k,v in option.getSettings().items():
                gfx_options[k] = v
                gfx.setparameter(k,v)
                print k,v
            i = i + 1

        # TODO: filter out "global" options, and do this only if
        # pdf layer is affected
    
    def Apply(self, event):
        self.updateOptions()
        self.Hide()
        self.needreload = 1


class State:
    def __init__(self):
        self.pdf = None
        self.page = None
        self.pagenr = 1
        self.pagebitmap = None
        self.bitmap_width = 0
        self.bitmap_height = 0
        self.bitmap_page = 0
        self.filename = None
        self.status_text = None
        self.lastsavefile = "output.swf"
        self.lasthtmlfile = "index.html"

        self.listeners = []

    def onEvent(self,event_type, function):
        self.listeners += [(event_type,function)]
    def loadPDF(self,filename):
        self.filename = filename
        self.lastsavefile = swapextension(filename,"swf")
        self.lasthtmlfile = swapextension(filename,"html")

        self.pdf = gfx.open("pdf",filename)
        if(has_different_size_pages(self.pdf)):
            # just let the user know- for now, we can't handle this properly
            dlg = wx.MessageDialog(app.frame, """In this PDF, width or height are not the same for each page. This might cause problems if you export pages of different dimensions into the same SWF file.""", "Notice", style=wx.OK, pos=wx.DefaultPosition)
            dlg.ShowModal()
            dlg.Destroy()

        self.changePage(1)

        for type,f in self.listeners:
            if type&EVENT_PAGE_CHANGE or type&EVENT_FILE_CHANGE:
                f()
        self.setStatus("File loaded successfully.")

    def saveSWF(self, filename, progress, pages=None, html=0):
        if html:
            basename,ext = os.path.splitext(filename)
            if not ext:
                html = basename + ".html"
                filename = basename + ".swf"
            elif ext.lower() != ".swf":
                html = filename
                filename = basename + ".swf"
            else:
                html = basename + ".html"
                filename = filename

        steps = 100.0 / (self.pdf.pages*2 + 3)
        pos = [0]
        
        self.lastsavefile = filename
        if html:
            self.lasthtmlfile = html

        swf = gfx.SWF()
        for k,v in gfx_options.items():
            swf.setparameter(k,v)
        if pages is None:
            pages = range(1,self.pdf.pages+1)
        pdfwidth,pdfheight=0,0
        for pagenr in pages:
            page = self.pdf.getPage(pagenr)
            pdfwidth = page.width
            pdfheight = page.height
            swf.startpage(page.width, page.height)
            page.render(swf)
            swf.endpage()
        swf.save(filename)
        if not os.path.isfile(filename):
            error("Couldn't create file "+filename)

        if gfx_options.get("rfxview",None):
            rfxview = os.path.join(basedir, "rfxview.swf")
            if not os.path.isfile(rfxview):
                error("File rfxview.swf not found in working directory")
            else:
                size1 = os.stat(filename)[stat.ST_SIZE]
                swfcombine([rfxview,"viewport="+filename,"-o",filename])
                size2 = os.stat(filename)[stat.ST_SIZE]
                if size1 == size2:
                    error("Couldn't add viewer to file "+filename)
        
        if html:
            version = int(gfx_options.get("flashversion", "8"))
            swf = gfx.open("swf", filename)
            page1 = swf.getPage(1)

            width,height = str(page1.width),str(page1.height)


            w = gfx_options.get("rfxwidth","")
            if w == "fullscreen":    width = "100%"
            elif w == "same as PDF": width = pdfwidth+40
            elif w.isdigit():        width = w
            else:                    width = pdfwidth
            
            h = gfx_options.get("rfxheight","")
            if h == "fullscreen":    height = "100%"
            elif h == "same as PDF": height = pdfheight+70
            elif h.isdigit():        height = h
            else:                    height = pdfwidth

            flashvars = ""
            zoomtype = gfx_options.get("rfxzoomtype","")
            if zoomtype=="Original resolution":
                flashvars = "zoomtype=1"
            elif zoomtype=="Show all":
                flashvars = "zoomtype=2"
            elif zoomtype=="Maximum width/height":
                flashvars = "zoomtype=3"

            swffilename = os.path.basename(filename)
            fi = open(html, "wb")
            fi.write(HTMLTEMPLATE % locals())
            fi.close()


    def changePage(self,page):
        self.pagenr = page
        self.page = self.pdf.getPage(self.pagenr)
        for type,f in self.listeners:
            if type&EVENT_PAGE_CHANGE:
                f()

    def getPageIcon(self,pagenr):
        page = self.pdf.getPage(pagenr)
        return wx.BitmapFromImage(wx.ImageFromData(ICON_SIZE,ICON_SIZE,page.asImage(ICON_SIZE,ICON_SIZE)))
        #return wx.BitmapFromImage(wx.ImageFromData(8,8,"0"*(64*3)))

    def getPageImage(self, width, height):
        if self.bitmap_width == width and self.bitmap_height == height and self.bitmap_page == self.pagenr:
            return self.pagebitmap
        else:
            self.bitmap_width = width
            self.bitmap_height = height
            self.bitmap_page = self.pagenr
            self.pagebitmap = wx.BitmapFromImage(wx.ImageFromData(width,height,self.page.asImage(width,height)))
            #self.pagebitmap = wx.BitmapFromImage(wx.ImageFromData(8,8,"0"*(64*3)))
            return self.pagebitmap

    def setStatus(self,text):
        self.status_text = text
        for type,f in self.listeners:
            if type&EVENT_STATUS_TEXT:
                f()

state = State()

class PageListWidget(wx.ListCtrl):
    def __init__(self,parent):
        wx.ListCtrl.__init__(self,parent,style=wx.LC_ICON|wx.LC_AUTOARRANGE)
        #self.SetMinSize((ICON_SIZE+8,-1))
        #self.SetMaxSize((ICON_SIZE+8,-1))
        #self.SetSize((ICON_SIZE+8,-1))
        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.SelectItem)
        state.onEvent(EVENT_FILE_CHANGE, self.reload)
        state.onEvent(EVENT_PAGE_CHANGE, self.switchPage)
        self.reload()
        self.dontcare = 0
        #self.Bind(wx.EVT_IDLE, self.OnIdle)
        #print dir(self)

    def processFiles(self):
        if self.filepos >= 0 and self.filepos < state.pdf.pages:
            icon = state.getPageIcon(self.filepos+1)
            self.imglist.Add(icon)
            self.InsertImageStringItem(self.filepos, str(self.filepos+1), self.filepos)
            self.filepos = self.filepos + 1
        self.Update()

    def OnIdle(self,event):
        self.processFiles()
        event.ResumePropagation(0)

    def reload(self):
        self.filepos = -1
        self.DeleteAllItems()
        self.imglist = wx.ImageList(ICON_SIZE,ICON_SIZE,mask=False)
        self.AssignImageList(self.imglist,wx.IMAGE_LIST_NORMAL)
        self.filepos = 0
        while state.pdf and self.filepos < state.pdf.pages:
            self.processFiles()

    def switchPage(self):
        if self.dontcare:
            self.dontcare = 0
            return
        for i in range(0,self.GetItemCount()):
            self.Select(i, False)
        self.Select(state.pagenr-1, True)
        self.Focus(state.pagenr-1)
        self.Update()

    def SelectItem(self,event):
        self.dontcare = 1 #ignore next change event
        state.changePage(event.GetIndex()+1)


helptxt = """
This is the SWF preview window.
Here, you will see how the SWF file generated from
the PDF file will look like. Changing parameters in
the configuration which affect the appeareance of
the final SWF will affect this preview, too, so you
can always evaluate the final output beforehand.
"""

        
class OnePageWidget(wx.Window):
    def __init__(self,parent):
        wx.Window.__init__(self, parent)
        self.SetSize((160,100))
        self.SetMinSize((160,100))
        self.Fit()
        self.Bind(wx.EVT_PAINT, self.OnPaint)
        self.Bind(wx.EVT_SIZE, self.OnSize)
        self.Bind(wx.EVT_KEY_DOWN, self.key_down)
        state.onEvent(EVENT_PAGE_CHANGE, self.OnPageChange)
    
    def key_down(self, event):
        if state.pdf:
            if event.GetKeyCode() == 312 and state.pagenr>1:
                state.changePage(state.pagenr-1)
            elif event.GetKeyCode() == 313 and state.pagenr<state.pdf.pages:
                state.changePage(state.pagenr+1)

    def OnPageChange(self):
        self.Refresh()

    def OnSize(self, event):
        self.Refresh()

    def Draw(self,dc=None):
        global bitmap
        if not dc:
            dc = wx.ClientDC(self)
        posx = 0 
        posy = 0
        window_width,window_height = self.GetSize()
        dc.Clear()

        if not state.pdf or not state.page:
            return

        if state.page.width * window_height > state.page.height * window_width:
            width = window_width
            height = window_width * state.page.height / state.page.width
            posy = (window_height - height) / 2
        else:
            width = window_height * state.page.width / state.page.height
            height = window_height
            posx = (window_width - width) / 2

        dc.DrawBitmap(state.getPageImage(width,height), posx,posy, False)
        #state.getPageImage(

    def OnPaint(self, event):
        dc = wx.PaintDC(self)
        self.Draw(dc)

class Pdf2swfFrame(wx.Frame):
    #def __init__(self):
        #wx.Window.__init__(self, None, id=-1, pos=wx.DefaultPosition, size=wx.DefaultSize)
    def __init__(self,application):
        wx.Frame.__init__(self, None, -1, style = wx.DEFAULT_FRAME_STYLE)
        self.application = application
        
        self.SetTitle("pdf2swf")
        self.createMenu()
        self.createToolbar()
        self.createStatusBar()
        self.createMainFrame()
        
        self.SetSize((800,600))

        self.options = OptionFrame(None)
        self.options.Show(False)
        self.options.updateOptions()

        state.onEvent(EVENT_STATUS_TEXT, self.status_change)
        self.html = 0
       
        #self.table = wx.AcceleratorTable([(wx.ACCEL_ALT,  ord('X'), 333),])
        #self.SetAcceleratorTable(self.table)

        self.Bind(wx.EVT_IDLE, self.OnIdle)
        self.Bind(wx.EVT_CLOSE, self.menu_exit)
        return

    def menu_open(self,event):
        global state
        if state.filename:
            dlg = wx.FileDialog(self, "Choose PDF File:", style = wx.DD_DEFAULT_STYLE, defaultFile = state.filename, wildcard = "PDF files (*.pdf)|*.pdf|all files (*.*)|*.*")
        else:
            dlg = wx.FileDialog(self, "Choose PDF File:", style = wx.DD_DEFAULT_STYLE, wildcard = "PDF files (*.pdf)|*.pdf|all files (*.*)|*.*")

        if dlg.ShowModal() == wx.ID_OK:
            self.filename = dlg.GetFilename() 
            state.loadPDF(self.filename)

    def menu_save(self,event,pages=None):
        html,self.html = self.html,0
        global state
        if not state.pdf:
            return
        print "html",html
        if not html:
            defaultFile = state.lastsavefile
        else:
            defaultFile = state.lasthtmlfile
        dlg = wx.FileDialog(self, "Choose Save Filename:", style = wx.SAVE | wx.OVERWRITE_PROMPT, defaultFile = defaultFile, wildcard = "all files (*.*)|*.*|SWF files (*.swf)|*.swf|HTML template (*.html)|*.html")
        
        if dlg.ShowModal() == wx.ID_OK:
            filename = os.path.join(dlg.GetDirectory(),dlg.GetFilename())
        
            #progress = ProgressFrame(self, "Saving %s File '%s'..." % (html and "HTML" or "SWF", filename))
            #progress.Show(True)
            progress = None
            state.saveSWF(filename, progress, pages, html)
            #progress.Destroy()
    
    def menu_save_selected(self,event):
        if not state.pdf:
            return
        p = []
        for i in range(0,self.pagelist.GetItemCount()):
            if self.pagelist.IsSelected(i):
                p += [i+1]
        self.menu_save(event, pages=p)

    def menu_save_html(self,event):
        self.html = 1
        return self.menu_save(event)

    def menu_save_selected_html(self,event):
        self.html = 1
        return self.menu_save_selected(event)

    def menu_exit(self,event):
        self.application.Exit()

    def menu_selectall(self,event):
        for i in range(0,self.pagelist.GetItemCount()):
            self.pagelist.Select(i, True)
    def menu_options(self,event):
        self.options.Show(True)

    def status_change(self):
        self.statusbar.SetStatusText(state.status_text)

    def OnIdle(self,event):
        if self.options.needreload:
            self.options.needreload = 0
            if state.pdf:
                # reload
                state.loadPDF(state.filename)

    def createMenu(self):
        menubar = wx.MenuBar()

        menu = wx.Menu();menubar.Append(menu, "&File")
        menu.Append(wx.ID_OPEN, "Open PDF\tCTRL-O");self.Bind(wx.EVT_MENU, self.menu_open, id=wx.ID_OPEN)
        menu.AppendSeparator()
        menu.Append(wx.ID_SAVE, "Save SWF (all pages)\tCTRL-W");self.Bind(wx.EVT_MENU, self.menu_save, id=wx.ID_SAVE)
        menu.Append(wx.ID_SAVEAS, "Save SWF (selected pages)\tCTRL-S");self.Bind(wx.EVT_MENU, self.menu_save_selected, id=wx.ID_SAVEAS)
        menu.AppendSeparator()
        menu.Append(2001, "Save HTML template (all pages)\tCTRL-H");self.Bind(wx.EVT_MENU, self.menu_save_html, id=2001)
        menu.Append(2002, "Save HTML template (selected pages)");self.Bind(wx.EVT_MENU, self.menu_save_selected_html, id=2002)
        menu.AppendSeparator()
        menu.Append(wx.ID_EXIT, "Exit\tCTRL-Q");self.Bind(wx.EVT_MENU, self.menu_exit, id=wx.ID_EXIT)

        menu = wx.Menu();menubar.Append(menu, "&Edit")
        menu.Append(wx.ID_SELECTALL, "Select All\tCTRL-A");self.Bind(wx.EVT_MENU, self.menu_selectall, id=wx.ID_SELECTALL)
        menu.AppendSeparator()
        menu.Append(wx.ID_PREFERENCES, "Options\tCTRL-R");self.Bind(wx.EVT_MENU, self.menu_options, id=wx.ID_PREFERENCES)

        menu = wx.Menu();menubar.Append(menu, "&Help")

        self.SetMenuBar(menubar)


    def createToolbar(self):

        tsize = (16,16)
        self.toolbar = self.CreateToolBar(wx.TB_HORIZONTAL | wx.NO_BORDER | wx.TB_FLAT)

        self.toolbar.AddSimpleTool(wx.ID_OPEN,
                                   wx.ArtProvider.GetBitmap(wx.ART_FILE_OPEN, wx.ART_TOOLBAR, tsize),
                                   "Open")
        self.toolbar.AddSimpleTool(wx.ID_SAVE,
                                   wx.ArtProvider.GetBitmap(wx.ART_FILE_SAVE, wx.ART_TOOLBAR, tsize),
                                   "Save selected pages")
        self.toolbar.AddSimpleTool(wx.ID_PREFERENCES,
                                   wx.ArtProvider.GetBitmap(wx.ART_LIST_VIEW, wx.ART_TOOLBAR, tsize),
                                   "Options")
        #self.toolbar.AddSeparator()
        self.toolbar.Realize()

    def createStatusBar(self):
        self.statusbar = self.CreateStatusBar(1)

    def createMainFrame(self):
        
        if 0:
            self.pagelist = PageListWidget(self)
            self.onepage = OnePageWidget(self)
            hsplit = wx.BoxSizer(wx.HORIZONTAL)
            pagelistbox = wx.StaticBox(self, -1, "Pages")
            pagelistboxsizer= wx.StaticBoxSizer(pagelistbox, wx.VERTICAL)
            pagelistboxsizer.Add(self.pagelist, proportion=1, flag=wx.EXPAND)
            onepagebox = wx.StaticBox(self, -1, "Page 1")
            onepageboxsizer= wx.StaticBoxSizer(onepagebox, wx.VERTICAL)
            onepageboxsizer.Add(self.onepage, proportion=1, flag=wx.EXPAND)
            hsplit.Add(pagelistboxsizer, 0, wx.EXPAND, 0)
            hsplit.Add(onepageboxsizer, 1, wx.EXPAND, 0)
            self.SetAutoLayout(True)
            self.SetSizer(hsplit)
            hsplit.Fit(self)
            hsplit.SetSizeHints(self)
        else:
            hsplit = wx.SplitterWindow(self, style=wx.SP_3D|wx.SP_LIVE_UPDATE)
            #p1 = wx.Panel(hsplit,-1, style=wx.SUNKEN_BORDER)
            #p2 = wx.Panel(hsplit,-1, style=wx.SUNKEN_BORDER)
            self.pagelist = PageListWidget(hsplit)
            self.onepage = OnePageWidget(hsplit)
            #hsplit.SplitVertically(p1,p2, sashPosition=64)
            hsplit.SplitVertically(self.pagelist, self.onepage, sashPosition=ICON_SIZE*3/2)
            hsplit.SetMinimumPaneSize(10)

class MyApp(wx.App):
    def __init__(self):
        wx.App.__init__(self, redirect=False, filename=None, useBestVisual=False)
        
        #state.loadPDF("sitis2007.pdf")
        #state.loadPDF("wxPython-Advanced-OSCON2004.pdf")
        global staticdata
        staticdata = StaticData()

        self.frame = Pdf2swfFrame(self)
        self.SetTopWindow(self.frame)
        self.frame.Show(True)

        #self.frame = TestFrame(self)
        #self.frame.Show(True)

    def OnInit(self):
        return True

        
raw_width=100
raw_height=100
raw_data="""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffQQQ\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"""+\
"""\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"""+\
"""\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffJJJ]]]\xc5\xc5\xc5\xc1\xc1\xc1\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4"""+\
"""\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc2\xc2\xc2\xc1\xc1\xc1\xc1\xc1\xc1\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4"""+\
"""\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc1\xc1\xc1\xc4\xc4\xc4\x96\x96\x96"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffHHH\x81\x81\x81\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd0\xd0\xd0"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffIIIxxx\xfc\xfc\xfc\xf8\xf8\xf8\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc"""+\
"""\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xf9\xf9\xf9\xc2\xc2\xc2\xb2\xb2\xb2\xaf\xaf\xaf\xe9\xe9\xe9\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfa\xfa\xfa\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfa\xfa\xfa\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc"""+\
"""\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xf9\xf9\xf9\xfc\xfc\xfc\xc2\xc2\xc2"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffIII\x7a\x7a\x7a\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff"""+\
"""\xff\xff\xfc\xfc\xfc\xff\xff\xff\xdd\xdd\xdd\x22\x22\x22\x83\x83\x83\x7d\x7d\x7d\xdd\xdd\xdd\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xf9\xf9\xf9\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfeIII\x79\x79\x79\xfe\xfe\xfe\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xd8\xd8\xd8TTT\xff\xff\xff\xff\xff\xff\xe3\xe3\xe3gggnnn\xb4\xb4\xb4\xa6\xa6\xa6\x5c\x5c\x5ciii\xe1\xe1\xe1\xf0\xf0\xf0\x7b\x7b\x7bqqqZZZ\xb3\xb3\xb3oooooo\xec\xec\xec\xfc\xfc\xfc\x92\x92\x92WWWooo\xed\xed\xed\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc4\xc4\xc4"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfeIII\x79\x79\x79\xfe\xfe\xfe\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xe0\xe0\xe0%%%lll\x86\x86\x86\xc3\xc3\xc3&&&\xdf\xdf\xdf\xff\xff\xff\xeb\xeb\xeb\xe0\xe0\xe0ccc\x79\x79\x79\xfb\xfb\xfb---\xd6\xd6\xd6\xab\xab\xab,,,\xed\xed\xed\x83\x83\x83\xa4\xa4\xa4\xc2\xc2\xc2III\xf3\xf3\xf3sss\x7e\x7e\x7e\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffIII\x7a\x7a\x7a\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff"""+\
"""\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd9\xd9\xd9LLL\xea\xea\xea\xee\xee\xee\xcb\xcb\xcbccc\xff\xff\xff\xf6\xf6\xf6xxx\x8c\x8c\x8c\x7d\x7d\x7dkkk\xee\xee\xeefff\xff\xff\xff\xcb\xcb\xcbppp\xff\xff\xff\xa4\xa4\xa4\x8d\x8d\x8d\xa2\xa2\xa2@@@\x92\x92\x92\x79\x79\x79\xa5\xa5\xa5\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfeHHH\x79\x79\x79\xfe\xfe\xfe\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xd5\xd5\xd5JJJ\xff\xff\xff\xff\xff\xff\xcc\xcc\xccWWW\xfd\xfd\xfd\xe4\xe4\xe4FFF\xe9\xe9\xe9mmm___\xed\xed\xed[[[\xfa\xfa\xfa\xc4\xc4\xc4ggg\xfe\xfe\xfe\x9b\x9b\x9b\x86\x86\x86\xd4\xd4\xd4GGG\xdc\xdc\xdc\xe7\xe7\xe7\xe6\xe6\xe6\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffIII\x7a\x7a\x7a\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff"""+\
"""\xff\xff\xfd\xfd\xfd\xff\xff\xff\xe7\xe7\xe7\x93\x93\x93\xfd\xfd\xfd\xfd\xfd\xfd\xe0\xe0\xe0\x9c\x9c\x9c\xfe\xfe\xfe\xfe\xfe\xfe\xa7\xa7\xa7nnn\x8d\x8d\x8d\xa9\xa9\xa9\xf3\xf3\xf3\x9f\x9f\x9f\xfd\xfd\xfd\xdd\xdd\xdd\xa5\xa5\xa5\xfe\xfe\xfe\xc6\xc6\xc6\xaf\xaf\xaf\xff\xff\xff\xa7\xa7\xa7cccooo\xcd\xcd\xcd\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfeHHH\x79\x79\x79\xfe\xfe\xfe\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xffLLL\x7c\x7c\x7c\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xee\xee\xee\xf3\xf3\xf3<<<mmm\xf3\xf3\xf3\xef\xef\xef\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3"""+\
"""\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3"""+\
"""\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xc3\xc3\xc3\x22\x22\x22YYYVVVVVVWWWWWWVVVWWWWWWWWWVVVWWWDDDKKK\x5c\x5c\x5c[[[[[[[[[\x5c\x5c\x5c\x5c"""+\
"""\x5c\x5c[[[\x5c\x5c\x5c[[[\x5c\x5c\x5c[[[[[[\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c[[[\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c[[[[[[[[[\x5c\x5c\x5c[[[\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c[[[[[[\x5c\x5c"""+\
"""\x5c[[[[[[[[[\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c\x5c[[[[[[\x5c\x5c\x5c\x5c\x5c\x5c[[[\x5c\x5c\x5c\x5c\x5c\x5c[[[[[[\x5c\x5c\x5cXXXMMM\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfa\xfa\xfa\xff\xff\xff\xb3\xb3\xb3)))\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xffWWW\xf2\xf2\xf2\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6000\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfc\xfc\xfc\xfa\xfa\xfa\xf9\xf9\xf9\xfc\xfc\xfc\xfe"""+\
"""\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xf9\xf9\xf9\xfc\xfc\xfc\xfb\xfb\xfb\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\x5c\x5c\x5c\xf3\xf3\xf3\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6...\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x96\x96\x96^^^^^^\x93\x93\x93\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe"""+\
"""\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xf9\xf9\xf9\xff\xff\xffNNN\xa6\xa6\xa6\xe3\xe3\xe3\xe6\xe6\xe6\xde\xde\xde\xd4\xd4\xd4\xbb\xbb\xbb\xec\xec\xec\xad\xad\xad\xac\xac\xac\xf1\xf1\xf1\xfe"""+\
"""\xfe\xfe\xe6\xe6\xe6\xd9\xd9\xd9\xab\xab\xab\xf1\xf1\xf1\xdf\xdf\xdf\xb1\xb1\xb1\xf6\xf6\xf6\xfe\xfe\xfe\xff\xff\xff\xb9\xb9\xb9\xb0\xb0\xb0\xf8\xf8\xf8\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff]]]\x85\x85\x85\xb8\xb8\xb8\xed\xed\xedUUUUUU\xab\xab\xab\xd7\xd7\xd7\x9b\x9b\x9b\x79\x79\x79eee\xff"""+\
"""\xff\xffxxxRRR\x82\x82\x82III\x88\x88\x88nnn\x85\x85\x85\xff\xff\xff\x88\x88\x88\x7b\x7b\x7b\x7c\x7c\x7c\x7e\x7e\x7e\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xffZZZddd\x8f\x8f\x8f\xd9\xd9\xd9XXX\xb8\xb8\xb8\xff\xff\xff\xf0\xf0\xf0\xb6\xb6\xb6\xa5\xa5\xa5000\xf4"""+\
"""\xf4\xf4\x7a\x7a\x7a\x9c\x9c\x9c\xff\xff\xffGGG\xc8\xc8\xc8\xff\xff\xffUUU\xe2\xe2\xe2777\xa9\xa9\xa9\xa7\xa7\xa7BBB\xe1\xe1\xe1\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfa\xfa\xfa\xfe\xfe\xfe\xb5\xb5\xb5...\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfeZZZ\xc8\xc8\xc8\xff\xff\xff\xff\xff\xffXXX\xd9\xd9\xd9\xfb\xfb\xfb\x82\x82\x82\x7e\x7e\x7e\xd5\xd5\xd5444\xe9"""+\
"""\xe9\xe9\x84\x84\x84\xb6\xb6\xb6\xfb\xfb\xfbooo\xd2\xd2\xd2\xfd\xfd\xfdUUU\xe0\xe0\xe0666\xa7\xa7\xa7\xc1\xc1\xc1\xc8\xc8\xc8\xf5\xf5\xf5\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\x5c\x5c\x5c\xbd\xbd\xbd\xfc\xfc\xfc\xfe\xfe\xfeZZZ\xd5\xd5\xd5\xff\xff\xff\x94\x94\x94www\x9d\x9d\x9d(((\xee"""+\
"""\xee\xee\x83\x83\x83\xb3\xb3\xb3\xfe\xfe\xfejjj\xd1\xd1\xd1\xfe\xfe\xfeQQQ\xfe\xfe\xfe\x88\x88\x88uuu\xae\xae\xae\xb2\xb2\xb2\xf8\xf8\xf8\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd7\xd7\xd7\xef\xef\xef\xff\xff\xff\xff\xff\xff\xd6\xd6\xd6\xf4\xf4\xf4\xff\xff\xff\xfc\xfc\xfc\xb0\xb0\xb0\xc2\xc2\xc2\xd7\xd7\xd7\xf8"""+\
"""\xf8\xf8\xe0\xe0\xe0\xec\xec\xec\xfe\xfe\xfe\xdb\xdb\xdb\xf3\xf3\xf3\xfe\xfe\xfe\xd4\xd4\xd4\xfe\xfe\xfe\xff\xff\xff\xb9\xb9\xb9\x9b\x9b\x9b\xcb\xcb\xcb\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xb6\xb6\xb6///\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xf9\xf9\xf9\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf9\xf9\xf6\xf6\xf6\xfa\xfa\xfa\xb2\xb2\xb2...\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfa\xfa\xfa\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfa\xfa\xfa\xfb\xfb\xfb\xfd\xfd\xfd\xfb\xfb\xfb\xf8\xf8\xf8\xf9\xf9\xf9\xfa\xfa\xfa\xfc"""+\
"""\xfc\xfc\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfa\xfa\xfa\xfd\xfd\xfd\xfc\xfc\xfc\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd"""+\
"""\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc6\xc6\xc6111\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""QQQJJJIIIIIIIIIHHHHHHIIIHHHIIIHHHGGGIII111\x1f\x1f\x1f\xac\xac\xac\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xad\xad\xad\xad\xad\xad\xae\xae\xae\xae"""+\
"""\xae\xae\xad\xad\xad\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xad\xad\xad\xad\xad\xad\xad\xad\xad\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xad\xad\xad\xad\xad\xad\xae\xae"""+\
"""\xae\xae\xae\xae\xad\xad\xad\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xae\xb1\xb1\xb1\xea\xea\xea\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\x00\x00\x00YYY\x7e\x7e\x7e\x79\x79\x79\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x79\x79\x79\x7a\x7a\x7a\x79\x79\x79\x7a\x7a\x7a\x7b\x7b\x7b\x7f\x7f\x7f\x8d\x8d\x8d\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x90\x90\x90\x90"""+\
"""\x90\x90\x8f\x8f\x8f\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x8f\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x8f\x8f\x8f\x90\x90"""+\
"""\x90\x90\x90\x90\x8f\x8f\x8f\x90\x90\x90\x90\x90\x90\x8f\x8f\x8f\x93\x93\x93PPP\xb0\xb0\xb0\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\x04\x04\x04\xd3\xd3\xd3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x98\x98\x98\xad\xad\xad\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\x00\x00\x00\xc1\xc1\xc1\xfb\xfb\xfb\xf8\xf8\xf8\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\xf9\xf9\xf8\xf8\xf8\xf8\xf8\xf8\xfa\xfa\xfa\xf7\xf7\xf7\xf7\xf7\xf7\xfa\xfa\xfa\xfc\xfc\xfc\xf8\xf8\xf8\xf9\xf9\xf9\xf7\xf7\xf7\xfa\xfa\xfa\xf9\xf9\xf9\xf8\xf8\xf8\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xf7\xf7\xf7\xf7\xf7\xf7\xfa\xfa\xfa\xfc\xfc\xfc\xfc"""+\
"""\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc"""+\
"""\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xf9\xf9\xf9\xfc\xfc\xfc\x8e\x8e\x8e\xae\xae\xae\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\x7f\x7f\x7fSSSUUU\x9c\x9c\x9c\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff"""+\
"""\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfeJJJ\xcb\xcb\xcb\xf5\xf5\xf5\xf1\xf1\xf1\xd6\xd6\xd6\xbb\xbb\xbb\xb6\xb6\xb6\xe1\xe1\xe1\x97\x97\x97\x9f\x9f\x9f\xed\xed\xed\xfe\xfe\xfe\xd3\xd3\xd3\xc8\xc8\xc8\x99\x99\x99\xee\xee\xee\xcb\xcb\xcb\xa1\xa1\xa1\xf5\xf5\xf5\xff\xff\xff\xf6\xf6\xf6\x9f\x9f\x9f\xa0\xa0\xa0\xf8\xf8\xf8\xff\xff\xff\xfe"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe"""+\
"""\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3"""+\
"""\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xffTTT\x85\x85\x85\xa9\xa9\xa9\xdc\xdc\xdcJJJddd\xc2\xc2\xc2\xd5\xd5\xd5\xb0\xb0\xb0vvvjjj\xff\xff\xffZZZ[[[\x93\x93\x93888\x94\x94\x94ppp\x8d\x8d\x8d\xfc\xfc\xfcnnn\x92\x92\x92\x86\x86\x86\x79\x79\x79\xfd\xfd\xfd\xfc"""+\
"""\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4"""+\
"""\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffSSS\x7e\x7e\x7e\xa0\xa0\xa0\xd7\xd7\xd7SSS\xdb\xdb\xdb\xff\xff\xff\xe5\xe5\xe5\xa3\xa3\xa3\x93\x93\x93>>>\xfe\xfe\xfefff\xba\xba\xba\xff\xff\xffFFF\xe4\xe4\xe4\xe9\xe9\xe9mmm\xcb\xcb\xcb;;;\xa6\xa6\xa6\x94\x94\x94JJJ\xee\xee\xee\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfeUUU\xe1\xe1\xe1\xff\xff\xff\xfa\xfa\xfaccc\xe2\xe2\xe2\xfc\xfc\xfcooo\x9c\x9c\x9c\xcd\xcd\xcd000\xff\xff\xffiii\xcc\xcc\xcc\xfc\xfc\xfceee\xe9\xe9\xe9\xe0\xe0\xe0mmm\xcf\xcf\xcf;;;\xb8\xb8\xb8\xd0\xd0\xd0\xd8\xd8\xd8\xfa\xfa\xfa\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff]]]\xd4\xd4\xd4\xfc\xfc\xfc\xf5\xf5\xf5iii\xe1\xe1\xe1\xff\xff\xff\x94\x94\x94xxx\x83\x83\x83999\xfc\xfc\xfcooo\xcb\xcb\xcb\xfe\xfe\xfehhh\xe9\xe9\xe9\xe4\xe4\xe4kkk\xfe\xfe\xfe\x88\x88\x88sss\x98\x98\x98\xad\xad\xad\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xe1\xe1\xe1\xf8\xf8\xf8\xfe\xfe\xfe\xfd\xfd\xfd\xe4\xe4\xe4\xf9\xf9\xf9\xfe\xfe\xfe\xfd\xfd\xfd\xbe\xbe\xbe\xd2\xd2\xd2\xe9\xe9\xe9\xfd\xfd\xfd\xe5\xe5\xe5\xf6\xf6\xf6\xfe\xfe\xfe\xe4\xe4\xe4\xfb\xfb\xfb\xfa\xfa\xfa\xe5\xe5\xe5\xfd\xfd\xfd\xff\xff\xff\xc4\xc4\xc4\xb0\xb0\xb0\xdc\xdc\xdc\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x90\x90\x90\xae\xae\xae\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\x5c\x5c\x5c\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x90\x90\x90\xae\xae\xae\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\x5c\x5c\x5c\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe[[[\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc3\xc3\xc3\x00\x00\x00\xc4\xc4\xc4\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x90\x90\x90\xae\xae\xae\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\x5c\x5c\x5c\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\x5c\x5c\x5c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc4\xc4\xc4\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff[[[\xef\xef\xef\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xf8\xf8\xf8\xfb\xfb\xfb\xc1\xc1\xc1\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff^^^\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd3\xd3\xd3\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xffLLLooo\x7c\x7c\x7c\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x7a\x79\x79\x79\x7e\x7e\x7eYYY\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xffDDDDDDJJJHHHIIIHHHIIIHHHIIIIIIIIIIIIJJJ\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffYYY\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfeVVV\xee\xee\xee\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfeVVV\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffWWW\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffWWW\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfeVVV\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffWWW\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x90\x90\x90\xae\xae\xae\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xffWWW\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\x8f\x8f\x8f\xad\xad\xad\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfeVVV\xf3\xf3\xf3\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\x90\x90\x90\xaf\xaf\xaf\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xffWWW\xf2\xf2\xf2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x8f\x8f\x8f\xab\xab\xab\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfdYYY\xf3\xf3\xf3\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x8d\x8d\x8d###222......//////...//////......///---\x19\x19\x19\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\x7e\x7e\x7e000\xb6\xb6\xb6\xb2\xb2\xb2\xb5\xb5\xb5\xb6\xb6\xb6\xb6\xb6\xb6\xb5\xb5\xb5\xb6\xb6\xb6\xb6\xb6\xb6\xb5\xb5\xb5\xb5\xb5\xb5\xb6\xb6\xb6\xb6\xb6\xb6\xc3\xc3\xc3\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xffxxxNNN\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xfe\xfe\xfe\x7a\x7a\x7aHHH\xfb\xfb\xfb\xf6\xf6\xf6\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xfe\xfe\xfe\x79\x79\x79HHH\xfe\xfe\xfe\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x7a\x7a\x7aIII\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xfe\xfe\xfe\x79\x79\x79HHH\xfe\xfe\xfe\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x7a\x7a\x7aIII\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc3\xc3\xc3\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xfe\xfe\xfe\x79\x79\x79III\xfe\xfe\xfe\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x7a\x7a\x7aIII\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x7a\x7a\x7aIII\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xc2\xc2\xc2\xfc\xfc\xfc\xf9\xf9\xf9\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xf8\xf8\xf8\xfc\xfc\xfcxxxIII\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\x00\x00\x00\xd0\xd0\xd0\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x81\x81\x81HHH\xfe\xfe\xfe\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\x00\x00\x00\x96\x96\x96\xc4\xc4\xc4\xc1\xc1\xc1\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc4\xc4\xc4\xc1\xc1\xc1\xc5\xc5\xc5]]]JJJ\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff"""

simpleviewer_width=100
simpleviewer_height=100
simpleviewer_data="""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"""+\
"""\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"""+\
"""\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\x84\x84\x84\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb5\xb5\xb5\xb6\xb6\xb6\xb5\xb5\xb5\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7"""+\
"""\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7"""+\
"""\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\x84\x84\x84\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\xf9\xf9\x79\x8b\x79ftf\xf7\xf7\xf7&2&\xbd\xc1\xbd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xaa\xb2\xaa2Z2+\xca+PgP\xf6\xf6\xf6*k**\x8c*JdJ\xe1\xe1\xe1\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd4\xd6\xd4?\x5c?*\x9d*2\xfe22\xff2OgO\xf4\xf4\xf4-r-2\xff2-\xe8-*j*o\x81o\xf6"""+\
"""\xf6\xf6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xef\xef\xef^s^)s)/\xef/2\xff22\xff22\xff2NgN\xf3\xf3\xf3.t.2\xff22\xff22\xff2)\xc9)."""+\
"""U.\xa0\xa9\xa0\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\x8c\x98\x8c,[,+\xd6+2\xff22\xff22\xff22\xff22\xff2NgN\xf2\xf2\xf2.u.2\xff22\xff22\xff22\xff22"""+\
"""\xfe2)\xa2)<Y<\xce\xd0\xce\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xbc\xc0\xbc2Q2*\xb3*2\xff22\xff22\xff22\xff22\xff22\xff22\xff2MgM\xf0\xf0\xf0/w/2\xff22\xff22\xff22\xff22"""+\
"""\xff22\xff20\xf40,\x7d,[q[\xec\xec\xec\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xfe\xfe\xfe\x7d\x8a\x7d\x1dO\x1d+\xdc+2\xff22\xff22\xff22\xff22\xff22\xff22\xff27Q7\xb0\xb0\xb0&n&2\xff22\xff22\xff22\xff22"""+\
"""\xff22\xff22\xfd2'\x98'5R5\xb4\xb4\xb4\xd0\xd0\xd0\xab\xab\xab\xc2\xc2\xc2\xd8\xd8\xd8\xff\xff\xff\xee\xee\xee\xb3\xb3\xb3\xa6\xa6\xa6\xca\xca\xca\xc9\xc9\xc9\xa7\xa7\xa7\xf3\xf3\xf3\xb2\xb2\xb2\xed\xed\xed\xb4\xb4\xb4\xe1\xe1\xe1\xff\xff\xff\xb3\xb3\xb3\xde\xde\xde\xc5\xc5\xc5xxx\xe9\xe9\xe9\xff\xff\xff\xb8\xb8\xb8\xd5\xd5\xd5\xd2\xd2\xd2\xab\xab\xab\xc3\xc3"""+\
"""\xc3\xd4\xd4\xd4\xe0\xe0\xe0\xba\xba\xba\xc2\xc2\xc2\x9b\x9b\x9b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\x91\x91\x91VlV!r!/\xf2/2\xff22\xff22\xff22\xff22\xff20J0\x8b\x8b\x8b+v+2\xff22\xff22\xff22\xff22"""+\
"""\xff2(\xbd(\x1fD\x1f\x8b\x94\x8b\xc2\xc2\xc2\xa6\xa6\xa6\x9d\x9d\x9d\xd6\xd6\xd6\xc0\xc0\xc0\xa7\xa7\xa7\xff\xff\xff\xa3\xa3\xa3\xf8\xf8\xf8\x9d\x9d\x9d\xa5\xa5\xa5\xa1\xa1\xa1\xa7\xa7\xa7\xa8\xa8\xa8\xfc\xfc\xfc\xa2\xa2\xa2\x9b\x9b\x9b\xff\xff\xff\xf7\xf7\xf7\x90\x90\x90\xda\xda\xda\xa7\xa7\xa7\xa7\xa7\xa7\xff\xff\xff\xff\xff\xff\xb1\xb1\xb1\x84\x84\x84\x9d\x9d\x9d\xe1\xe1\xe1\xb5\xb5"""+\
"""\xb5\xa7\xa7\xa7\x8c\x8c\x8c\xa0\xa0\xa0\xb9\xb9\xb9\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xac\xac\xac\xa7\xa7\xa7\x9b\x9c\x9b+H+(\x9c(2\xfd22\xff22\xff22\xff28S8\xaf\xaf\xaf,x,2\xff22\xff22\xff2+\xdd+\x1f"""+\
"""U\x1fk\x7bk\xa6\xa6\xa6\xd3\xd3\xd3\x98\x98\x98\x9b\x9b\x9b\xbd\xbd\xbd\xe5\xe5\xe5\xd8\xd8\xd8\xbd\xbd\xbd\xff\xff\xff\xcf\xcf\xcf\xa5\xa5\xa5\xb8\xb8\xb8\xac\xac\xac\xaa\xaa\xaa\xbd\xbd\xbd\xdb\xdb\xdb\xab\xab\xab\xd0\xd0\xd0\xbd\xbd\xbd\xff\xff\xff\xf5\xf5\xf5\xb0\xb0\xb0\xc0\xc0\xc0\xbd\xbd\xbd\xaf\xaf\xaf\xe6\xe6\xe6\xfc\xfc\xfc\x96\x96\x96\x90\x90\x90\xbd\xbd\xbd\xed\xed\xed\xd0\xd0"""+\
"""\xd0\xbd\xbd\xbd\xc3\xc3\xc3\xb0\xb0\xb0\xe6\xe6\xe6\xa4\xa4\xa4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xa7\xaf\xa70U0*\xc0*2\xff22\xff2HcH\xeb\xeb\xeb0\x7d02\xff2/\xf2/)\x7a)F\x5cF\xe9"""+\
"""\xe9\xe9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\xf9\xf9\x7b\x8a\x7b*`*+\xdc+FaF\xe9\xe9\xe9/\x7c/(\x9d(;X;\xca\xcb\xca\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe3\xe3\xe3\xb1\xb1\xb1\xef\xef\xef\xb2\xb2\xb2\xef\xef\xef\xb3\xb3\xb3\xc3\xc3\xc3\xcc\xcc\xcc;S;IYI\xa7\xa7\xa7\x1a'\x1a\x83\x8c\x83\xc7\xc7\xc7\x7d\x7d\x7d\xdf\xdf\xdf\xbe"""+\
"""\xbe\xbe\xdb\xdb\xdb\x7f\x7f\x7f\xd5\xd5\xd5\xe4\xe4\xe4\xd9\xd9\xd9\xd0\xd0\xd0\xc6\xc6\xc6\xff\xff\xff\xd0\xd0\xd0\xbc\xbc\xbc\xec\xec\xec\xb1\xb1\xb1\xdc\xdc\xdc\xc8\xc8\xc8\xcf\xcf\xcf\xb2\xb2\xb2\xf6\xf6\xf6\xca\xca\xca\xb7\xb7\xb7\xd9\xd9\xd9\xc8\xc8\xc8\xd4\xd4\xd4\xbd\xbd\xbd\xc8\xc8\xc8\xd7\xd7\xd7\xb1\xb1\xb1\xee\xee\xee\xc3\xc3\xc3\xb3\xb3\xb3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa2\xa2\xa2\xff\xff\xff\xa6\xa6\xa6\xfd\xfd\xfd\xa3\xa3\xa3\x9d\x9d\x9d\xa8\xa8\xa8\xbf\xbf\xbf\xa5\xa5\xa5\x9d\x9d\x9d\xaf\xaf\xaf\xab\xab\xab\xa2\xa2\xa2\xff\xff\xff\xa7\xa7\xa7\xdb\xdb\xdb\x8e"""+\
"""\x8e\x8e\x9f\x9f\x9f\xa7\xa7\xa7\xe7\xe7\xe7\xc0\xc0\xc0\xa6\xa6\xa6\x9b\x9b\x9b\xff\xff\xff\xff\xff\xff\xc9\xc9\xc9\x7b\x7b\x7b\xc6\xc6\xc6\xc3\xc3\xc3\xa3\xa3\xa3\xa7\xa7\xa7\x96\x96\x96\xf3\xf3\xf3\xaf\xaf\xaf\xa9\xa9\xa9\x8f\x8f\x8f\xd5\xd5\xd5\xa7\xa7\xa7\xa2\xa2\xa2\xff\xff\xff\xa7\xa7\xa7\xa0\xa0\xa0\xfa\xfa\xfa\xa9\xa9\xa9\xa4\xa4\xa4\x96\x96\x96\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc5\xc5\xc5\xad\xad\xad\xd6\xd6\xd6\xac\xac\xac\xd3\xd3\xd3\xbd\xbd\xbd\xbd\xbd\xbd\xd4\xd4\xd4\x9a\x9a\x9a\xd9\xd9\xd9\xab\xab\xab\xd9\xd9\xd9\xaa\xaa\xaa\xc6\xc6\xc6\xba\xba\xba\xd9\xd9\xd9\xa2"""+\
"""\xa2\xa2\xc9\xc9\xc9\xbb\xbb\xbb\xd9\xd9\xd9\x98\x98\x98\x9b\x9b\x9b\xbd\xbd\xbd\xff\xff\xff\xff\xff\xff\xae\xae\xae\x88\x88\x88\xc3\xc3\xc3\x88\x88\x88\xbb\xbb\xbb\xbd\xbd\xbd\x92\x92\x92\xa1\xa1\xa1\xe1\xe1\xe1\xbb\xbb\xbb\xb0\xb0\xb0\xbc\xbc\xbc\xbd\xbd\xbd\xb5\xb5\xb5\xbb\xbb\xbb\xbd\xbd\xbd\xbd\xbd\xbd\xff\xff\xff\xbd\xbd\xbd\xab\xab\xabxxx\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe5\xe5\xe5\xe6\xe6\xe6\xff\xff\xff\xff\xff\xff\xcb\xcb\xcb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xbf\xbf\xbf\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf9\xf9\xf9\xed\xed\xed\xe7\xe7\xe7\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xec\xec\xec\xff\xff\xff\xff"""+\
"""\xff\xff\xec\xec\xec\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xe8\xe8\xe8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe6\xe6\xe6\xb9\xb9\xb9\xe5\xe5\xe5\xbe\xbe\xbe\xbf\xbf\xbfxxx\xf0\xf0\xf0\xfb\xfb\xfb\xb1\xb1\xb1\xe4\xe4\xe4\xc7\xc7\xc7\xd3\xd3\xd3\xe4\xe4\xe4\xa9\xa9\xa9\xba\xba\xba\xff\xff\xff\xd4"""+\
"""\xd4\xd4\x86\x86\x86\xe9\xe9\xe9\xb5\xb5\xb5\xe2\xe2\xe2\xff\xff\xff\xea\xea\xea\xb8\xb8\xb8\xf4\xf4\xf4\xcc\xcc\xcc\xd9\xd9\xd9\xd9\xd9\xd9\xde\xde\xde\xb2\xb2\xb2\xdd\xdd\xdd\xb2\xb2\xb2\xc0\xc0\xc0\xc4\xc4\xc4\xec\xec\xec\xb2\xb2\xb2\xf4\xf4\xf4\xbf\xbf\xbf\x88\x88\x88\xff\xff\xff\xbd\xbd\xbd\xa0\xa0\xa0\xe0\xe0\xe0\xba\xba\xba\xed\xed\xed\xb0\xb0\xb0\xbe\xbe\xbe\xb9\xb9\xb9\xe0\xe0\xe0\xb4\xb4"""+\
"""\xb4\xe4\xe4\xe4\xd2\xd2\xd2\xc1\xc1\xc1\xdd\xdd\xdd\xb9\xb9\xb9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\x91\x91\x91\xa9\xa9\xa9\xbc\xbc\xbc\xbe\xbe\xbe\xa7\xa7\xa7\xa7\xa7\xa7\xff\xff\xff\xed\xed\xed\x94\x94\x94\xd9\xd9\xd9\x7d\x7d\x7d\x97\x97\x97\xa3\xa3\xa3\xdb\xdb\xdb\xba\xba\xba\xff\xff\xff\xa3"""+\
"""\xa3\xa3\xa8\xa8\xa8\xb3\xb3\xb3\xe3\xe3\xe3\xa1\xa1\xa1\xff\xff\xff\x96\x96\x96\xb1\xb1\xb1\xbf\xbf\xbf\xac\xac\xac\xa8\xa8\xa8\xa6\xa6\xa6\xbe\xbe\xbe\xa5\xa5\xa5\xb1\xb1\xb1\xeb\xeb\xeb\x96\x96\x96\xa7\xa7\xa7\xa5\xa5\xa5\xf7\xf7\xf7\xa0\xa0\xa0\xb3\xb3\xb3\x96\x96\x96\xff\xff\xff\xd1\xd1\xd1\xd6\xd6\xd6\x8c\x8c\x8c\xa0\xa0\xa0\xb9\xb9\xb9\xc7\xc7\xc7\x96\x96\x96\xa7\xa7\xa7\xb8\xb8\xb8\xdd\xdd"""+\
"""\xdd\xa3\xa3\xa3\xa5\xa5\xa5\xa9\xa9\xa9\xaa\xaa\xaa\xea\xea\xea\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc8\xc8\xc8\xb0\xb0\xb0\xdd\xdd\xdd\xce\xce\xce\xbd\xbd\xbd\xa8\xa8\xa8\xee\xee\xee\xef\xef\xef\xb1\xb1\xb1\xc6\xc6\xc6\xa7\xa7\xa7\xbf\xbf\xbf\xc4\xc4\xc4\x9c\x9c\x9c\xcb\xcb\xcb\xff\xff\xff\xb2"""+\
"""\xb2\xb2\x88\x88\x88\xe2\xe2\xe2\xa4\xa4\xa4\xc5\xc5\xc5\xff\xff\xff\xce\xce\xce\xb0\xb0\xb0\xe4\xe4\xe4\xc1\xc1\xc1\xa3\xa3\xa3\x8e\x8e\x8e\xd3\xd3\xd3\x9a\x9a\x9a\xc0\xc0\xc0\xf8\xf8\xf8\xbd\xbd\xbd\xbd\xbd\xbd\xd0\xd0\xd0\xa8\xa8\xa8\xde\xde\xde\x9c\x9c\x9c\x90\x90\x90\xff\xff\xff\xef\xef\xef\xa7\xa7\xa7\xc2\xc2\xc2\xb0\xb0\xb0\xd5\xd5\xd5\xdd\xdd\xdd\xbd\xbd\xbd\xbd\xbd\xbd\xb8\xb8\xb8\x99\x99"""+\
"""\x99\xc4\xc4\xc4\xb5\xb5\xb5\xa2\xa2\xa2\xc4\xc4\xc4\xf9\xf9\xf9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""+\
"""\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd5\xd5\xd5\xf6\xf6\xf6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xf4\xf4\xf4\xee\xee\xee\xec\xec\xec\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xf3\xf3\xf3\xf3\xf3\xf3\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xf7\xf7\xf7\xef\xef\xef\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc8\xc8\xc8\xd6\xd6\xd6\xb1\xb1\xb1\xef\xef\xef\xc6\xc6\xc6\xcb\xcb\xcb\xc8\xc8\xc8\xdc\xdc\xdc\x99\x99\x99\xc8\xc8\xc8\xd4\xd4\xd4\xc1\xc1\xc1\x87\x87\x87\xd9\xd9\xd9\xff\xff\xff\xd9\xd9\xd9\xb4\xb4\xb4\xc3\xc3\xc3\x91\x91\x91\xcc\xcc\xcc\xff\xff\xff\xd9\xd9\xd9\xf4\xf4\xf4\xd0\xd0\xd0\x7a\x7a\x7a\xf9\xf9\xf9\xd3\xd3\xd3\xd2\xd2\xd2\xb1\xb1\xb1\xde\xde\xde\x97\x97\x97\xb4\xb4\xb4\xfc\xfc\xfc\xb8\xb8\xb8\xdb\xdb\xdb\xc7\xc7\xc7\xcf\xcf\xcf\xbe\xbe\xbe\xdc\xdc\xdc\xff\xff\xff\xf1\xf1\xf1\xb7\xb7\xb7\xe4\xe4\xe4xxx\xf3\xf3\xf3\xff\xff\xff\xb7\xb7\xb7\x91\x91\x91\xe1\xe1\xe1\xb5\xb5\xb5\xdd\xdd\xdd\xc7\xc7\xc7\xbe\xbe\xbe\xd5\xd5\xd5\xcd\xcd\xcd\xc9\xc9\xc9\xc3\xc3\xc3\xd7\xd7\xd7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\x9f\x9f\x9f\xfa\xfa\xfa\xaa\xaa\xaa\xa4\xa4\xa4\xff\xff\xff\xa7\xa7\xa7\xa3\xa3\xa3\xc4\xc4\xc4\xc2\xc2\xc2\xb1\xb1\xb1\xaf\xaf\xaf\x96\x96\x96\xa8\xa8\xa8\xfe\xfe\xfe\xa7\xa7\xa7\x9d\x9d\x9d\xa8\xa8\xa8\xa7\xa7\xa7\xff\xff\xff\xff\xff\xff\xa8\xa8\xa8\xe4\xe4\xe4\xbf\xbf\xbf\xaa\xaa\xaa\xff\xff\xff\xd3\xd3\xd3\xd0\xd0\xd0\xae\xae\xae\x8d\x8d\x8d\x96\x96\x96\xde\xde\xde\xa5\xa5\xa5\xcd\xcd\xcd\xa1\xa1\xa1\x9b\x9b\x9b\xd7\xd7\xd7\x91\x91\x91\xa0\xa0\xa0\xff\xff\xff\x9e\x9e\x9e\xb6\xb6\xb6\xb5\xb5\xb5\xa7\xa7\xa7\xff\xff\xff\xd6\xd6\xd6\xcd\xcd\xcd\x96\x96\x96\xa5\xa5\xa5\xd5\xd5\xd5\xb2\xb2\xb2\xb7\xb7\xb7\xbb\xbb\xbb\xa1\xa1\xa1\x9b\x9b\x9b\xea\xea\xea\x84\x84\x84\x9b\x9b\x9b\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xbd\xbd\xbd\xbd\xbd\xbd\xff\xff\xff\xbd\xbd\xbd\xa5\xa5\xa5\xcb\xcb\xcb\xbd\xbd\xbd\xbb\xbb\xbb\x93\x93\x93\xd2\xd2\xd2\xcb\xcb\xcb\x9d\x9d\x9d\x8f\x8f\x8f\xcc\xcc\xcc\xa8\xa8\xa8\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xd1\xd1\xd1\xc5\xc5\xc5\xff\xff\xff\xc3\xc3\xc3\x9d\x9d\x9d\xd1\xd1\xd1\x9d\x9d\x9d\xf9\xf9\xf9\xde\xde\xde\xcf\xcf\xcf\x9a\x9a\x9a\x9b\x9b\x9b\xa1\xa1\xa1\x9d\x9d\x9d\xe8\xe8\xe8\xa0\xa0\xa0\xbe\xbe\xbe\xbd\xbd\xbd\xfa\xfa\xfa\xa2\xa2\xa2\xca\xca\xca\xff\xff\xff\xd6\xd6\xd6\xb0\xb0\xb0\xe0\xe0\xe0\xa4\xa4\xa4\xf2\xf2\xf2\xf7\xf7\xf7\x9b\x9b\x9b\x9a\x9a\x9a\xc5\xc5\xc5\xa0\xa0\xa0\xdb\xdb\xdb\xd4\xd4\xd4\xa1\xa1\xa1\xb7\xb7\xb7\xbd\xbd\xbd\xfe\xfe\xfe\xa3\xa3\xa3\xc4\xc4\xc4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xd0\xd0\xd0\xab\xab\xab\xc2\xc2\xc2\xd7\xd7\xd7\xce\xce\xce\xbf\xbf\xbf\xf8\xf8\xf8\xb1\xb1\xb1\xcd\xcd\xcd\xc5\xc5\xc5\xb1\xb1\xb1\xf5\xf5\xf5\xb2\xb2\xb2\xe5\xe5\xe5\xff\xff\xff\xde\xde\xde\xb3\xb3\xb3\xfb\xfb\xfb\xa7\xa7\xa7\xc8\xc8\xc8\xce\xce\xce\xab\xab\xab\xe0\xe0\xe0\xf8\xf8\xf8\xd9\xd9\xd9\xc9\xc9\xc9\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\x9d\x9d\x9d\xd7\xd7\xd7\xbf\xbf\xbf\xa7\xa7\xa7\xc7\xc7\xc7xxx\xb1\xb1\xb1\xeb\xeb\xeb\x96\x96\x96\x9d\x9d\x9d\xc3\xc3\xc3\xd8\xd8\xd8\xb0\xb0\xb0\x92\x92\x92\xff\xff\xff\xd6\xd6\xd6\x9d\x9d\x9d\xc1\xc1\xc1\xa7\xa7\xa7\xa7\xa7\xa7\xa3\xa3\xa3\x97\x97\x97\xb8\xb8\xb8\xee\xee\xee\xa6\xa6\xa6\xc2\xc2\xc2sss\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xbd\xbd\xbd\xe6\xe6\xe6\xd7\xd7\xd7\xbd\xbd\xbd\xab\xab\xab\x84\x84\x84\xdf\xdf\xdf\xa5\xa5\xa5\x93\x93\x93\xbd\xbd\xbd\xd7\xd7\xd7\xca\xca\xca\xa0\xa0\xa0\xa2\xa2\xa2\xff\xff\xff\xbe\xbe\xbe\x9c\x9c\x9c\xc9\xc9\xc9\xbd\xbd\xbd\xbd\xbd\xbd\xac\xac\xackkk\xe6\xe6\xe6\xa0\xa0\xa0\xaa\xaa\xaa\xa7\xa7\xa7\x7d\x7d\x7d\xe5\xe5\xe5\xe6\xe6\xe6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf6\xf6\xf6\xae\xae\xae\xde\xde\xde\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xef\xef\xef\xff\xff\xff\xf0\xf0\xf0\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\x97\x97\x97\xff\xff\xff\x9f\x9f\x9f\x7f\x7f\x7f\xdd\xdd\xdd\xff\xff\xff\xd4\xd4\xd4\xc6\xc6\xc6\xda\xda\xda\xb5\xb5\xb5\xe6\xe6\xe6\xc8\xc8\xc8\xc4\xc4\xc4\xb2\xb2\xb2\xb8\xb8\xb8\xe5\xe5\xe5\xff\xff\xff\xd6\xd6\xd6\xb6\xb6\xb6\xfe\xfe\xfe\xb7\xb7\xb7\x92\x92\x92\xff\xff\xff\xde\xde\xde\xb2\xb2\xb2\xc0\xc0\xc0\xc3\xc3\xc3\xc8\xc8\xc8\xdd\xdd\xdd\xb2\xb2\xb2\xc0\xc0\xc0\xc4\xc4\xc4\xc8\xc8\xc8\xdc\xdc\xdc\xb2\xb2\xb2\xc0\xc0\xc0\xc5\xc5\xc5\xff\xff\xff\xdb\xdb\xdb\xfa\xfa\xfa\xd5\xd5\xd5\xd3\xd3\xd3\xc7\xc7\xc7\xd9\xd9\xd9\xb5\xb5\xb5\xe8\xe8\xe8\xc8\xc8\xc8\xca\xca\xca\xc3\xc3\xc3\xe2\xe2\xe2\xb2\xb2\xb2\xbf\xbf\xbf\xc1\xc1\xc1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\x98\x98\x98\xff\xff\xff\x9f\x9f\x9f\xa7\xa7\xa7\xff\xff\xff\xff\xff\xff\x7f\x7f\x7f\x91\x91\x91\xa5\xa5\xa5\xf2\xf2\xf2\xa8\xa8\xa8\xa7\xa7\xa7\x9d\x9d\x9d\xaf\xaf\xaf\xe7\xe7\xe7\xa7\xa7\xa7\xff\xff\xff\xcf\xcf\xcf\x89\x89\x89\xb8\xb8\xb8\xce\xce\xce\x96\x96\x96\xff\xff\xff\xb4\xb4\xb4\xe9\xe9\xe9\x96\x96\x96\xa7\xa7\xa7\xa7\xa7\xa7\xb1\xb1\xb1\xeb\xeb\xeb\x96\x96\x96\xa7\xa7\xa7\xa7\xa7\xa7\xaf\xaf\xaf\xed\xed\xed\x97\x97\x97\xa7\xa7\xa7\xff\xff\xff\xeb\xeb\xeb\xa7\xa7\xa7\xac\xac\xac\x7e\x7e\x7e\x90\x90\x90\xa4\xa4\xa4\xf5\xf5\xf5\xa8\xa8\xa8\xa7\xa7\xa7\xc3\xc3\xc3sss\xba\xba\xba\xe1\xe1\xe1\x96\x96\x96\xa7\xa7\xa7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xcc\xcc\xcc\xac\xac\xac\xc5\xc5\xc5\xbc\xbc\xbc\xda\xda\xda\xff\xff\xff\xb5\xb5\xb5\xb0\xb0\xb0\xc0\xc0\xc0\xfd\xfd\xfd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xc8\xc8\xc8\xf5\xf5\xf5\xbd\xbd\xbd\xff\xff\xff\xb5\xb5\xb5\x90\x90\x90\xd5\xd5\xd5\x9b\x9b\x9b\x9b\x9b\x9b\xff\xff\xff\xc7\xc7\xc7\xf6\xf6\xf6\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xc5\xc5\xc5\xf8\xf8\xf8\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xc3\xc3\xc3\xfa\xfa\xfa\xbd\xbd\xbd\xbd\xbd\xbd\xff\xff\xff\xff\xff\xff\x85\x85\x85\xf4\xf4\xf4\xb4\xb4\xb4\xb2\xb2\xb2\xbd\xbd\xbd\xff\xff\xff\xbd\xbd\xbd\xbd\xbd\xbd\xa7\xa7\xa7\x7e\x7e\x7e\xcb\xcb\xcb\xf1\xf1\xf1\xbd\xbd\xbd\xbd\xbd\xbd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xeb\xeb\xeb\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe1\xe1\xe1\xb3\xb3\xb3\xe0\xe0\xe0\xdd\xdd\xdd\xd9\xd9\xd9\xc8\xc8\xc8\xdf\xdf\xdf\xb2\xb2\xb2\xff\xff\xff\xfd\xfd\xfd\xad\xad\xad\xcc\xcc\xcc\xe6\xe6\xe6\xb4\xb4\xb4\xf4\xf4\xf4\xb1\xb1\xb1\xd5\xd5\xd5xxx\xd0\xd0\xd0\xbf\xbf\xbf\xd9\xd9\xd9\xda\xda\xda\xf6\xf6\xf6\xb2\xb2\xb2\x9e\x9e\x9e\xff\xff\xff\xed\xed\xed\xb7\xb7\xb7\xeb\xeb\xeb\xdc\xdc\xdc\xcf\xcf\xcf\xd1\xd1\xd1\xc8\xc8\xc8\xd8\xd8\xd8\xbd\xbd\xbd\xcd\xcd\xcd\xc4\xc4\xc4\xc8\xc8\xc8\x87\x87\x87\xd5\xd5\xd5\xb8\xb8\xb8\xd5\xd5\xd5\x88\x88\x88\xd5\xd5\xd5\xc8\xc8\xc8\xcc\xcc\xcc\xc7\xc7\xc7\xd8\xd8\xd8\xb3\xb3\xb3\xec\xec\xec\xff\xff\xff\xd9\xd9\xd9\xee\xee\xee\xdc\xdc\xdc\xb7\xb7\xb7\xa7\xa7\xa7\xbf\xbf\xbf\xcd\xcd\xcd\xd7\xd7\xd7\xae\xae\xae\xc3\xc3\xc3\xcc\xcc\xcc\xe4\xe4\xe4\xb1\xb1\xb1\xf0\xf0\xf0\xb2\xb2\xb2\xee\xee\xee\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa3\xa3\xa3\xd4\xd4\xd4\xbb\xbb\xbb\xb1\xb1\xb1\xa6\xa6\xa6\xa7\xa7\xa7\xbf\xbf\xbf\xa5\xa5\xa5\xfe\xfe\xfe\xf9\xf9\xf9\xa3\xa3\xa3\xa8\xa8\xa8\xa5\xa5\xa5\xe6\xe6\xe6\xac\xac\xac\x94\x94\x94\xe3\xe3\xe3\xa7\xa7\xa7\x9f\x9f\x9f\xfb\xfb\xfb\xa8\xa8\xa8\xa9\xa9\xa9\xae\xae\xae\xf2\xf2\xf2\x96\x96\x96\xff\xff\xff\x98\x98\x98\xb4\xb4\xb4\xbc\xbc\xbcppp\xd4\xd4\xd4\x7d\x7d\x7d\x90\x90\x90\xa2\xa2\xa2\xf6\xf6\xf6\xa2\xa2\xa2\xff\xff\xff\xa7\xa7\xa7\xa7\xa7\xa7\xff\xff\xff\xb1\xb1\xb1\x84\x84\x84\xa7\xa7\xa7\xff\xff\xff\xa7\xa7\xa7\xa5\xa5\xa5\xa1\xa1\xa1\xa2\xa2\xa2\xfa\xfa\xfa\xa8\xa8\xa8\xff\xff\xff\xa8\xa8\xa8\xd6\xd6\xd6\xc3\xc3\xc3\xb7\xb7\xb7\xa7\xa7\xa7\xb8\xb8\xb8\x7c\x7c\x7c\xa1\xa1\xa1\xf5\xf5\xf5\x9d\x9d\x9d\xa7\xa7\xa7\xa2\xa2\xa2\xff\xff\xff\xa7\xa7\xa7\xfc\xfc\xfc\xa2\xa2\xa2\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc1\xc1\xc1\x93\x93\x93\xc2\xc2\xc2\x9b\x9b\x9b\x96\x96\x96\xbd\xbd\xbd\xd4\xd4\xd4\x9a\x9a\x9a\xf7\xf7\xf7\xfb\xfb\xfb\xc2\xc2\xc2\xbd\xbd\xbd\xca\xca\xca\xa4\xa4\xa4\xd9\xd9\xd9\xb0\xb0\xb0\xc8\xc8\xc8\xa0\xa0\xa0\xb6\xb6\xb6\xff\xff\xff\xae\xae\xae\x85\x85\x85\xe0\xe0\xe0\xa1\xa1\xa1\xa8\xa8\xa8\xff\xff\xff\xd0\xd0\xd0\xb1\xb1\xb1\xd6\xd6\xd6\xb9\xb9\xb9\xb5\xb5\xb5\xb2\xb2\xb2\xb3\xb3\xb3\xbd\xbd\xbd\xff\xff\xff\xad\xad\xad\xc3\xc3\xc3\xbd\xbd\xbd\xc5\xc5\xc5\xcf\xcf\xcf\x96\x96\x96\x90\x90\x90\xc6\xc6\xc6\xd0\xd0\xd0\xbd\xbd\xbd\xaf\xaf\xaf\xa8\xa8\xa8\xbd\xbd\xbd\xff\xff\xff\xbd\xbd\xbd\xff\xff\xff\xbe\xbe\xbe\x98\x98\x98\xd2\xd2\xd2\xc9\xc9\xc9\xbd\xbd\xbd\x9c\x9c\x9c\x87\x87\x87\xbd\xbd\xbd\xff\xff\xff\xbd\xbd\xbd\xbd\xbd\xbd\xc6\xc6\xc6\xad\xad\xad\xd6\xd6\xd6\xac\xac\xac\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf0\xf0\xf0\xdb\xdb\xdb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xf0\xf0\xf0\xf6\xf6\xf6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xe8\xe8\xe8\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\xde\xde\xde\xb3\xb3\xb3\xfb\xfb\xfb\x7a\x7a\x7a\xcd\xcd\xcd\xe8\xe8\xe8\xb3\xb3\xb3\xf5\xf5\xf5\xac\xac\xac\xb9\xb9\xb9\xe8\xe8\xe8\xb2\xb2\xb2\xf7\xf7\xf7\xff\xff\xff\xb2\xb2\xb2\xc4\xc4\xc4\xc8\xc8\xc8\xe6\xe6\xe6\xb2\xb2\xb2\xd8\xd8\xd8\xea\xea\xea\xff\xff\xff\xd9\xd9\xd9\xd9\xd9\xd9\x9e\x9e\x9e\xbf\xbf\xbf\xff\xff\xff\xdc\xdc\xdc\xb4\xb4\xb4\xf7\xf7\xf7\xae\xae\xae\xc8\xc8\xc8\xcc\xcc\xcc\xad\xad\xad\xdc\xdc\xdc\xfc\xfc\xfc\xd9\xd9\xd9\xc8\xc8\xc8\xc7\xc7\xc7\xb5\xb5\xb5\xfd\xfd\xfd\xff\xff\xff\xd0\xd0\xd0\xca\xca\xca\xd3\xd3\xd3\xe3\xe3\xe3\xea\xea\xea\xff\xff\xff\xd0\xd0\xd0\xc9\xc9\xc9\xe2\xe2\xe2\xb3\xb3\xb3\xf7\xf7\xf7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\xd6\xd6\xd6\x9d\x9d\x9d\xc1\xc1\xc1\x96\x96\x96\xa3\xa3\xa3\xa5\xa5\xa5\xef\xef\xef\xaf\xaf\xaf\xa0\xa0\xa0\xa7\xa7\xa7\xc9\xc9\xc9\xa2\xa2\xa2\xf6\xf6\xf6\xff\xff\xff\x9d\x9d\x9d\xa8\xa8\xa8\xa7\xa7\xa7\xc7\xc7\xc7\xa3\xa3\xa3\xc4\xc4\xc4\xdd\xdd\xdd\xff\xff\xff\xa8\xa8\xa8\xa6\xa6\xa6\xb2\xb2\xb2\xf5\xf5\xf5\xff\xff\xff\xd4\xd4\xd4\x96\x96\x96\xc5\xc5\xc5\xae\xae\xae\xa7\xa7\xa7\xa3\xa3\xa3\x96\x96\x96\xb0\xb0\xb0\xf7\xf7\xf7\xa6\xa6\xa6\xa7\xa7\xa7\x96\x96\x96\xd9\xd9\xd9\xca\xca\xca\xff\xff\xff\x7b\x7b\x7b\x90\x90\x90\xe9\xe9\xe9ZZZ\xff\xff\xff\xff\xff\xff\x7c\x7c\x7c\x90\x90\x90\xd8\xd8\xd8\xa7\xa7\xa7\xb4\xb4\xb4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xbd\xbd\xbd\xbe\xbe\xbe\x9c\x9c\x9c\xc9\xc9\xc9\x81\x81\x81\xab\xab\xab\xcd\xcd\xcd\xa6\xa6\xa6\xe1\xe1\xe1\xc1\xc1\xc1\xbd\xbd\xbd\xdc\xdc\xdc\xa0\xa0\xa0\xe9\xe9\xe9\xff\xff\xff\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xbd\xdb\xdb\xdb\x9f\x9f\x9f\xc7\xc7\xc7\xe6\xe6\xe6\xff\xff\xff\xa9\xa9\xa9\x88\x88\x88\xdc\xdc\xdc\xba\xba\xba\xff\xff\xff\xbb\xbb\xbb\x98\x98\x98\xcc\xcc\xcc\xc2\xc2\xc2\xbd\xbd\xbd\xa9\xa9\xa9mmm\xe2\xe2\xe2\xa2\xa2\xa2\xad\xad\xad\xbd\xbd\xbd\x88\x88\x88\x9c\x9c\x9c\xf1\xf1\xf1\xff\xff\xff\xb0\xb0\xb0\xb5\xb5\xb5\xbb\xbb\xbb\xbd\xbd\xbd\xe6\xe6\xe6\xff\xff\xff\xb1\xb1\xb1\xb4\xb4\xb4\xc2\xc2\xc2\xa2\xa2\xa2\xbf\xbf\xbf\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcb\xcb\xcb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcb\xcb\xcb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xed\xed\xed\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xdc\xdc\xdc\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xe3\xe3\xe3\xb1\xb1\xb1\xef\xef\xef\xb2\xb2\xb2\xef\xef\xef\xb4\xb4\xb4\xbc\xbc\xbc\xad\xad\xad\xf5\xf5\xf5\xad\xad\xad\xbc\xbc\xbc\xae\xae\xae\xfe\xfe\xfe\xb7\xb7\xb7\xde\xde\xde\xd4\xd4\xd4\x88\x88\x88\xe7\xe7\xe7\xb5\xb5\xb5\xe1\xe1\xe1\xff\xff\xff\xe9\xe9\xe9\xb2\xb2\xb2\xee\xee\xee\xb3\xb3\xb3\xe9\xe9\xe9\xb9\xb9\xb9\xbd\xbd\xbd\xe5\xe5\xe5\xb2\xb2\xb2\xf4\xf4\xf4\xba\xba\xba\xe5\xe5\xe5\xcf\xcf\xcf\xac\xac\xac\xe1\xe1\xe1\xf7\xf7\xf7\xd9\xd9\xd9\xca\xca\xca\xc2\xc2\xc2\xa9\xa9\xa9\xb4\xb4\xb4\xff\xff\xff\xff\xff\xff\xe0\xe0\xe0\x9e\x9e\x9e\x89\x89\x89\xe5\xe5\xe5\xe6\xe6\xe6\xd9\xd9\xd9\xc8\xc8\xc8\xd9\xd9\xd9\xb7\xb7\xb7\xff\xff\xff\xf9\xf9\xf9\xb2\xb2\xb2\xe1\xe1\xe1\xd9\xd9\xd9\xe7\xe7\xe7\xc1\xc1\xc1\x92\x92\x92\xe4\xe4\xe4\xb9\xb9\xb9\xfc\xfc\xfc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa2\xa2\xa2\xff\xff\xff\xa6\xa6\xa6\xfd\xfd\xfd\xa3\xa3\xa3\x9d\x9d\x9d\x96\x96\x96\xe1\xe1\xe1\xc1\xc1\xc1\xa2\xa2\xa2\x96\x96\x96\xc4\xc4\xc4\xb5\xb5\xb5\xd8\xd8\xd8\xa1\xa1\xa1\xa3\xa3\xa3\xab\xab\xab\xb4\xb4\xb4\xe1\xe1\xe1\xa1\xa1\xa1\xff\xff\xff\xa2\xa2\xa2\xff\xff\xff\xad\xad\xad\xf7\xf7\xf7\xa2\xa2\xa2\x9d\x9d\x9d\xa8\xa8\xa8\xc6\xc6\xc6\xa3\xa3\xa3\xb4\xb4\xb4\xa7\xa7\xa7\xa9\xa9\xa9\xa3\xa3\xa3\x9a\x9a\x9a\xb9\xb9\xb9\xeb\xeb\xeb\xa6\xa6\xa6\xc3\xc3\xc3sss\xbc\xbc\xbc\xea\xea\xea\xff\xff\xff\xff\xff\xff\xe0\xe0\xe0\xbf\xbf\xbf\xc7\xc7\xc7\xb4\xb4\xb4\xc5\xc5\xc5\xa6\xa6\xa6\xa7\xa7\xa7\xb8\xb8\xb8\xaa\xaa\xaa\xff\xff\xff\xf7\xf7\xf7\xae\xae\xae\x8f\x8f\x8f\xa8\xa8\xa8\xc5\xc5\xc5\xc4\xc4\xc4\xc8\xc8\xc8\x8f\x8f\x8f\xa7\xa7\xa7\xd3\xd3\xd3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc5\xc5\xc5\xad\xad\xad\xd6\xd6\xd6\xac\xac\xac\xd3\xd3\xd3\xbd\xbd\xbd\xbd\xbd\xbd\xee\xee\xee\xcd\xcd\xcd\xc1\xc1\xc1\xbd\xbd\xbd\xd8\xd8\xd8\xdb\xdb\xdb\xa2\xa2\xa2\xc1\xc1\xc1\xb3\xb3\xb3\x89\x89\x89\xe1\xe1\xe1\xa3\xa3\xa3\xc4\xc4\xc4\xff\xff\xff\xcb\xcb\xcb\xad\xad\xad\xdb\xdb\xdb\xa8\xa8\xa8\xcc\xcc\xcc\xbd\xbd\xbd\xbd\xbd\xbd\xda\xda\xda\x9e\x9e\x9e\xda\xda\xda\xa7\xa7\xa7\xd3\xd3\xd3\xad\xad\xadmmm\xe5\xe5\xe5\x9f\x9f\x9f\xa9\xa9\xa9\xa7\xa7\xa7\x7e\x7e\x7e\xe1\xe1\xe1\xb3\xb3\xb3\xcb\xcb\xcb\xff\xff\xff\xe8\xe8\xe8\x94\x94\x94\xa5\xa5\xa5\xfb\xfb\xfb\x98\x98\x98\x9d\x9d\x9d\xbd\xbd\xbd\xce\xce\xce\x9a\x9a\x9a\xfe\xfe\xfe\xe8\xe8\xe8\x9c\x9c\x9c\x9e\x9e\x9e\xb8\xb8\xb8\x91\x91\x91\xe1\xe1\xe1\x9f\x9f\x9f\xc7\xc7\xc7\xb0\xb0\xb0\xee\xee\xee\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xce\xce\xce\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xd6\xd6\xd6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xd2\xd2\xd2\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\xd6\xd6\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf2\xf2\xf2\xdf\xdf\xdf\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xeb\xeb\xeb\xe5\xe5\xe5\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\xd6\xd6\xe4\xe4\xe4\xff\xff\xff\xfd\xfd\xfd\xd9\xd9\xd9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xc3\xc3\xc3\xba\xba\xba\xbd\xbd\xbd\xc3\xc3\xc3\xc3\xc3\xc3\xd2\xd2\xd2\xa5\xa5\xa5\xc4\xc4\xc4\xac\xac\xac\xfe\xfe\xfe\xff\xff\xff\xa9\xa9\xa9\x7f\x7f\x7f\xd4\xd4\xd4\xaa\xaa\xaa\xe4\xe4\xe4\xab\xab\xab\xb1\xb1\xb1\xb5\xb5\xb5\xb7\xb7\xb7\xc1\xc1\xc1\xff\xff\xff\xc3\xc3\xc3\xb8\xb8\xb8\xab\xab\xab\xdf\xdf\xdf\xff\xff\xff\xa8\xa8\xa8\xcc\xcc\xcc\xac\xac\xac\xc7\xc7\xc7\xa8\xa8\xa8\xa7\xa7\xa7\xe2\xe2\xe2\x97\x97\x97\xc4\xc4\xc4\xae\xae\xae\xda\xda\xda\x85\x85\x85\xbd\xbd\xbd\xcd\xcd\xcd\xad\xad\xad\xe1\xe1\xe1\x99\x99\x99\xbe\xbe\xbe\xc7\xc7\xc7\x93\x93\x93\xcd\xcd\xcd\xac\xac\xac\xc5\xc5\xc5\xac\xac\xac\xcb\xcb\xcb\xbc\xbc\xbcxxx\xee\xee\xee\xfc\xfc\xfc\xc7\xc7\xc7\x95\x95\x95\xae\xae\xae\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\xa3\xa3\xa3\xff\xff\xff\xa8\xa8\xa8\x9e\x9e\x9e\xbd\xbd\xbd\xe6\xe6\xe6\x85\x85\x85\xaa\xaa\xaa\xee\xee\xee\xf0\xf0\xf0\xb3\xb3\xb3\x97\x97\x97\xa5\xa5\xa5\xf3\xf3\xf3\xad\xad\xad\xa9\xa9\xa9\xa8\xa8\xa8\xa2\xa2\xa2\xa3\xa3\xa3\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\xa5\xa5\xa5\xff\xff\xff\xa8\xa8\xa8\xff\xff\xff\xa3\xa3\xa3\xd7\xd7\xd7\x91\x91\x91\xb5\xb5\xb5\x97\x97\x97\xdb\xdb\xdb\xb2\xb2\xb2\xc0\xc0\xc0\x90\x90\x90\xb2\xb2\xb2\xc6\xc6\xc6\xbe\xbe\xbe\xa8\xa8\xa8\x8f\x8f\x8f\xb1\xb1\xb1\xc3\xc3\xc3\xc3\xc3\xc3\xa8\xa8\xa8\xa3\xa3\xa3\xc9\xc9\xc9\xb6\xb6\xb6\x8a\x8a\x8a\xb2\xb2\xb2\xa3\xa3\xa3\xff\xff\xff\xa7\xa7\xa7\xa8\xa8\xa8\xff\xff\xff\xfa\xfa\xfa\xad\xad\xad\xa5\xa5\xa5\xa8\xa8\xa8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xd3\xd3\xd3\xd3\xd3\xd3\xff\xff\xff\xc2\xc2\xc2\xa2\xa2\xa2\xde\xde\xde\xf5\xf5\xf5\xd2\xd2\xd2\xb0\xb0\xb0\xf9\xf9\xf9\xff\xff\xff\xb2\xb2\xb2\xae\xae\xae\xe3\xe3\xe3\xad\xad\xad\xf2\xf2\xf2\xd5\xd5\xd5\xbe\xbe\xbe\xc5\xc5\xc5\xd3\xd3\xd3\xff\xff\xff\xff\xff\xff\xd3\xd3\xd3\xd3\xd3\xd3\xff\xff\xff\xd3\xd3\xd3\xff\xff\xff\xd3\xd3\xd3\xff\xff\xff\xb3\xb3\xb3\xc9\xc9\xc9\x90\x90\x90\xa9\xa9\xa9\xec\xec\xec\xe2\xe2\xe2\xde\xde\xde\xb0\xb0\xb0\xe3\xe3\xe3\xe0\xe0\xe0\xd3\xd3\xd3\xdd\xdd\xdd\xb0\xb0\xb0\xe1\xe1\xe1\xe3\xe3\xe3\xd3\xd3\xd3\xd3\xd3\xd3\xa5\xa5\xa5\xe7\xe7\xe7\xb6\xb6\xb6\xc6\xc6\xc6\xd3\xd3\xd3\xff\xff\xff\xd3\xd3\xd3\xbf\xbf\xbf\xec\xec\xec\xfd\xfd\xfd\xd6\xd6\xd6\xd3\xd3\xd3\xd3\xd3\xd3\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe1\xe1\xe1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe4\xe4\xe4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xe4\xe4\xe4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd1\xd1\xd1\xd6\xd6\xd6\xeb\xeb\xeb\xf8\xf8\xf8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xd6\xd6\xd6\xd1\xd1\xd1\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xbd\xbd\xbd\xe2\xe2\xe2\xcf\xcf\xcf\xaa\xaa\xaa\xca\xca\xca\xa7\xa7\xa7\xc3\xc3\xc3\xdc\xdc\xdc\xd6\xd6\xd6\x97\x97\x97\xc0\xc0\xc0\x83\x83\x83\xda\xda\xda\xb3\xb3\xb3\xc4\xc4\xc4\x83\x83\x83\xd9\xd9\xd9\xae\xae\xae\xc1\xc1\xc1\xff\xff\xff\xc1\xc1\xc1\xfb\xfb\xfb\xbe\xbe\xbe\xb4\xb4\xb4\xbb\xbb\xbb\xa7\xa7\xa7\xc3\xc3\xc3\xaa\xaa\xaa\xb3\xb3\xb3\xff\xff\xff\xd8\xd8\xd8\xb5\xb5\xb5\xdc\xdc\xdc\xa1\xa1\xa1\xdd\xdd\xdd\xa2\xa2\xa2\xd8\xd8\xd8\xbc\xbc\xbc\xb3\xb3\xb3\xff\xff\xff\xfb\xfb\xfb\xa6\xa6\xa6\xd9\xd9\xd9\xc3\xc3\xc3\xa7\xa7\xa7\xa7\xa7\xa7\xc3\xc3\xc3\xe7\xe7\xe7\xd5\xd5\xd5\x93\x93\x93\x99\x99\x99\x9b\x9b\x9b\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xaf\xaf\xaf\x91\x91\x91\xbe\xbe\xbe\xe5\xe5\xe5\xa2\xa2\xa2\xa7\xa7\xa7\xa8\xa8\xa8\xc3\xc3\xc3\xc4\xc4\xc4\xb2\xb2\xb2\xa3\xa3\xa3\xa8\xa8\xa8\xf7\xf7\xf7\x9f\x9f\x9f\x7e\x7e\x7e\xa8\xa8\xa8\xee\xee\xee\x81\x81\x81\xae\xae\xae\xff\xff\xff\xe6\xe6\xe6\x80\x80\x80\xd4\xd4\xd4\x7a\x7a\x7a\xa8\xa8\xa8\xa7\xa7\xa7\xa7\xa7\xa7\xc0\xc0\xc0\xe7\xe7\xe7\xff\xff\xff\x99\x99\x99\xb7\xb7\xb7\xca\xca\xca\xa2\xa2\xa2\xc2\xc2\xc2\xa7\xa7\xa7\xbb\xbb\xbb\x7d\x7d\x7d\xa5\xa5\xa5\xfb\xfb\xfb\xd7\xd7\xd7\xca\xca\xca\xff\xff\xff\xa7\xa7\xa7\xa7\xa7\xa7\xa7\xa7\xa7\xa8\xa8\xa8\xd3\xd3\xd3\xc2\xc2\xc2\xb0\xb0\xb0\xa3\xa3\xa3\xc3\xc3\xc3\xe4\xe4\xe4\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xf6\xf6\xf6\xb3\xb3\xb3\xf9\xf9\xf9\xae\xae\xae\xdc\xdc\xdc\xd3\xd3\xd3\xd0\xd0\xd0\xa7\xa7\xa7\xd4\xd4\xd4\x83\x83\x83\xcc\xcc\xcc\xd6\xd6\xd6\xd4\xd4\xd4\xa6\xa6\xa6\xb6\xb6\xb6\xd6\xd6\xd6\xd5\xd5\xd5\xba\xba\xba\xc2\xc2\xc2\xff\xff\xff\xff\xff\xff\xaa\xaa\xaa\xff\xff\xff\xc1\xc1\xc1\xbb\xbb\xbb\xd3\xd3\xd3\xd3\xd3\xd3\xf2\xf2\xf2\xba\xba\xba\xff\xff\xff\xe8\xe8\xe8\xb0\xb0\xb0\xda\xda\xda\xb0\xb0\xb0\xd6\xd6\xd6\xb0\xb0\xb0\xd3\xd3\xd3\xca\xca\xca\xb2\xb2\xb2\xff\xff\xff\xff\xff\xff\xae\xae\xae\xda\xda\xda\xd3\xd3\xd3\xd3\xd3\xd3\xd3\xd3\xd3\xd5\xd5\xd5\xaa\xaa\xaa\xe1\xe1\xe1\xd9\xd9\xd9\xd3\xd3\xd3\xe2\xe2\xe2\xf1\xf1\xf1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf6\xf6\xf6\xeb\xeb\xeb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf2\xf2\xf2\xdf\xdf\xdf\xff\xff\xff\xff\xff\xff\xd1\xd1\xd1\xd1\xd1\xd1\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xcb\xcb\xcb\x9b\x9b\x9b\xc2\xc2\xc2\xaa\xaa\xaa\xbc\xbc\xbc\xa7\xa7\xa7\xa7\xa7\xa7\xdb\xdb\xdb\xaf\xaf\xaf\xdb\xdb\xdb\x92\x92\x92\xc6\xc6\xc6\xb6\xb6\xb6\xdb\xdb\xdb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xa3\xa3\xa3\xd5\xd5\xd5\xb3\xb3\xb3\xba\xba\xba\xa2\xa2\xa2\xa7\xa7\xa7\xa7\xa7\xa7\xa5\xa5\xa5\xff\xff\xff\xa3\xa3\xa3\xa3\xa3\xa3\x9e\x9e\x9e\xb7\xb7\xb7\xc8\xc8\xc8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xd8\xd8\xd8\xa7\xa7\xa7\xe1\xe1\xe1\xb6\xb6\xb6\xcd\xcd\xcd\xd3\xd3\xd3\xd3\xd3\xd3\xeb\xeb\xeb\xad\xad\xad\xeb\xeb\xeb\xd3\xd3\xd3\xed\xed\xed\xb0\xb0\xb0\xdf\xdf\xdf\xcb\xcb\xcb\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc1\xc1\xc1\xb8\xb8\xb8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xc2\xc2\xc2\xd8\xd8\xd8\xe5\xe5\xe5\xa7\xa7\xa7\xc9\xc9\xc9\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x9f\x9f\x9f\xa8\xa8\xa8\xc5\xc5\xc5\xa5\xa5\xa5\xf4\xf4\xf4\xa4\xa4\xa4\x9f\x9f\x9f\xd2\xd2\xd2\xb0\xb0\xb0\xec\xec\xec\xff\xff\xff\xf3\xf3\xf3\x9f\x9f\x9f\xff\xff\xff\xdf\xdf\xdf\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x85\x85\x85\xc0\xc0\xc0\xbd\xbd\xbd\x91\x91\x91\xb0\xb0\xb0\xbf\xbf\xbf\x96\x96\x96\x94\x94\x94\xb5\xb5\xb5\xd5\xd5\xd5\xff\xff\xff\xf8\xf8\xf8\x9f\x9f\x9f\xff\xff\xff\x97\x97\x97\xfc\xfc\xfc\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xcf\xcf\xcf\xff\xff\xff\xd0\xd0\xd0\xa8\xa8\xa8\xe1\xe1\xe1\xae\xae\xae\x86\x86\x86\xe2\xe2\xe2\xb0\xb0\xb0\xe9\xe9\xe9\xff\xff\xff\xc5\xc5\xc5\x98\x98\x98\xff\xff\xff\xc8\xc8\xc8\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x0d\x0d\x0d\x84\x84\x84\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\x85\x85\x85\xa9\xa9\xa9\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\xb7\x84\x84\x84\x0d\x0d\x0d\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff"""

motionpaper_width=100
motionpaper_height=69
motionpaper_data="""\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xf9\xf9\xf9\xf5\xf6\xf6\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xf8\xf9\xf9\xf7\xf7\xf7\xfb\xfb\xfb\xf6\xf7\xf7\xfd\xfd\xfd\xf8"""+\
"""\xf8\xf8\xf8\xf9\xf9\xfb\xfc\xfb\xf6\xf7\xf7\xf4\xf5\xf5\xfe\xfe\xfe\xf8\xf8\xf8\xf9\xf9\xf9\xfc\xfc\xfc\xf5\xf6\xf6\xf5\xf6\xf6\xfc\xfc\xfc\xf5\xf6\xf6\xfa\xfb\xfb\xfb\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xf6\xf7\xf7\xf8\xf9\xf9\xf7\xf7\xf7\xfa\xfa\xfa\xf5\xf6\xf6\xfb\xfc\xfc\xfa\xfb\xfa\xfb\xfb\xfb\xfb\xfc\xfc\xfb\xfb\xfb\xf6\xf7\xf7\xf9\xf9\xf9\xf3\xf4\xf4\xf4\xf5\xf5\xf4\xf5\xf5\xf4\xf5\xf5\xf3\xf4"""+\
"""\xf4\xf3\xf4\xf4\xf4\xf5\xf5\xf4\xf5\xf5\xf4\xf5\xf5\xf4\xf5\xf5\xf4\xf5\xf5\xf4\xf5\xf5\xf3\xf4\xf4\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf9\xf9\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb"""+\
"""\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xee\xee\xee\xf1\xf1\xf1\xe5\xe5\xe5\xe7\xe8\xe7\xe3\xe4\xe4\xed\xed\xed\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xcc\xcc\xcc\xe6"""+\
"""\xe7\xe7\xea\xea\xea\xe4\xe4\xe4\xee\xef\xef\xec\xec\xec\xb0\xb0\xb0\xdd\xdd\xdd\xed\xee\xed\xe6\xe7\xe6\xee\xef\xef\xe8\xe9\xe9\xdb\xdb\xdb\xf4\xf4\xf4\xe5\xe5\xe5\xe4\xe5\xe5\xe6\xe7\xe6\xe5\xe5\xe5\xef\xef\xef\xec\xed\xed\xeb\xeb\xeb\xe1\xe1\xe1\xf1\xf1\xf1\xe4\xe4\xe4\xe8\xe9\xe9\xe6\xe6\xe6\xe6\xe6\xe6\xe5\xe6\xe6\xee\xee\xee\xed\xee\xee\xf9\xfa\xfa\xfa\xfb\xfb\xf9\xfa\xfa\xfa\xfb\xfb\xf9\xfa"""+\
"""\xfa\xf9\xfa\xfa\xfa\xfb\xfb\xfa\xfb\xfb\xfa\xfb\xfb\xfa\xfb\xfb\xf9\xfa\xfa\xf9\xfa\xfa\xfb\xfc\xfc\xd6\xd6\xd6\xdd\xde\xdd\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2"""+\
"""\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe0\xe0\xe0\xe2\xe2\xe2\xd9\xd9\xd9\xd5\xd6\xd5\xc6\xc7\xc7\xc7\xc7\xc7\xc3\xc3\xc3\xcd\xcd\xcd\xd7\xd8\xd7\xde\xde\xde\xd3\xd4\xd3\x97\x97\x97\xbf"""+\
"""\xc0\xbf\xd2\xd2\xd2\xc5\xc5\xc5\xd1\xd2\xd2\xc9\xca\xc9\x98\x98\x98\xbd\xbd\xbd\xd0\xd1\xd0\xc4\xc4\xc4\xd0\xd1\xd0\xcd\xce\xcd\xbf\xbf\xbf\xd3\xd4\xd3\xc8\xc8\xc8\xc4\xc4\xc4\xc6\xc6\xc6\xc4\xc4\xc4\xd3\xd4\xd3\xd5\xd6\xd6\xcd\xcd\xcd\xbe\xbe\xbe\xd5\xd6\xd5\xc6\xc6\xc6\xc7\xc7\xc7\xc6\xc6\xc6\xc5\xc5\xc5\xc6\xc6\xc6\xd1\xd2\xd2\xe0\xe0\xe0\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe"""+\
"""\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xb6\xb7\xb6\xbc\xbd\xbc\xde\xdf\xdf\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1"""+\
"""\xbe\xbe\xbe\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbe\xbe\xbe\xbd\xbd\xbd\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbe\xbe\xbe\xbe\xbe\xbe\xbd\xbd\xbd\xbd\xbd\xbd\xbe\xbe\xbe\xbc\xbc\xbc\xb6\xb6\xb6\xba\xba\xba\xb9\xba\xba\xba\xba\xba\xb8\xb8\xb8\xb8\xb8\xb8\xbe\xbe\xbe\xb7\xb8\xb8\xbe\xbe\xbe\xb9"""+\
"""\xb9\xb9\xb8\xb8\xb8\xba\xba\xba\xb6\xb6\xb6\xb5\xb5\xb5\xbd\xbd\xbd\xb9\xb9\xb9\xb8\xb8\xb8\xba\xba\xba\xb5\xb5\xb5\xb5\xb5\xb5\xb9\xb9\xb9\xb5\xb5\xb5\xb9\xba\xb9\xba\xba\xba\xba\xba\xba\xba\xba\xba\xb7\xb7\xb7\xbb\xbb\xbb\xb7\xb7\xb7\xb7\xb8\xb8\xb6\xb6\xb6\xba\xba\xba\xb9\xb9\xb9\xba\xba\xba\xba\xba\xba\xba\xba\xba\xb7\xb7\xb7\xbd\xbd\xbd\xc0\xc0\xc0\xbf\xbf\xbf\xbf\xbf\xbf\xc0\xc0\xc0\xbf\xbf"""+\
"""\xbf\xbf\xbf\xbf\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xc0\xbf\xbf\xbf\xc0\xc0\xc0\xbe\xbe\xbe\xbc\xbc\xbc\xba\xba\xba\xbb\xbb\xbb\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbe\xbe\xbe\xbd\xbd\xbd\xbd\xbd\xbd\xbe\xbe\xbe\xbd\xbd\xbd\xbd\xbd\xbd\xbe\xbe\xbe\xbe\xbe\xbe\xbd\xbd\xbd\xbe\xbe\xbe\xbe\xbe\xbe"""+\
"""\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xdf\xdf\xdf\xe1\xe1\xe1\xe0\xe0\xe0\xe1"""+\
"""\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe2\xe2\xe2\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe2\xe2\xe2\xe2\xe2\xe2\xe1\xe1\xe1\xe2\xe2\xe2\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe1\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf"""+\
"""\xdf\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xe1\xe1\xe1\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xdf\xdf\xdf\xe0\xe0\xe0\xdf\xdf\xdf\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0\xdf\xdf\xdf\xe0\xe0\xe0\xe0\xe0\xe0"""+\
"""\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf4\xf4\xf4\xf5"""+\
"""\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5"""+\
"""\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6"""+\
"""\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1"""+\
"""\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0"""+\
"""\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xee\xee\xee\xef\xef\xef\xee\xee\xee\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1"""+\
"""\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xee\xef\xef\xee\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xef\xf0\xef\xef\xef\xef\xef"""+\
"""\xf0\xf0\xee\xef\xef\xef\xef\xef\xee\xf0\xf0\xef\xef\xef\xee\xef\xef\xef\xef\xef\xf0\xef\xef\xef\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf2\xf2\xf2\xf4\xf4\xf4\xf3\xf3\xf3\xf2\xf2\xf2\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0\xef\xf0\xf0\xf0\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xee\xef"""+\
"""\xef\xef\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xee\xef\xef\xef\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xef\xf0\xf0\xef\xef\xef\xef\xf0\xf0\xee\xef\xef\xf0\xf0\xf0\xf1\xf1\xf1\xf3\xf3\xf3\xf4\xf4\xf4\xf6\xf6\xf6\xf7\xf7\xf7\xf9\xf9\xf9\xfb\xfb\xfb\xfb\xfa\xfa\xf5\xf5\xf5\xf8\xf8\xf8\xef\xef\xef\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1"""+\
"""\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xee\xee\xee\xdb\xdc\xdb\xe0\xe1\xe0\xe6\xe6\xe6\xe5\xe5\xe5\xe5\xe5\xe5\xe5\xe6\xe6\xe6\xe6\xe6\xe5\xe5\xe5\xe5\xe6\xe6\xe5\xe5\xe5\xe5\xe6\xe5\xe5\xe6\xe6\xe6\xe6\xe6\xe6\xe6\xe6\xe5\xe6\xe5\xe5\xe6\xe6\xe6\xe6\xe6\xe5\xe6\xe5\xe6\xe6\xe6\xe5\xe6\xe5\xe5\xe5\xe5\xe6\xe6\xe6\xe6\xe6\xe6\xe5\xe6\xe6\xe5\xe6\xe5\xe6\xe6\xe6\xe6"""+\
"""\xe6\xe6\xe6\xe7\xe6\xe7\xe7\xe7\xe6\xe6\xe6\xe6\xe6\xe6\xe7\xe7\xe7\xe6\xe6\xe6\xe4\xe4\xe4\xe2\xe3\xe2\xe1\xe2\xe2\xe0\xe1\xe1\xe0\xdf\xe0\xe1\xe1\xe2\xe2\xe3\xe2\xe3\xe4\xe3\xe4\xe5\xe5\xea\xeb\xea\xd6\xd6\xd6\xc3\xc4\xc3\xcb\xcc\xcc\xcf\xd0\xcf\xd3\xd4\xd3\xd6\xd6\xd6\xdb\xda\xdb\xdd\xde\xde\xdf\xe0\xe0\xe1\xe2\xe2\xe3\xe4\xe4\xe5\xe6\xe5\xe6\xe6\xe6\xe6\xe7\xe7\xe7\xe7\xe7\xe6\xe7\xe6\xe6\xe6"""+\
"""\xe7\xe6\xe7\xe6\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe6\xe6\xe6\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe7\xe6\xe6\xe6\xe6\xe6\xe6\xe7\xe7\xe7\xe6\xe6\xe6\xe5\xe6\xe5\xe5\xe6\xe5\xe5\xe5\xe5\xe6\xe6\xe6\xe1\xe1\xe1\xd4\xd5\xd5\xc9\xc9\xc9\xbd\xbe\xbd\xb2\xb2\xb2\xa6\xa7\xa7\x9b\x9c\x9c\x8c\x8c\x8c\x8e\x8e\x8e\xbb\xbc\xbc\xa9\xa9\xa9\xfb\xfb\xfb\xee\xee\xee\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1"""+\
"""\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xef\xef\xef\xe3\xe2\xe1\xf1\xf0\xf1\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xfe\xff\xfe\xfe\xfe\xff\xfe\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xfe\xff\xff\xfe\xff\xfe\xfe\xfe\xff\xfe\xff\xfe\xfe\xfe\xff\xfe\xff\xfe\xfe\xfe\xff\xfe\xff\xfe\xff\xfe\xff\xfe\xff\xff\xfe\xff\xfe\xfe\xfe\xff\xfe\xfe\xff\xfe\xff\xfe\xfe\xfe\xff"""+\
"""\xff\xff\xfe\xfe\xfe\xfe\xfd\xfe\xff\xfe\xff\xfe\xfd\xfe\xff\xfe\xff\xfe\xfd\xfe\xfb\xf9\xfa\xf7\xf6\xf7\xf4\xf3\xf4\xf5\xf3\xf5\xf8\xfe\xf9\xf1\xf7\xf2\xf4\xf1\xf3\xf6\xf5\xf6\xf7\xf5\xf6\xff\xff\xff\xdb\xda\xdb\xba\xb8\xb9\xc9\xc8\xc9\xd0\xcf\xd0\xd9\xd7\xd9\xe3\xe9\xe4\xe3\xea\xe4\xeb\xe8\xea\xf0\xee\xf0\xf4\xf3\xf4\xf7\xf6\xf7\xfb\xf9\xfa\xfd\xfb\xfc\xfe\xfd\xfe\xff\xfe\xff\xfe\xfd\xfe\xfe\xfd"""+\
"""\xfe\xfe\xfd\xfe\xff\xfe\xff\xff\xfe\xff\xff\xfe\xff\xff\xfe\xff\xfe\xfd\xfe\xff\xfe\xff\xff\xfe\xff\xff\xfe\xff\xfe\xfd\xfe\xff\xfe\xff\xff\xfd\xff\xff\xfe\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf7\xf6\xf7\xdf\xde\xdf\xc7\xc6\xc7\xaf\xaf\xaf\x96\x96\x96\x7d\x7c\x7dhgh?>?\xa2\xa2\xa2\x7c\x7c\x7chhh\xff\xff\xff\xed\xed\xed\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1"""+\
"""\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xee\xee\xee\xe6\xe5\xe5\xf0\xf0\xf0\xdd\xe2\xde\xd6\xdd\xd7\xd6\xdc\xd6\xe4\xea\xe5\xe7\xea\xe7\xd5\xda\xd6\xdb\xe2\xdc\xd5\xdb\xd6\xda\xe0\xdb\xdf\xe4\xe0\xf9\xfd\xfa\xed\xf2\xee\xdd\xe4\xde\xe5\xec\xe6\xe4\xeb\xe5\xdb\xe1\xdb\xe5\xec\xe6\xd9\xe1\xda\xd2\xda\xd3\xe1\xe7\xe2\xe8\xef\xe9\xe1\xe8\xe2\xdd\xe4\xdd\xf8\xfa\xf8\xe6"""+\
"""\xf7\xe4\xe8\xf7\xe7\xff\xff\xff\xfd\xfe\xfe\xfd\xfe\xfe\xfe\xfe\xff\xfd\xfe\xfe\xf9\xff\xfb\xf5\xfd\xf7\xf9\xff\xfb\xdb\xed\xde\x84Q\x7a\xd9\x82\xca\xef\xff\xf3\xf5\xfb\xf7\xf5\xfd\xf7\xff\xff\xff\xdc\xe0\xdd\xbd\xc4\xbe\xcb\xd2\xcc\xd6\xdc\xd7\xc8\xd8\xca\x7cQs\xccx\xbd\xe8\xf7\xea\xf1\xf6\xf2\xf4\xfa\xf5\xf7\xfe\xf8\xfa\xff\xfb\xfc\xfe\xfe\xfd\xff\xfe\xfe\xff\xff\xfe\xff\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfe\xfe\xfe\xff\xff\xfe\xff\xff\xfe\xff\xff\xfe\xff\xff\xfe\xfe\xfe\xfe\xff\xff\xfe\xff\xff\xfe\xff\xff\xfe\xfe\xfe\xfd\xfe\xfe\xff\xff\xff\xec\xf0\xed\xd6\xde\xd7\xd6\xdd\xd7\xdb\xe1\xdc\xe9\xee\xea\xc9\xcf\xca\xb3\xb9\xb4\xa2\xa7\xa3\x8d\x92\x8e\x80\x83\x80v\x79wX]Wpro\xf4\xf3\xf3222ttt\xff\xff\xff\xec\xec\xec\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0"""+\
"""\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xee\xee\xee\xef\xef\xef\xd9\xda\xd8\xe4\xd4\xe1\xc5\xa3\xbe\xbe\x9c\xb7\xb7\x95\xb0\xcb\xaa\xc5\xcc\xae\xc6\xb8\x98\xb1\xc6\xa2\xc0\xc0\x9d\xb9\xbe\x9e\xb8\xc1\x9e\xba\xe9\xc8\xe3\xdf\xbc\xd8\xc1\x9d\xba\xc8\xa4\xc1\xc2\x9e\xbb\xbd\x99\xb6\xc2\x9e\xbb\xc5\xa1\xbe\xbf\x9b\xb8\xbd\x98\xb5\xca\xa6\xc3\xc4\xa0\xbd\xc8\xa2\xc1\xd5\xbb\xcc\xdb"""+\
"""\xc6\xd1\xfe\xda\xf8\xfd\xda\xf7\xfd\xda\xf7\xfd\xda\xf7\xfe\xdb\xf8\xfd\xd9\xf7\xf9\xd6\xf3\xf5\xd3\xef\xf8\xd4\xf1\xe1\xc8\xdc\xa4X\x95\xdf\x79\xce\xf0\xd8\xec\xf5\xd5\xf0\xf5\xd8\xf0\xff\xe2\xfa\xdc\xc2\xd8\xbc\xa2\xb8\xca\xaf\xc6\xd4\xb7\xd0\xcb\xb6\xc7\x97U\x8b\xd0o\xbf\xe5\xce\xe1\xec\xce\xe7\xef\xd2\xea\xf4\xd5\xef\xf8\xd7\xf2\xf8\xd8\xf3\xfc\xd9\xf6\xfc\xda\xf6\xfc\xd9\xf6\xfb\xda"""+\
"""\xf5\xfb\xda\xf5\xfb\xda\xf6\xfd\xda\xf7\xfd\xda\xf7\xfb\xda\xf6\xf8\xdb\xf3\xfb\xdb\xf5\xfb\xdb\xf6\xfc\xda\xf7\xfc\xda\xf6\xfc\xd9\xf6\xff\xdf\xfc\xdf\xbc\xd9\xbe\x9c\xb7\xbd\x9b\xb6\xbc\x9c\xb5\xd1\xb0\xcb\xa7\x8c\xa2\x99\x7d\x94\x8as\x86wariXfSGOVRR\xcb\xca\xcb\xc4\xc4\xc4\x00\x00\x00\x7f\x7f\x7f\xff\xff\xff\xeb\xeb\xeb\xee\xee\xee\xef\xef\xef\xef\xef\xef"""+\
"""\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xef\xef\xef\xf2\xef\xf1\xd2\xe0\xd3\xe0\x7f\xcf\xd9$\xba\xd41\xb8\xd14\xb6\xcf1\xb4\xd1-\xb4\xd9/\xbc\xd71\xba\xd32\xb7\xd31\xb7\xca-\xb0\xc5+\xaa\xe5)\xc8\xff*\xe6\xfe)\xe1\xfe)\xe2\xfe+\xe4\xfe*\xe3\xff*\xe3\xff,\xe4\xfe+\xe4\xfe%\xde\xfe$\xdd\xfe%\xde\xfa\x1d\xd5\xfe"""+\
"""\x1f\xda\xfc\x1d\xd6\xfc\x1d\xd6\xfc\x1d\xd6\xfd\x1e\xd7\xfc\x1d\xd6\xfd\x1f\xd8\xfb\x1f\xd5\xf7 \xd2\xf5\x22\xd1\xf6%\xd3\xf96\xd8\xf03\xd0\xf1,\xcf\xf23\xd1\xf47\xd3\xfdD\xdd\xda9\xbf\xbb\x13\x9e\xc8\x1d\xac\xd2\x1f\xb4\xc8(\xad\xb4D\xa0\xb7@\xa2\xba5\xa3\xc56\xac\xc36\xaa\xc25\xa9\xd12\xb6\xca1\xaf\xcd.\xb1\xc1+\xa7\xc4'\xa9\xc9&"""+\
"""\xac\xc5&\xa9\xd0$\xb2\xbe%\xa3\xc4%\xa8\xd1#\xb3\xc2$\xa6\xc0$\xa4\xc5#\xa8\xd2\x22\xb4\xc3$\xa7\xd2\x22\xb3\xc5\x22\xa9\xc6(\xaa\xcc,\xb0\xd4,\xb8\xcb-\xaf\xbd&\xa3\xaf&\x97\xa7!\x90\x91\x1d\x7c\x7d\x1alm\x16^O\x0bC\xa2\x90\x9f\xec\xee\xeb\x8a\x89\x89\x00\x00\x00\x87\x87\x87\xff\xff\xff\xec\xec\xec\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0"""+\
"""\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xef\xef\xef\xf2\xf1\xf2\xd2\xd2\xd1\xdf\xd7\xdd\xf0\xdf\xed\xef\xe0\xec\xe4\xd4\xe1\xe1\xd2\xde\xed\xdc\xea\xf2\xe2\xef\xe1\xd3\xde\xe4\xd5\xe1\xe7\xd6\xe4\xf5\xe7\xf3\xe8\xd9\xe5\xe7\xd8\xe4\xe8\xd7\xe5\xe8\xd7\xe5\xeb\xd9\xe7\xe6\xd5\xe3\xe6\xd5\xe3\xe8\xd7\xe4\xe4\xd2\xe0\xe6\xd5\xe2\xf8\xe8\xf5\xfd\xec\xfa\xfc\xeb\xf9\xfd\xed\xfb\xfd"""+\
"""\xed\xfa\xfe\xee\xfb\xfb\xeb\xf8\xfd\xec\xfa\xf7\xe7\xf4\xfd\xec\xfa\xef\xde\xec\xe9\xd8\xe6\xe6\xd6\xe3\xe3\xd3\xe0\xe2\xd3\xe0\xee\xdd\xeb\xf1\xe0\xee\xf1\xe3\xef\xf5\xe7\xf3\xf5\xe7\xf3\xff\xf1\xfd\xdc\xd0\xda\xbc\xb0\xba\xcb\xbe\xc9\xd2\xc6\xd0\xd7\xc2\xd4\xd8\xab\xd0\xe3\xb0\xda\xeb\xb9\xe3\xf0\xbe\xe8\xf2\xc3\xea\xf7\xc9\xef\xf9\xcd\xf2\xfc\xd1\xf5\xfd\xd4\xf6\xfe\xd7\xf7\xfe\xdb\xfa\xfe\xdc"""+\
"""\xfa\xfd\xdf\xf9\xfd\xe2\xfa\xfe\xe6\xfb\xfd\xe7\xf9\xfb\xe7\xf7\xfd\xe9\xfa\xfc\xec\xf9\xfb\xec\xf8\xfb\xed\xf8\xfc\xed\xfa\xfc\xed\xf9\xfb\xee\xf9\xf9\xec\xf7\xfa\xeb\xf7\xfb\xeb\xf9\xf9\xe9\xf7\xe6\xd8\xe3\xd1\xc3\xce\xba\xaf\xb8\xa5\x9b\xa3\x91\x88\x8fskq\x92\x8d\x91\xcc\xce\xcc\xe9\xe8\xe8MMM\x00\x00\x00\x89\x89\x89\xff\xff\xff\xec\xec\xec\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0"""+\
"""\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xef\xef\xef\xed\xed\xed\xe5\xe4\xe4\xef\xf0\xef\xde\xe1\xde\xe2\xe3\xe2\xdd\xe1\xdd\xd8\xdc\xd8\xe4\xe6\xe3\xe5\xe7\xe5\xdd\xe0\xdd\xdb\xde\xdb\xdd\xe1\xdd\xed\xed\xed\xde\xe1\xde\xdc\xdf\xdb\xdc\xe0\xdc\xdb\xdf\xdb\xdd\xe0\xdd\xde\xe2\xde\xdb\xdf\xdb\xda\xde\xda\xd8\xdc\xd8\xd9\xdd\xd9\xf5\xf6\xf5\xff\xff\xff\xfe\xfe\xfe\xfe\xff\xff\xfe"""+\
"""\xfe\xfe\xff\xff\xff\xee\xee\xee\xfa\xfa\xfa\xcb\xcd\xca\xfc\xfc\xfc\xe3\xe6\xe2\xd6\xd9\xd5\xce\xd2\xce\xce\xd1\xcd\xd6\xd9\xd6\xf4\xf8\xf4\xf2\xf6\xf3\xe9\xed\xe9\xf7\xfb\xf7\xf6\xf9\xf6\xff\xff\xff\xdd\xde\xdd\xbd\xc0\xbd\xcc\xcd\xcc\xd2\xe0\xd4\xd8\xa7\xd0\xd29\xb8\xd8.\xba\xbe,\xa4\xca8\xb0\xdbD\xc0\xc3I\xad\xcfT\xb9\xd5_\xc0\xd0f\xbd\xcal\xb8\xc7s\xb7\xd2\x85"""+\
"""\xc3\xd3\x91\xc6\xcb\x96\xc1\xc1\x9a\xb9\xda\xb8\xd3\xff\xea\xff\xfe\xf8\xfe\xfe\xff\xfe\xff\xfe\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xfe\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xff\xff\xff\xf9\xfb\xf9\xe3\xe7\xe3\xcd\xd0\xcd\xb7\xba\xb7\xa1\xa4\xa2\x86\x89\x87\x86\x89\x87\xc1\xc2\xc1\xc7\xc6\xc6\xcf\xcf\xcf\x15\x15\x15\x05\x05\x05\x89\x89\x89\xfd\xfd\xfe\xeb\xeb\xeb\xee\xee\xee\xef\xef\xef\xef\xef\xef"""+\
"""\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xec\xec\xe6\xe5\xe5\xf4\xf4\xf4\xf9\xf8\xf9\xee\xed\xee\xff\xff\xff\xff\xff\xff\xf7\xf6\xf7\xef\xee\xee\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xf0\xef\xef\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfd\xfe\xfd\xfc\xfd\xfe\xfd\xfe\xfe\xfd\xfe\xfd"""+\
"""\xfc\xfd\xff\xff\xff\xe6\xe5\xe6\xd5\xd4\xd4\xd0\xce\xcf\xde\xe1\xe0\xd2\xd7\xd7\xf2\xf3\xf4\xf9\xf8\xf9\xea\xeb\xec\xc8\xcd\xcc\xdf\xe1\xe1\xd6\xd5\xd5\xe7\xe7\xe7\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xca\xcb\xd1\xd4\xd2\xd8\xcc\xd6\xc2\x95\xba\xba\x8f\xb2\xc4\x9d\xbd\xcb\xa4\xc4\xc6\x9f\xbf\xcc\xaa\xc5\xc7\xa6\xc0\xd3\xb4\xcd\xce\xb1\xc8\xd2\xb8\xcd\xcf\xba\xcb\xcc\xb7"""+\
"""\xc8\xcd\xba\xc9\xd2\xc3\xce\xce\xc3\xcc\xdb\xd0\xd8\xe1\xd8\xde\xda\xd6\xd9\xdf\xde\xdf\xd5\xd3\xd4\xea\xe9\xe9\xff\xff\xff\xfe\xfd\xfe\xfd\xfd\xfd\xfa\xf9\xfa\xfa\xf9\xfa\xfb\xfa\xfb\xed\xec\xed\xd7\xd6\xd7\xc2\xc1\xc2\xad\xac\xad\x98\x97\x98\x83\x83\x83\xb8\xb8\xb8\xb2\xb1\xb1\xe1\xe2\xe2\x98\x98\x98\x00\x00\x00\x0f\x0f\x0f\x8a\x8a\x8a\xfc\xfc\xfc\xea\xea\xea\xed\xed\xed\xee\xee\xee\xee\xee\xee"""+\
"""\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xee\xee\xee\xf0\xf0\xf0\xd6\xd4\xd4\xe8\xe8\xe8\xfa\xfa\xfa\xed\xed\xed\xff\xff\xff\xfe\xfe\xfe\xf6\xf6\xf6\xee\xee\xee\xff\xff\xff\xfa\xfa\xfa\xfd\xfd\xfd\xf0\xef\xef\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd"""+\
"""\xfd\xfd\xff\xff\xff\xe3\xe2\xe2\xcc\xcc\xcc\xcf\xce\xce\x9d\xa6\xa3\x99\xa4\xa2\xcf\xd5\xd5\xed\xed\xed\xc4\xca\xc9\x8c\x99\x96\xaa\xb1\xaf\xbe\xbc\xbc\xe7\xe6\xe6\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd1\xd2\xd6\xd8\xd6\xc9\xd3\xcb\xce\xd7\xcf\xd8\xdf\xd9\xd0\xd7\xd1\xdc\xe3\xdd\xe8\xef\xe9\xec\xf2\xec\xe1\xe7\xe2\xd9\xdf\xda\xe2\xe7\xe3\xe4\xe7\xe4\xe0\xe4"""+\
"""\xe1\xdf\xe3\xe0\xe6\xe8\xe6\xd9\xdb\xd9\xb5\xb6\xb4\xb2\xb3\xb1\xb4\xb4\xb3\xb5\xb4\xb4\xad\xac\xab\xc7\xc6\xc6\xc3\xc3\xc3\xbc\xbc\xbc\xc8\xc8\xc7\xeb\xeb\xeb\xe7\xe7\xe7\xe5\xe5\xe5\xd6\xd5\xd5\xc0\xc0\xc0\xaa\xa9\xa9\x92\x91\x91ppp\xa6\xa7\xa6\xc4\xc3\xc3\xb8\xb9\xb9\xf6\xf1\xf0MCE\x04\x01\x04\x13\x13\x13\x8d\x8d\x8d\xfd\xfd\xfd\xeb\xeb\xeb\xee\xee\xee\xef\xef\xef\xef\xef\xef"""+\
"""\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xf0\xf0\xf0\xd2\xd1\xd1\xe6\xe5\xe5\xfc\xfc\xfc\xee\xee\xee\xff\xff\xff\xff\xff\xff\xf7\xf7\xf7\xef\xef\xef\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xf0\xf0\xf0\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfd\xfe\xfe\xfe\xfc"""+\
"""\xfc\xfc\xff\xff\xff\xe2\xe2\xe2\xcc\xcc\xcb\xd8\xd7\xd7\xed\xee\xee\xe0\xe3\xe2\xf7\xf9\xf8\xf9\xf8\xf8\xf0\xf1\xf0\xd6\xda\xd9\xee\xef\xee\xdb\xda\xda\xea\xea\xea\xf7\xf7\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd1\xd1\xd1\xde\xdd\xde\xce\xca\xcd\xa5\xa1\xa3\xbe\xb9\xbb\xe6\xe3\xe4\xe4\xe2\xe4\xe3\xe1\xe2\xe3\xe1\xe3\xe3\xe1\xe2\xeb\xea\xeb\xfb\xf9\xfa\xca\xc9\xc9\xdd\xdc"""+\
"""\xdd\xf8\xf8\xf8\xbb\xba\xba\xe6\xe5\xe5\xe4\xe1\xe2\xaa\xa6\xa7\xef\xec\xed\xd2\xd1\xd1\xb5\xb3\xb3\xf9\xf7\xf8\xc0\xbd\xbe\xc1\xbe\xbf\xf8\xf5\xf6\xbb\xb9\xb9\xdb\xda\xda\xed\xed\xed\xa1\xa1\xa0\xb8\xb8\xb8\xaf\xaf\xae\x88\x87\x87\x9c\x9c\x9c\xcd\xcc\xcc\xc3\xc3\xc3\xdf\xdd\xdd\xd8\xc9\xc8\x15\x15\x14\x13\x13\x13\x16\x15\x16\x8f\x8f\x8f\xfb\xfb\xfb\xea\xea\xea\xed\xed\xed\xee\xee\xee\xee\xee\xee"""+\
"""\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xee\xee\xee\xf2\xf2\xf2\xce\xcd\xcd\xe2\xe1\xe1\xfa\xfa\xfa\xeb\xec\xec\xff\xff\xff\xff\xff\xff\xf5\xf5\xf5\xe2\xe2\xe1\xe5\xe5\xe5\xd1\xd1\xd0\xe3\xe2\xe2\xe7\xe6\xe6\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xff\xff\xff\xe2\xe1\xe1\xcd\xcc\xcc\xcb\xca\xc9\xe4\xe2\xe2\xe5\xe3\xe3\xdd\xda\xda\xd8\xd8\xd8\xd6\xd5\xd5\xd9\xd9\xd8\xd7\xd6\xd6\xd3\xd3\xd3\xe3\xe3\xe3\xf9\xf9\xf9\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd3\xd5\xd5\xc3\xcb\xc8\xb3\xba\xb7\xc3\xcc\xc8\xcf\xd5\xd2\xd2\xd1\xd1\xb2\xb1\xb1\xb6\xb5\xb5\xd6\xd5\xd5\xe4\xe4\xe4\xf2\xf2\xf2\xd0\xd0\xd0\xe0\xe0"""+\
"""\xe0\xf1\xef\xf0\xcc\xc8\xc9\xe8\xe6\xe6\xe2\xeb\xe7\xcf\xda\xd5\xe6\xf0\xec\xc7\xcb\xc9\xc2\xc9\xc6\xe9\xf3\xee\xd1\xda\xd6\xd0\xdb\xd6\xe5\xf1\xec\xc2\xc9\xc6\xe1\xe0\xe0\xe1\xe1\xe1\xad\xac\xac\xb5\xb5\xb5\x9f\x9e\x9e\x8f\x91\x90\xd2\xd2\xd2\xb7\xb6\xb6\xcb\xcb\xcb\xef\xdd\xdd\x9c\x99\x98\x00\x00\x00   \x1e\x1e\x1e\x92\x92\x92\xfc\xfc\xfc\xeb\xeb\xeb\xee\xee\xee\xef\xef\xef\xef\xef\xef"""+\
"""\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xe0\xdd\xde\xe9\xef\xea\xec\xd1\xe5\xe1\xc6\xda\xe6\xec\xe7\xdf\xde\xdf\xe4\xe3\xe3\xdb\xdb\xdb\xd1\xd1\xd1\xbe\xbd\xbd\xd4\xd4\xd4\xdc\xdc\xdc\xca\xc9\xc9\xcc\xcb\xcb\xc9\xc8\xc8\xcb\xca\xca\xcd\xcc\xcc\xd2\xd2\xd2\xcb\xcb\xcb\xcc\xcb\xcb\xc8\xc8\xc7\xca\xca\xc9\xd0\xd0\xcf\xd3\xd2\xd2\xd2\xd1\xd1\xd3\xd3\xd3\xcc"""+\
"""\xcb\xcb\xdb\xd9\xd9\xd5\xdc\xda\xb4\xc2\xbd\xcc\xd1\xcf\xb1\xca\xc2\xb1\xca\xc1\xae\xc4\xbc\xc5\xc5\xc4\xc1\xc0\xc0\xc2\xc1\xc1\xc3\xc2\xc2\xbf\xbe\xbe\xe2\xe2\xe2\xf9\xf9\xf9\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd4\xd3\xd3\xd1\xd6\xd4\xba\xce\xc7\xd0\xe5\xdd\xd3\xea\xe1\xc6\xd6\xcf\xe1\xe0\xe0\xb5\xb4\xb4\xc1\xc0\xc0\xe2\xe2\xe2\xdc\xdc\xdc\xed\xed\xec\xdb\xdb\xda\xe5\xe4"""+\
"""\xe4\xde\xe8\xe3\xd5\xe3\xdd\xda\xe8\xe2\xcc\xe3\xda\xbd\xce\xc7\xc5\xdb\xd2\xc2\xd6\xce\xc9\xde\xd5\xcd\xe6\xdd\xd0\xe6\xde\xde\xe8\xe4\xde\xe8\xe4\xd4\xda\xd8\xe6\xe5\xe5\xd7\xd7\xd7\xb6\xb6\xb6\xaf\xae\xae\x97\x97\x97\xcb\xcb\xcb\xba\xb9\xb9\xb1\xb1\xb1\xcb\xc8\xc8\xf3\xea\xeaSUU\x01\x01\x01%%%$$$\x94\x94\x94\xfb\xfb\xfb\xea\xea\xea\xed\xed\xed\xee\xee\xee\xee\xee\xee"""+\
"""\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xec\xec\xec\xe7\xe5\xe6\xf5\xfe\xf7\xf6\xcc\xeb\xee\xc6\xe5\xdb\xe2\xdb\xce\xca\xcb\xf4\xf7\xf7\xb4\xb4\xb4\xb1\xb1\xb1\xc3\xc3\xc3\xda\xda\xda\xdf\xde\xde\x9c\x9a\x9a\xab\xaa\xaa\xab\xaa\xa9\xaa\xa9\xa8\xa5\xa4\xa3\xaf\xae\xad\xaa\xa9\xa8\xaf\xad\xad\xa8\xa6\xa6\xa5\xa4\xa4\xa3\xa2\xa1\xab\xaa\xa9\xab\xaa\xa9\xb3\xb2\xb2\xb6"""+\
"""\xb4\xb4\xb9\xba\xb8\xd3\xc8\xcf\xb3\xa1\xab\xd7\xd0\xd4\xce\xa8\xc1\xce\xab\xc2\xcb\xab\xc0\xd0\xcf\xcf\xcd\xcd\xcc\xce\xcd\xcd\xcc\xcb\xcb\xd5\xd5\xd5\xe9\xe9\xe9\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd2\xd2\xd3\xd5\xd4\xcc\xd2\xd0\xd1\xd7\xd5\xd7\xdd\xdb\xd9\xdc\xdb\xe6\xe5\xe5\xe0\xdf\xdf\xe4\xe4\xe4\xeb\xeb\xeb\xed\xed\xed\xf1\xf0\xf0\xe6\xe6\xe6\xeb\xeb"""+\
"""\xeb\xe5\xec\xe9\xe3\xec\xe8\xe3\xeb\xe8\xe3\xe9\xe7\xd6\xd9\xd8\xe0\xe5\xe3\xe8\xf0\xec\xe5\xec\xe9\xe4\xeb\xe8\xe3\xe9\xe7\xec\xea\xeb\xf0\xed\xee\xe9\xe7\xe8\xe6\xe6\xe6\xd3\xd3\xd3\xba\xba\xba\xa4\xa4\xa4\xc2\xc2\xc2\xdb\xda\xda\xb1\xb1\xb1\xc9\xc9\xc9\xdc\xdc\xdc\xd3\xd5\xd5\x18\x18\x18\x11\x11\x11&%%$$$\x97\x97\x97\xfa\xfa\xfa\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee"""+\
"""\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xef\xee\xee\xd9\xd6\xd8\xe6\xed\xe7\xd2\xad\xcb\xee\xb8\xd4\xf9\x8a\x7c\xf7wp\xff\xef\xef\xc4\xc7\xc7\xc0\xbf\xbf\xe1\xe1\xe1\xf0\xf1\xf1\xe8\xe8\xe8\xb2\xb1\xb0\xb2\xb1\xb1\xb5\xb4\xb4\xb4\xb3\xb3\xaa\xa9\xa9\xaf\xae\xae\xb2\xb1\xb0\xbb\xba\xba\xb8\xb7\xb6\xb3\xb2\xb1\xb2\xb0\xb0\xb2\xb2\xb1\xb2\xb1\xb1\xb7\xb6\xb6\xcb"""+\
"""\xca\xca\xf4\xf6\xf4\xd5\xcb\xd2\xb2\xa0\xac\xd5\xce\xd3\xc1\xa0\xb9\xc1\xa1\xb9\xbe\xa2\xb7\xce\xcd\xce\xcb\xcc\xcb\xcc\xcc\xcc\xd0\xd0\xd0\xe6\xe5\xe5\xeb\xeb\xeb\xf7\xf7\xf7\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xda\xda\xda\xd9\xd8\xd9\xdb\xda\xdb\xe0\xdf\xdf\xeb\xea\xea\xe9\xe9\xe9\xef\xef\xef\xf1\xf1\xf1\xf1\xf1\xf1\xef\xef\xef\xf8\xf8\xf8\xff\xff\xff\xfe\xfe"""+\
"""\xfe\xfe\xff\xfe\xff\xfe\xff\xff\xfe\xff\xff\xff\xff\xff\xfe\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf4\xf4\xf4\xdf\xdf\xdf\xc5\xc6\xc6\xbe\xbf\xbf\xe8\xe7\xe7\xd9\xd8\xd8\xbd\xbd\xbd\xbe\xbe\xbe\xe7\xe7\xe7\x9b\x9b\x9b\x00\x00\x00\x1d\x1d\x1d((('''\x99\x99\x99\xfa\xfa\xfa\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee"""+\
"""\xed\xed\xed\xed\xed\xed\xec\xec\xec\xed\xed\xed\xec\xec\xec\xec\xec\xec\xf0\xf0\xf0\xd0\xcd\xce\xdd\xe4\xdd\xcc\xa6\xc4\xf0\xbc\xd9\xf6\x90\x83\xf2mf\xf7\xe6\xe4\xde\xe2\xe2\xce\xcd\xcd\xc6\xc5\xc5\xe5\xe5\xe5\xdc\xdc\xdc\x9d\x9c\x9b\xa0\x9e\x9e\xa9\xa8\xa7\xa4\xa3\xa3\xae\xad\xad\xa8\xa7\xa7\xa6\xa5\xa4\xae\xac\xac\xa6\xa5\xa5\xa4\xa3\xa3\xb3\xb2\xb2\xb2\xb1\xb1\xb2\xb1\xb1\xb0\xaf\xaf\xb6"""+\
"""\xb5\xb4\xfc\xfe\xfd\xe1\xd7\xde\xb8\xa5\xb2\xd3\xce\xd2\xc3\xa5\xbb\xca\xac\xc3\xc9\xab\xc0\xd2\xcd\xcf\xcf\xcb\xcc\xca\xca\xca\xe5\xe5\xe5\xf4\xf4\xf4\xe8\xe8\xe8\xf7\xf7\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd6\xd6\xd6\xbe\xbe\xbe\xc1\xc0\xc0\xc5\xc4\xc4\xc2\xc2\xc2\xc8\xc8\xc8\xcd\xcc\xcc\xcc\xcc\xcb\xca\xca\xc9\xc6\xc5\xc5\xdc\xdc\xdc\xf1\xf1\xf1\xed\xed"""+\
"""\xed\xeb\xeb\xeb\xf2\xf2\xf2\xe7\xe6\xe6\xd3\xd3\xd3\xd9\xd8\xd8\xd4\xd4\xd4\xd6\xd6\xd6\xd6\xd5\xd5\xdc\xdb\xdb\xdb\xdb\xdb\xd7\xd7\xd7\xda\xda\xda\xf1\xf1\xf1\xdc\xdb\xdb\xc4\xc3\xc3\xb4\xb4\xb4\xdd\xdd\xdd\xd7\xd6\xd6\xd1\xd1\xd1\x96\x95\x95\xa9\xa9\xa9\xe8\xe8\xe8PPP\x02\x02\x02###.---,,\x9b\x9b\x9b\xf8\xf8\xf8\xea\xea\xea\xec\xec\xec\xed\xed\xed\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xf1\xf1\xf1\xcd\xca\xcb\xdc\xe4\xdd\xd0\xa6\xc4\xe6\xc1\xdf\xf2\xfa\xf4\xf2\xf1\xf2\xea\xed\xed\xe4\xe3\xe3\xf0\xf0\xf0\xd9\xd8\xd8\xed\xed\xed\xda\xda\xda\xb7\xb6\xb6\xb7\xb6\xb5\xba\xb9\xb8\xb5\xb4\xb4\xbe\xbd\xbd\xbf\xbe\xbe\xbb\xb9\xb9\xb8\xb7\xb7\xbf\xbe\xbe\xb3\xb2\xb1\xc6\xc5\xc5\xdf\xde\xde\xdf\xdf\xdf\xdd\xdc\xdc\xda\xda\xda\xf2\xf0\xf1\xd4\xd9\xd6\xb6\xc2\xbb\xda\xd9\xd9\xce\xcb\xca\xdb\xda\xd8\xc3\xd4\xca\xc0\xd4\xca\xbe\xd0\xc7\xd0\xd1\xd0\xd9\xd8\xd8\xdc\xdc\xdc\xe6\xe6\xe6\xf8\xf8\xf8\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xdc\xdc\xdc\xcf\xd0\xcf\xbe\xbe\xbd\xce\xce\xcd\xe2\xe2\xe1\xef\xef\xef\xf7\xf7\xf7\xfb\xfb\xfb\xed\xed\xec\xe8\xe8\xe8\xf4\xf4\xf4\xd4\xd4\xd4\xde\xde\xde\xee\xee\xee\xcd\xcd\xcc\xde\xdf\xde\xc6\xc6\xc5\xa0\xa0\x9f\xce\xce\xcd\xbb\xbb\xba\xa5\xa6\xa4\xde\xdf\xdd\xb7\xb7\xb6\xb4\xb3\xb2\xdb\xdb\xdb\xca\xc9\xc9\xc7\xc6\xc6\xbb\xbb\xbb\xd3\xd3\xd3\xd1\xd0\xd0\xc5\xc4\xc4\xa8\xa7\xa7\x94\x93\x93\xcf\xce\xce\xdd\xdd\xdd\x1a\x1a\x1a\x10\x10\x10&&&444988\x9d\x9d\x9d\xf9\xf9\xf9\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xed\xed\xed\xec\xec\xec\xed\xed\xed\xec\xec\xec\xed\xed\xed\xed\xed\xed\xdf\xdc\xde\xe9\xf1\xea\xd0\xa7\xc5\xef\xc6\xe3\xfe\xff\xff\xfd\xfc\xfd\xf5\xf4\xf3\xed\xed\xed\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xe1\xe1\xe1\xa7\xa6\xa5\xb9\xb8\xb8\xaf\xae\xae\xb2\xb1\xb1\xba\xb9\xb9\xb9\xb8\xb8\xac\xab\xaa\xb6\xb5\xb5\xb9\xb8\xb8\xb2\xb0\xb0\xa9\xa8\xa8\xb1\xb0\xaf\xc2\xc1\xc0\xdc\xdc\xdc\xd5\xd4\xd4\xee\xee\xed\xdd\xd9\xde\xb2\xac\xb4\xdd\xdd\xdc\xd9\xd9\xd8\xd5\xd4\xd5\xc1\xb5\xc5\xc1\xb4\xc5\xbe\xb2\xc2\xce\xcc\xce\xce\xce\xce\xce\xcd\xcd\xe6\xe6\xe6\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd1\xd8\xd7\xd8\xcc\xc8\xcb\xa0\x9c\x9e\xba\xb5\xb8\xdb\xd8\xda\xcf\xce\xce\xb9\xb9\xb9\xb9\xb8\xb8\xd2\xd2\xd1\xe9\xe9\xe9\xf8\xf8\xf8\xc7\xc6\xc6\xdd\xdc\xdc\xf6\xf8\xf5\xb9\xb7\xb8\xe8\xe3\xe7\xf4\xef\xf4\xc4\xbe\xc2\xf7\xf3\xf7\xd9\xd6\xd8\xc8\xc1\xc6\xff\xf8\xff\xcf\xc9\xce\xd1\xd0\xd0\xff\xff\xff\xb3\xb2\xb2\xb8\xb7\xb7\xd4\xd4\xd4\xde\xdd\xdd\xc9\xc8\xc8\xe8\xe7\xe7\xa7\xa6\xa6\xb9\xb8\xb8\xe0\xe0\xe0\x94\x93\x93\x00\x00\x00\x1d\x1d\x1d*)):::???\x9f\x9f\x9f\xf8\xf8\xf8\xea\xea\xea\xec\xec\xec\xed\xed\xed\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xec\xec\xec\xea\xe7\xe8\xf0\xf8\xf2\xcb\xa1\xbf\xf2\xcc\xe9\xd3\xd1\xca\xc2\xb7\xb8\xe7\xea\xeb\xf2\xf1\xf1\xfd\xfd\xfd\xf9\xf9\xf9\xff\xff\xff\xe2\xe2\xe2\xa7\xa6\xa6\xad\xac\xac\xb5\xb4\xb4\xb7\xb6\xb6\xb0\xae\xae\xba\xb9\xb9\xaf\xae\xae\xb5\xb4\xb4\xbc\xbb\xbb\xb5\xb4\xb3\xb1\xb0\xaf\xb3\xb3\xb2\xb7\xb6\xb5\xc2\xc1\xc1\xb5\xb4\xb3\xc0\xc2\xc0\xcd\xbf\xc6\xb7\x9c\xaa\xd7\xd8\xd7\xd2\xd3\xd2\xd3\xcd\xcf\xc7\x9d\xb4\xc7\x9b\xb3\xc3\x9b\xb1\xcb\xc6\xc8\xcb\xcb\xca\xe0\xdf\xdf\xec\xec\xec\xf6\xf6\xf6\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd4\xd3\xd7\xcf\xd6\xc8\xa9\xc6\xe6\xc5\xe4\xed\xc9\xeb\xd7\xbf\xd5\xdf\xe0\xdf\xb5\xb4\xb4\xc0\xbf\xbf\xe2\xe2\xe2\xde\xdd\xdd\xed\xed\xed\xdc\xdc\xdb\xe5\xe5\xe5\xea\xe4\xe9\xe1\xcc\xdf\xe7\xc0\xe5\xde\xbd\xdb\xee\xc8\xeb\xd7\xb7\xd5\xc8\xae\xc5\xe9\xcc\xe7\xea\xce\xe8\xde\xc6\xdc\xe2\xe1\xe1\xea\xea\xea\xcc\xcb\xcb\xc5\xc5\xc5\xe5\xe5\xe5\xe6\xe5\xe5\xf3\xf3\xf3\xe8\xe8\xe8\xd8\xd8\xd8\xcc\xcc\xcc\xe4\xe4\xe4VVV\x00\x00\x00!!!,,,;;;>>>\xa2\xa3\xa3\xf8\xf8\xf8\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xed\xed\xed\xec\xec\xec\xed\xed\xed\xec\xec\xec\xec\xec\xec\xed\xed\xed\xdc\xd9\xda\xe6\xee\xe7\xcb\xa5\xc4\xef\xb6\xd3\xf2wh\xee_X\xfd\xe8\xe7\xc6\xca\xcb\xa1\xa0\xa0\xac\xac\xac\xcf\xcf\xcf\xdf\xde\xde\xb4\xb3\xb3\xb3\xb2\xb2\xbc\xbb\xbb\xb1\xb0\xb0\xb3\xb2\xb1\xaa\xa9\xa9\xbd\xbc\xbb\xb6\xb5\xb4\xb3\xb2\xb2\xb3\xb2\xb2\xb2\xb0\xb0\xb4\xb3\xb3\xb2\xb1\xb1\xb4\xb3\xb2\xb9\xb8\xb8\xf9\xfa\xf9\xdc\xd3\xda\xb2\x9e\xae\xda\xda\xd9\xd5\xd4\xd4\xd3\xcf\xd1\xbd\xa1\xb9\xbd\xa0\xb9\xbb\xa0\xb6\xc9\xc6\xc8\xe2\xe3\xe2\xf2\xf2\xf2\xe6\xe5\xe5\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd3\xd2\xd5\xd0\xd5\xcc\xb6\xca\xd6\xc0\xd5\xde\xc6\xdd\xd6\xc5\xd4\xdd\xde\xdc\xc5\xc4\xc4\xcd\xcd\xcc\xe1\xe1\xe1\xe1\xe0\xe0\xec\xec\xec\xdd\xdd\xdc\xe5\xe4\xe4\xe9\xd2\xe7\xe9\xce\xe8\xe2\xca\xe1\xc7\xb9\xc5\xe0\xc8\xde\xec\xd2\xea\xe7\xcd\xe6\xe3\xdf\xe2\xeb\xed\xec\xdf\xdf\xde\xe2\xe2\xe2\xe8\xe7\xe7\xc4\xc4\xc4\xda\xda\xda\xda\xd9\xd9\xf1\xf0\xf0\xf6\xf6\xf6\xdc\xdc\xdc\xd3\xd5\xd5\xdd\xd6\xd6\xda\xcd\xcd\x1c\x1f\x1f\x10\x10\x0f%%%555????>>\xa5\xa5\xa5\xf7\xf7\xf7\xea\xea\xea\xec\xec\xec\xed\xed\xed\xed\xed\xed\xed\xed\xed\xed\xed\xed\xec\xec\xec\xed\xed\xed\xec\xec\xec\xec\xec\xec\xf0\xf0\xf0\xce\xcb\xcc\xd9\xe1\xda\xcc\xa5\xc2\xef\xc0\xdd\xf7\x9f\x93\xf3\x7cv\xfe\xf0\xef\xc9\xcc\xcc\xbc\xbb\xbb\xe3\xe3\xe3\xe8\xe8\xe8\xe8\xe8\xe8\xaa\xa9\xa9\xba\xb9\xb9\xb6\xb5\xb5\xb7\xb6\xb6\xc4\xc3\xc2\xb4\xb3\xb3\xb4\xb3\xb2\xaf\xae\xae\xad\xac\xab\xb1\xb0\xb0\xb0\xaf\xaf\xb5\xb4\xb3\xac\xab\xaa\xab\xaa\xaa\xaa\xa9\xa9\xbf\xbf\xbe\xda\xd5\xd6\xc1\xb7\xba\xda\xdb\xdb\xd7\xd7\xd6\xd7\xd5\xd6\xd4\xc5\xca\xd3\xc4\xca\xd1\xc2\xc7\xce\xcc\xcc\xde\xde\xde\xe6\xe6\xe6\xe1\xe1\xe1\xf7\xf7\xf7\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd1\xd8\xd8\xd8\xe0\xe2\xe0\xe6\xe8\xe6\xea\xec\xeb\xf0\xf2\xf1\xf5\xf5\xf5\xfd\xfd\xfd\xfd\xfd\xfd\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfd\xfc\xfe\xfc\xfd\xfe\xfd\xff\xfe\xff\xfc\xfe\xfc\xfc\xfe\xfc\xfc\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xee\xee\xee\xdf\xdf\xdf\xd6\xd5\xd5\xd4\xd3\xd3\xff\xff\xff\xec\xec\xec\xd9\xd9\xd9\xd1\xd0\xd0\xeb\xd9\xd8\xac\xab\xaa\x00\x00\x00\x1b\x17\x1a)))999DDDEDD\xa7\xa8\xa7\xf6\xf6\xf6\xea\xea\xea\xec\xec\xec\xed\xed\xed\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xf1\xf1\xf1\xcf\xcc\xcd\xdf\xe7\xe1\xe9\xc0\xde\xef\xc7\xe5\xff\xff\xff\xff\xfd\xfe\xfa\xfa\xfa\xe0\xdf\xdf\xc3\xc3\xc3\xd1\xd1\xd1\xeb\xeb\xeb\xe3\xe2\xe2\xaa\xa9\xa8\xb2\xb1\xb1\xad\xab\xab\xaf\xae\xae\xb6\xb5\xb5\xaa\xa9\xa8\xae\xad\xac\xb4\xb3\xb2\xb3\xb2\xb2\xb8\xb7\xb6\xbc\xbb\xbb\xbe\xbd\xbc\xc0\xbf\xbf\xb9\xb8\xb8\xb6\xb5\xb5\xc8\xc7\xc6\xdb\xdc\xdb\xf7\xf9\xf8\xfb\xfb\xfb\xfa\xfa\xfa\xfa\xfa\xfa\xf6\xf8\xf7\xf2\xf5\xf4\xf1\xf3\xf2\xf0\xef\xf0\xef\xee\xee\xea\xea\xea\xe8\xe8\xe8\xf7\xf7\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd8\xd8\xd8\xc2\xc1\xc1\xbf\xbe\xbe\xcd\xcc\xcc\xc7\xc7\xc7\xc8\xc7\xc7\xc9\xc9\xc8\xe7\xe7\xe7\xf5\xf5\xf5\xf7\xf7\xf7\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf7\xf8\xf9\xf9\xf9\xf8\xf8\xf8\xf8\xf8\xf8\xfb\xfb\xfb\xfa\xf9\xf9\xfa\xf9\xfa\xfa\xfa\xfa\xf9\xf9\xf9\xfa\xfa\xfa\xf9\xf8\xf9\xe4\xe5\xe4\xdd\xdc\xdc\xc3\xc2\xc1\xfa\xfa\xfa\xfd\xfd\xfd\xe4\xe3\xe3\xd6\xd9\xd9\xd1\xbe\xbe\xf5\xef\xeebcd\x00\x00\x00 \x10\x1d.0/?>>LLLRRR\xa9\xa9\xa9\xf7\xf7\xf7\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xee\xee\xee\xee\xee\xdb\xd8\xd9\xea\xf1\xeb\xf4\xcc\xe9\xe6\xbe\xda\xf7\xff\xf8\xf5\xf3\xf4\xef\xed\xed\xe1\xe0\xe0\xe6\xe6\xe5\xc8\xc7\xc7\xe2\xe2\xe2\xe0\xe0\xe0\xe2\xe1\xe1\xdd\xdd\xdd\xe0\xe0\xe0\xe3\xe2\xe2\xdd\xdd\xdd\xdd\xdd\xdc\xdf\xdf\xdf\xda\xd9\xd9\xdf\xde\xde\xf9\xf8\xf9\xf8\xf8\xf8\xf8\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf9\xf9\xf9\xe5\xe5\xe4\xf6\xf7\xf6\xfb\xfa\xfb\xfa\xfa\xfa\xf9\xf9\xf9\xf3\xf4\xf4\xf0\xf4\xf1\xef\xf1\xee\xee\xef\xed\xee\xef\xee\xeb\xeb\xeb\xe7\xe7\xe7\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd2\xd2\xd7\xd7\xd7\xca\xc9\xc9\xcc\xcb\xcb\xd5\xd4\xd4\xd1\xd0\xd0\xe2\xe2\xe2\xea\xea\xe9\xf4\xf4\xf4\xe8\xe8\xe8\xde\xdd\xdd\xe9\xe9\xe8\xe4\xe3\xe3\xe5\xe4\xe4\xe7\xe6\xe6\xe6\xe5\xe5\xdc\xdb\xdb\xb7\xb6\xb5\xaf\xae\xad\xba\xb8\xb8\xb5\xb4\xb4\xad\xab\xab\xcb\xca\xca\xba\xb8\xb8\xb8\xb8\xb7\xe7\xe7\xe7\xd8\xd7\xd7\xce\xcd\xcd\xff\xff\xff\xf4\xf4\xf4\xde\xe1\xe1\xd2\xc5\xc5\xda\xcc\xcb\xe4\xe7\xe8\x22!!\x0c\x0b\x0c\x22!\x22111???PPP[[[\xab\xab\xab\xf7\xf7\xf7\xeb\xeb\xeb\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xed\xed\xed\xec\xec\xec\xed\xed\xed\xed\xed\xed\xed\xed\xed\xeb\xeb\xeb\xe9\xe7\xe8\xee\xf6\xf1\xea\xc5\xdc\xe1\xbc\xd3\xf8\xfe\xf9\xf9\xf5\xf6\xeb\xeb\xeb\xe3\xe3\xe3\xf4\xf4\xf4\xf1\xf0\xf0\xf5\xf4\xf4\xdb\xdb\xdb\xbb\xba\xba\xc1\xc1\xc1\xbe\xbd\xbd\xbd\xbc\xbc\xc6\xc5\xc5\xd1\xd0\xd0\xd9\xd9\xd9\xd6\xd5\xd5\xd1\xd1\xd0\xd0\xcf\xcf\xd0\xcf\xcf\xd2\xd1\xd1\xd1\xd0\xd0\xd2\xd2\xd2\xd7\xd7\xd6\xd4\xd2\xd2\xca\xcf\xce\xb1\xbd\xbb\xda\xd9\xd9\xd6\xd5\xd5\xd3\xd5\xd4\xb6\xcb\xc2\xb4\xc1\xc0\xb3\xc2\xc1\xb4\xc3\xc2\xb3\xcc\xc3\xc4\xca\xc7\xe5\xe3\xe4\xf8\xf8\xf8\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd1\xd1\xd1\xdd\xdd\xdd\xcc\xce\xce\x9d\x9e\x9e\xb8\xb9\xb9\xe4\xe6\xe6\xde\xdd\xdd\xd8\xd8\xd8\xd6\xd5\xd5\xdd\xdc\xdc\xeb\xeb\xeb\xfa\xfb\xfb\xc6\xc5\xc5\xdb\xdb\xda\xf8\xf8\xf8\xb5\xb4\xb4\xe6\xe5\xe5\xe9\xe8\xe8\xae\xae\xad\xf4\xf7\xf6\xd2\xd4\xd4\xb5\xb7\xb6\xfd\xff\xff\xc9\xc9\xc9\xcf\xce\xce\xd8\xd7\xd7\xc6\xc5\xc5\xf9\xf9\xf9\xff\xff\xff\xed\xef\xef\xd8\xd3\xd3\xd0\xb9\xb8\xec\xef\xef\xb0\xaf\xaf\x00\x00\x00\x1c\x1c\x1c)))777GGGSRRXXX\xae\xae\xae\xf5\xf5\xf5\xea\xea\xea\xed\xed\xed\xec\xec\xec\xed\xed\xed\xed\xed\xed\xed\xed\xed\xee\xee\xee\xec\xec\xec\xed\xed\xed\xee\xee\xee\xee\xee\xee\xdb\xd9\xda\xf0\xf8\xf3\xe7\xc0\xd8\xea\xc2\xda\xe8\xf8\xf3\xda\xdf\xe0\xec\xec\xec\xf1\xf1\xf1\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xe2\xe1\xe1\x9c\x9b\x9b\xa5\xa4\xa3\xab\xaa\xaa\xac\xab\xab\xb3\xb2\xb1\xbf\xbe\xbe\xcd\xcc\xcc\xd5\xd4\xd4\xcb\xca\xca\xc6\xc5\xc5\xcf\xcf\xce\xcf\xce\xce\xc8\xc7\xc7\xc9\xc8\xc8\xc9\xc8\xc8\xdd\xdf\xdd\xd5\xc7\xcf\xb8\x9c\xac\xd9\xdb\xda\xd4\xd3\xd4\xd5\xd5\xd4\xcf\xcd\xcf\xce\xb6\xcd\xca\x9e\xb9\xcb\x9c\xb9\xc8\xae\xb7\xd6\xd2\xd2\xe7\xe8\xe8\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd3\xd3\xd4\xcf\xd0\xcb\xb6\xb9\xc8\xb3\xb6\xd6\xbe\xc1\xd4\xc3\xc6\xd5\xd6\xd5\xb2\xb1\xb1\xb9\xb8\xb8\xd9\xd9\xd9\xe2\xe2\xe1\xf0\xf0\xf0\xd5\xd5\xd4\xe3\xe3\xe2\xed\xed\xec\xd2\xd1\xd1\xe7\xe9\xe8\xe9\xec\xec\xd2\xc3\xc5\xeb\xd0\xd4\xe6\xcc\xcf\xdf\xc5\xc9\xe6\xcc\xcf\xda\xd4\xd4\xdc\xdd\xdd\xbe\xbd\xbd\xed\xed\xec\xff\xff\xff\xfb\xfb\xfb\xe5\xe6\xe6\xd4\xba\xb8\xd2\xcf\xcf\xf6\xf7\xf7ggg\x00\x00\x00! !,*+<<<NNNWWWZYY\xb2\xb2\xb2\xf6\xf6\xf6\xeb\xeb\xeb\xec\xec\xec\xee\xee\xee\xed\xed\xed\xed\xed\xed\xee\xee\xee\xed\xed\xed\xf2\xf2\xf2\xee\xee\xee\xed\xed\xed\xf0\xf0\xf0\xd0\xce\xce\xe5\xec\xe7\xba\x94\xaa\xe5\xc0\xd7\xe4\xc9\xc2\xd5\xae\xac\xed\xee\xee\xf2\xf2\xf1\xf9\xf7\xf8\xeb\xe7\xe9\xf5\xf4\xf5\xe4\xe4\xe4\xad\xac\xac\xb7\xb6\xb6\xb9\xb8\xb8\xb5\xb4\xb4\xb6\xb5\xb5\xb9\xb8\xb7\xa9\xa8\xa7\xb0\xaf\xae\xab\xaa\xaa\xab\xaa\xaa\xb1\xb0\xb0\xaa\xa9\xa9\xac\xab\xab\xaf\xad\xad\xaa\xa9\xa9\xc1\xc2\xc0\xd2\xca\xd1\xb0\xa0\xae\xdb\xdc\xdb\xd5\xd5\xd5\xd6\xd5\xd5\xd1\xd0\xd0\xd0\xcd\xcd\xcc\xba\xbd\xcc\xbd\xbf\xd5\xc4\xc7\xe9\xe4\xe5\xe5\xe6\xe5\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xca\xcb\xd2\xd4\xd3\xd5\xcd\xce\xcc\xa8\xad\xe1\xbc\xc1\xe7\xbe\xc4\xd5\xba\xbd\xdf\xe0\xe0\xb6\xb5\xb5\xc1\xc1\xc0\xe1\xe1\xe1\xdd\xdc\xdc\xec\xec\xec\xda\xd9\xd9\xe3\xe3\xe3\xe9\xe9\xe9\xd8\xd9\xd8\xe6\xcf\xd2\xe5\xc7\xcb\xe3\xbe\xc3\xe6\xba\xc0\xc8\xaa\xae\xd9\xb3\xb8\xe3\xc6\xca\xda\xda\xda\xc6\xc4\xc4\xf7\xf7\xf7\xff\xff\xff\xfe\xfd\xfd\xf6\xfb\xfb\xdc\xc5\xc4\xd3\xc7\xc6\xdb\xde\xde\xe6\xe6\xe6%\x22%\x09\x00\x06 \x04\x1b4\x00+A/>TWTWVV]\x5c\x5c\xb4\xb5\xb5\xf5\xf5\xf5\xec\xec\xec\xf2\xf2\xf2\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xf1\xf1\xf1\xe2\xe2\xe2\xed\xed\xed\xee\xee\xee\xf0\xf0\xf0\xd3\xd1\xd1\xd1\xd7\xd2\xa9\x87\x9d\xe9\xb1\xc7\xfase\xf6RI\xf9\xde\xdc\xe0\xe2\xe5\x9b\x7d\x8e\x98\x83\x8f\xc1\xbc\xbe\xde\xdf\xde\xb2\xb0\xb0\xad\xac\xab\xb2\xb1\xb1\xaf\xae\xad\xb6\xb5\xb5\xb2\xb1\xb0\xac\xab\xab\xab\xaa\xaa\xb0\xae\xae\xb8\xb8\xb7\xb1\xb0\xb0\xb2\xb1\xb0\xbb\xbb\xba\xbd\xbc\xbc\xb6\xb5\xb5\xb4\xb5\xb4\xca\xc1\xc6\xb8\xa6\xb1\xd5\xd6\xd5\xd1\xd0\xd0\xd1\xd2\xd1\xcc\xc9\xca\xcb\xae\xbc\xc8\xae\xbc\xc8\xc8\xc9\xe3\xe7\xe6\xf2\xf2\xf2\xe7\xe7\xe7\xf7\xf7\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd6\xd5\xd5\xd6\xd0\xd1\xdb\xd5\xd6\xe0\xda\xdb\xe2\xdd\xde\xe9\xea\xea\xea\xea\xea\xee\xee\xee\xf0\xf0\xf0\xf1\xf1\xf1\xf5\xf5\xf5\xf1\xf1\xf1\xf3\xf2\xf2\xf5\xf5\xf5\xf0\xf0\xf0\xf4\xec\xed\xf2\xe7\xe8\xf2\xea\xeb\xf2\xeb\xec\xeb\xe7\xe8\xe3\xde\xde\xe4\xe3\xe3\xdb\xda\xda\xe8\xe8\xe7\xff\xff\xff\xfc\xfb\xfb\xff\xff\xff\xed\xde\xdd\xd7\xc0\xbf\xd2\xd6\xd7\xea\xea\xea\xb4\xb5\xb5\x01\x00\x01\x18\x14\x17%\x1e$4'2D@CVWVSRRhgg\xb6\xb6\xb6\xf6\xf6\xf6\xeb\xeb\xeb\xe2\xe2\xe2\xf1\xf1\xf1\xed\xed\xed\xed\xed\xed\xed\xed\xed\xf0\xf0\xf0\xc0\xc0\xc0\xe4\xe4\xe4\xef\xef\xef\xef\xef\xef\xd5\xd3\xd4\xc8\xcf\xca\xc1\x9b\xb1\xe6\xc1\xd8\xfb\xc9\xc0\xf4\xa5\xa1\xff\xfb\xfa\xc6\xbd\xc3\xa9\x98\xa1\xe6\xec\xe9\xe6\xe6\xe6\xe8\xe7\xe7\xac\xab\xab\xaa\xa8\xa8\xad\xac\xab\xbb\xba\xba\xb7\xb6\xb6\xb7\xb6\xb6\xb0\xaf\xae\xb1\xb0\xaf\xae\xad\xac\xb4\xb3\xb3\xbc\xbb\xbb\xae\xad\xad\xac\xab\xaa\xb6\xb5\xb5\xb3\xb2\xb2\xe1\xe1\xe0\xe5\xe5\xe4\xda\xda\xd9\xeb\xea\xea\xe8\xe7\xe7\xe8\xe7\xe7\xe4\xe4\xe3\xe1\xe3\xe2\xdf\xe0\xdf\xdf\xde\xde\xe1\xe0\xe0\xe2\xe2\xe2\xe6\xe6\xe6\xf8\xf8\xf8\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xda\xda\xda\xd3\xd5\xd4\xd5\xd6\xd6\xdd\xdf\xdf\xe5\xe6\xe6\xe7\xe6\xe6\xea\xe9\xe9\xeb\xeb\xeb\xf0\xef\xef\xf3\xf3\xf3\xf0\xf0\xf0\xef\xef\xef\xf1\xf0\xf0\xee\xed\xed\xef\xef\xef\xee\xf0\xef\xf7\xf9\xf8\xf6\xf7\xf6\xf6\xf7\xf7\xf4\xf5\xf5\xe8\xea\xea\xe3\xe2\xe2\xef\xee\xee\xff\xff\xff\xfd\xfd\xfd\xfe\xff\xff\xfc\xf5\xf5\xe3\xc4\xc2\xd6\xd8\xd8\xd2\xd2\xd1\xf6\xf6\xf6lll\x00\x00\x00!!!,-,;<;IIIYYYYXXtss\xb8\xb8\xb8\xf7\xf7\xf7\xe2\xe2\xe2\xc0\xc0\xc0\xf0\xf0\xf0\xed\xed\xed\xed\xed\xed\xee\xee\xee\xeb\xeb\xeb\xef\xef\xef\xea\xea\xea\xee\xee\xee\xed\xec\xec\xe7\xe4\xe5\xd6\xde\xd9\xe7\xbc\xd6\xeb\xc1\xda\xff\xff\xff\xff\xfd\xfe\xfa\xf9\xfa\xdc\xd8\xdb\xcf\xc9\xcd\xd0\xcd\xcf\xe8\xe5\xe8\xe2\xdf\xe1\xb4\xb1\xb3\xb7\xb3\xb5\xb4\xb1\xb2\xb2\xae\xb0\xb9\xb6\xb8\xb7\xb4\xb6\xb8\xb5\xb7\xb7\xb4\xb5\xb3\xb0\xb2\xb4\xb0\xb2\xbe\xba\xbc\xb9\xb5\xb7\xb2\xae\xb0\xb1\xae\xb0\xb6\xb2\xb4\xe0\xdd\xdf\xe8\xe7\xe8\xfb\xfb\xfb\xff\xff\xff\xfe\xfe\xfe\xff\xfe\xff\xfd\xfb\xfd\xfa\xf7\xfa\xf8\xf5\xf8\xf7\xf5\xf7\xf7\xf4\xf6\xf2\xef\xf1\xe8\xe6\xe8\xf6\xf4\xf6\xf5\xf3\xf5\xff\xfd\xff\xdc\xdb\xdc\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd5\xd5\xd5\xbf\xbe\xbe\xc2\xc1\xc1\xca\xc9\xc9\xc3\xc2\xc2\xcb\xca\xca\xcd\xcc\xcc\xce\xcd\xcd\xca\xca\xc9\xcf\xcf\xcf\xcf\xce\xce\xd0\xd0\xd0\xd2\xd1\xd1\xd0\xcf\xcf\xd2\xd2\xd2\xc6\xc5\xc5\xbe\xbd\xbd\xc7\xc6\xc6\xbf\xbd\xbd\xcd\xcd\xcd\xde\xdd\xdc\xe5\xe4\xe4\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf4\xd2\xd1\xde\xd7\xd7\xd4\xd6\xd6\xda\xda\xda\xe8\xe8\xe8))(\x0b\x0e\x0c%(%374AGBQSQddd\x5c[[kjj\xbc\xbc\xbc\xf5\xf5\xf5\xe9\xe9\xe9\xef\xef\xef\xeb\xeb\xeb\xee\xee\xee\xee\xee\xee\xed\xed\xed\xef\xef\xef\xda\xda\xda\xee\xee\xee\xed\xed\xed\xef\xef\xef\xd7\xd3\xd5\xc1\xce\xc4\xf3\xdd\xe8\xe6\xd1\xdb\xf6\xff\xf8\xf4\xfd\xf2\xed\xf8\xee\xe5\xf0\xe7\xe8\xf5\xeb\xcf\xdc\xd0\xe7\xf4\xe9\xdf\xec\xe1\xc9\xd6\xca\xd0\xdd\xd1\xc9\xd6\xca\xc8\xd5\xc9\xd0\xde\xd2\xd2\xde\xd3\xd0\xde\xd2\xd4\xe1\xd6\xcc\xd8\xce\xc8\xd4\xc9\xc9\xd6\xca\xcb\xd8\xcc\xcf\xdc\xd1\xcb\xd9\xcd\xc4\xd2\xc5\xed\xf6\xef\xe8\xf3\xea\xee\xfa\xf0\xf4\xff\xf6\xf3\xfe\xf5\xf3\xfe\xf5\xee\xfc\xf0\xeb\xf8\xee\xe9\xf6\xeb\xe8\xf5\xeb\xe9\xf5\xeb\xe6\xf1\xe7\xea\xf3\xeb\xf7\xff\xf9\xf6\xfd\xf8\xff\xff\xff\xdc\xdd\xdd\xbc\xbc\xbc\xcb\xcb\xcb\xd0\xd0\xd0\xdc\xdc\xdc\xd1\xd1\xd0\xbb\xbb\xba\xcc\xcc\xcb\xe3\xe3\xe2\xed\xed\xed\xf4\xf4\xf4\xf7\xf7\xf7\xeb\xeb\xeb\xe7\xe7\xe6\xf7\xf7\xf6\xd4\xd3\xd2\xe3\xe3\xe2\xf4\xf4\xf3\xcf\xcf\xce\xe3\xe2\xe1\xca\xca\xc9\xa2\xa1\xa0\xc3\xc3\xc2\xe2\xe1\xe1\xdd\xdc\xdc\xf1\xf1\xf1\xff\xff\xff\xfd\xfc\xfc\xfe\xff\xff\xfd\xe2\xe1\xed\xda\xd9\xda\xdf\xdf\xd1\xd1\xd1\xe9\xe9\xe9\xb8\xac\xab\x03\x00\x01\x18\x07\x15!\x0b\x1d0\x11*G\x0f=TCQgkhmlmrqq\xbe\xbe\xbe\xf5\xf5\xf5\xeb\xeb\xeb\xda\xda\xda\xf0\xf0\xf0\xed\xed\xed\xee\xee\xee\xef\xef\xef\xeb\xeb\xeb\xcc\xcc\xcc\xea\xea\xea\xef\xef\xef\xf1\xf0\xf1\xd0\xd4\xd0\xd6\xaf\xce\xec\x9e\xdf\xe7\xa0\xdb\xe4\xa0\xd8\xe8\x9f\xdb\xe7\x9f\xdb\xe6\xa0\xda\xec\xa1\xdf\xec\xa5\xdf\xeb\xa1\xdf\xe8\xa1\xdc\xec\xa5\xe0\xed\xa4\xe0\xec\xa6\xe0\xf0\xa6\xe3\xef\xa5\xe2\xec\xa6\xe0\xf0\xa5\xe3\xec\xa5\xe0\xeb\xa6\xdf\xec\xa7\xe0\xf0\xa6\xe4\xef\xa6\xe3\xef\xa6\xe2\xf1\xa5\xe4\xf0\xa7\xe3\xe9\xa1\xdc\xe9\xa0\xdc\xe7\xa0\xdb\xe7\xa0\xda\xe6\xa0\xda\xe5\xa0\xd9\xe7\x9c\xda\xe0\x9c\xd4\xe0\x9b\xd4\xdd\x9a\xd1\xdb\x9a\xd0\xda\x9c\xcf\xe5\xa6\xda\xf5\xaa\xe9\xf4\xad\xe8\xfe\xb2\xf1\xdc\xb9\xd6\xbd\xc2\xbe\xcc\xcb\xcc\xd3\xd3\xd2\xd8\xd7\xd8\xc4\xc3\xc5\xa0\x9e\xa1\xb9\xb7\xbb\xd9\xd8\xda\xd1\xd0\xd0\xb9\xb8\xb8\xb9\xb8\xb8\xd4\xd3\xd3\xe7\xe6\xe9\xf3\xf2\xf6\xbc\xba\xbe\xd4\xd2\xd6\xf1\xf0\xf4\xb1\xaf\xb3\xe2\xe1\xe5\xe6\xe5\xe8\xb5\xb4\xb6\xe7\xe7\xe7\xe4\xe3\xe3\xf1\xf0\xf0\xff\xff\xff\xfd\xfd\xfd\xfe\xff\xff\xfd\xef\xee\xfa\xdb\xda\xe7\xeb\xec\xd5\xd5\xd4\xd3\xd4\xd4\xf6\xea\xeaqkj\x00\x00\x00 \x0e\x1c'\x10#6\x170K\x16BXIVlolqppvuu\xc1\xc1\xc1\xf6\xf6\xf6\xe6\xe6\xe6\xcd\xcd\xcd\xed\xed\xed\xef\xef\xef\xed\xed\xed\xee\xee\xee\xee\xed\xed\xec\xec\xec\xea\xeb\xea\xee\xee\xee\xf0\xed\xf0\xd2\xde\xd3\xe2\x8c\xd3\xde3\xc1\xddA\xc3\xdf@\xc4\xe4>\xc8\xe5>\xca\xdf?\xc4\xe8=\xcc\xe0=\xc5\xe7>\xcb\xde?\xc3\xdd>\xc2\xe5>\xca\xdb;\xc0\xe08\xc3\xda9\xbe\xd39\xb8\xde7\xc1\xde7\xc1\xd67\xba\xd37\xb8\xdd6\xc0\xdb6\xbf\xdb6\xbe\xe05\xc2\xd47\xb9\xd87\xbc\xdb7\xbf\xdd7\xc0\xd78\xbc\xd79\xbc\xdb7\xbf\xdc6\xbf\xd66\xba\xd38\xb8\xd7@\xbd\xd7J\xbf\xd3K\xbc\xd7B\xbe\xf4D\xd6\xf3K\xd7\xfdJ\xde\xdb\x8a\xcd\xbd\xc8\xbf\xcb\xc9\xcb\xd5\xd5\xd4\xce\xcd\xd1\xac\xa8\xb6\xc6\xc1\xd1\xc8\xc2\xd3\xc0\xbc\xc8\xde\xdf\xde\xc3\xc2\xc2\xcd\xcc\xcc\xe0\xdf\xe0\xc9\xc4\xd5\xd0\xca\xde\xd3\xce\xe1\xd1\xcc\xdf\xce\xc9\xdc\xd5\xd0\xe3\xce\xc9\xdb\xb6\xb2\xbe\xcf\xce\xd3\xe6\xe5\xe4\xeb\xea\xea\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfa\xf9\xfc\xd8\xd7\xf7\xf6\xf6\xde\xdf\xdf\xda\xd6\xd8\xcd\xcc\xcc\xd9\xd6\xd6//0\x09\x0a\x09#%#/20?C?KSL[][jjjvuu\x81\x80\x80\xc2\xc2\xc2\xf4\xf4\xf4\xe9\xea\xea\xed\xed\xed\xed\xed\xed\xee\xee\xee\xef\xef\xef\xee\xee\xee\xf2\xf1\xf1\xd5\xda\xd9\xd6\xdb\xda\xf2\xf1\xf1\xf0\xed\xf0\xd3\xde\xd4\xe0\x8d\xd1\xf3M\xd8\xe4G\xc9\xd5N\xbd\xeb[\xd3\xdda\xc8\xdcj\xc8\xddt\xcb\xe1\x7e\xd0\xdc\x86\xcc\xdd\x8e\xce\xdf\x98\xd2\xd5\x9b\xca\xee\xb6\xe5\xff\xcf\xfa\xfd\xd9\xfa\xff\xe6\xfd\xfe\xf3\xfe\xfe\xfd\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xfe\xfe\xfe\xfe\xff\xfe\xff\xfe\xff\xfe\xfe\xfe\xfc\xfe\xfd\xfa\xff\xfb\xfb\xfd\xfb\xee\xe2\xea\xd0\xb2\xc7\xd2\xa8\xc4\xf9\xfe\xfa\xf5\xfe\xf6\xf7\xfd\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xd9\xd9\xd9\xe1\xe1\xe1\xe4\xe4\xe4\xeb\xeb\xea\xf1\xf1\xf1\xf3\xf3\xf3\xfa\xfa\xfa\xfd\xfd\xfd\xfa\xfa\xfa\xfb\xfc\xfb\xfc\xfc\xfc\xfb\xfb\xfa\xfb\xfb\xfb\xfc\xfc\xfc\xfa\xfa\xfa\xfe\xfe\xfd\xec\xec\xec\xdf\xdf\xde\xe6\xe5\xe5\xf9\xf9\xf9\xff\xff\xff\xfd\xfc\xfc\xfd\xff\xff\xfb\xdb\xd9\xfe\xf0\xf0\xef\xf1\xf2\xdc\xdb\xda\xc3\xd2\xc9\xc7\xca\xc9\xa6\xa6\xa6\x05\x07\x05\x19\x1a\x19(((767GFGVTVeeeuuu\x81\x80\x81\x91\x90\x90\xc3\xc4\xc3\xf8\xf7\xf7\xd4\xd9\xd8\xda\xdf\xde\xf2\xf1\xf1\xee\xee\xee\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xef\xef\xef\xef\xef\xef\xee\xeb\xed\xe5\xef\xe7\xee\xaa\xe2\xea`\xd2\xdfi\xca\xd8m\xc5\xe0n\xcb\xd8u\xc7\xd5\x7d\xc5\xd8\x85\xc9\xd6\x8a\xc8\xd0\x8d\xc3\xd4\x95\xc8\xdf\xa8\xd5\xe4\xb5\xdb\xf2\xc5\xeb\xff\xd7\xfa\xfc\xdc\xf7\xfc\xe3\xf7\xfc\xec\xfa\xfd\xf7\xfc\xfb\xfb\xfb\xf4\xf1\xf3\xf4\xf0\xf3\xf5\xf5\xf5\xf3\xf3\xf3\xf5\xf4\xf5\xf4\xf3\xf3\xf1\xf1\xf1\xef\xee\xee\xee\xed\xee\xf0\xf0\xf0\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfd\xfc\xf3\xeb\xf1\xb6\x7b\xa5\xb8t\xa4\xbd\x94\xb1\xdb\xc8\xd5\xf4\xf4\xf4\xf4\xf3\xf4\xf6\xf5\xf6\xff\xfe\xff\xdc\xdc\xdc\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd3\xd8\xd8\xd8\xc2\xc1\xc1\xc6\xc5\xc5\xc9\xc8\xc8\xc7\xc6\xc6\xcd\xcd\xcd\xca\xca\xca\xcb\xca\xca\xdb\xdb\xdb\xfa\xfa\xfa\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf8\xf8\xfa\xfa\xfa\xf2\xf3\xf2\xe3\xe2\xe2\xda\xd8\xd8\xf0\xef\xef\xff\xff\xff\xfd\xfc\xfc\xfe\xff\xff\xfe\xe9\xe8\xfb\xe3\xe2\xfc\xff\xff\xe7\xe8\xe6\xd9\xd1\xdb\x9d\x97\xac\xd4\xe4\xdcuqs\x00\x00\x00 \x1a\x1f-.-<;;LLLZZZjji\x79\x79\x79\x86\x85\x85\x95\x95\x95\xc6\xc6\xc6\xf4\xf4\xf4\xed\xed\xed\xee\xee\xee\xef\xee\xee\xee\xef\xef\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xef\xef\xef\xef\xef\xed\xed\xed\xe6\xe5\xe5\xec\xee\xec\xc1\xd7\xc4\xc1\xd9\xc5\xd1\xdd\xd2\xdb\xed\xde\xdc\xea\xde\xd8\xe0\xd9\xdf\xe7\xe0\xd9\xdf\xda\xda\xdf\xdb\xdd\xe2\xdd\xeb\xef\xeb\xf3\xf7\xf3\xf0\xf3\xf0\xec\xf1\xec\xf8\xfa\xf9\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xf8\xf8\xf8\xc4\xcf\xc5\xbf\xcc\xc0\xca\xca\xc9\xc0\xbf\xbf\xbe\xbd\xbd\xc8\xc7\xc6\xda\xda\xda\xd2\xd1\xd1\xd5\xd4\xd4\xdd\xdc\xdc\xf3\xf2\xf2\xe9\xe9\xe9\xe9\xe9\xe9\xe0\xdc\xdf\xe4\xd7\xe0\xf9\xfa\xf9\xfc\xff\xfd\xf7\xfa\xf8\xf2\xf2\xf2\xf5\xf5\xf5\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd2\xd2\xd7\xd7\xd7\xca\xc9\xca\xcf\xce\xce\xd4\xd3\xd4\xd0\xcf\xcf\xe3\xe3\xe3\xec\xec\xec\xf0\xf0\xf0\xe4\xe4\xe4\xde\xdd\xdd\xe8\xe7\xe7\xe6\xe5\xe6\xe5\xe5\xe5\xe6\xe6\xe6\xe3\xe3\xe3\xde\xde\xde\xe4\xe2\xe3\xef\xee\xee\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xef\xf0\xf0\xdc\xd2\xd1\xff\xff\xff\xf6\xf6\xf6\xe0\xe4\xe3\xb8\x94\x95\xc1\x9a\xb4\xdf\xe1\xdf.,.\x0a\x00\x07$\x1a\x22343AAARRR```ppp\x80\x80\x80\x89\x89\x88\x95\x95\x95\xc9\xc9\xc9\xf4\xf4\xf4\xed\xee\xee\xef\xef\xef\xee\xee\xee\xef\xef\xef\xef\xef\xef\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xed\xee\xe1\xe0\xdf\xee\xee\xee\xe3\x87\xd6\xd8l\xc6\xdc\xac\xd6\xe8\x7c\xdb\xf8\xc4\xf2\xff\xff\xff\xff\xff\xff\xed\xec\xed\xde\xdc\xdd\xde\xdd\xde\xdf\xde\xdf\xd5\xd3\xd4\xd8\xd7\xd8\xd5\xd3\xd4\xe2\xe0\xe1\xec\xeb\xeb\xe6\xe5\xe5\xfc\xfb\xfc\xfd\xff\xfe\xec\xa6\xe4\xde\x87\xd0\xe8\xe1\xe7\xe7\xe9\xe7\xe7\xe7\xe7\xea\xe9\xe9\xff\xff\xff\xed\xed\xed\xde\xde\xde\xde\xdd\xdd\xe0\xe0\xe0\xd9\xd9\xd9\xd8\xd7\xd7\xd6\xd6\xd5\xe1\xe3\xe1\xe2\xe1\xe1\xdb\xd9\xda\xf0\xef\xf0\xf3\xf3\xf3\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd0\xd0\xd0\xdc\xdd\xdd\xcc\xce\xcd\x9c\x9e\x9c\xb8\xba\xb8\xe4\xe6\xe5\xde\xdd\xdd\xd8\xd8\xd8\xd8\xd7\xd7\xde\xde\xde\xeb\xed\xec\xfa\xfd\xfc\xc3\xc6\xc4\xde\xdf\xde\xf8\xf8\xf8\xd3\xd3\xd2\xe8\xe7\xe7\xea\xe9\xe9\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xbc\xbb\xbb\x9c\x9c\x9c\xc7\xc6\xc6\xee\xee\xee\xdf\xe0\xe1\xc6\xbb\xb7\xce\xd0\xca\xb7\xb7\xb8\x07\x07\x07\x16\x17\x16$%$333AAAPPP^]]lll\x7b\x7a\x7a\x89\x89\x89\x9a\x99\x99\xcb\xcc\xcb\xf3\xf3\xf3\xed\xed\xed\xee\xee\xee\xef\xef\xef\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xf0\xef\xf0\xdc\xdf\xdc\xe8\xd7\xe5\xeb+\xcd\xedJ\xd4\xef\x81\xe0\xd7\x1a\xbd\xf3\xb1\xeb\xff\xff\xff\xff\xfe\xff\xdd\xdd\xdd\xa9\xa8\xa7\xae\xac\xac\xb1\xb0\xb0\xb5\xb3\xb4\xb9\xba\xb7\xbc\xbe\xb8\xad\xad\xab\xb1\xb0\xb0\xbb\xba\xba\xfa\xfc\xfa\xfe\xf6\xfd\xf3\x22\xd3\xec0\xcc\xff\xfc\xff\xfe\xff\xfe\xff\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xdd\xdd\xdd\xaa\xa9\xa9\xad\xac\xac\xb3\xb1\xb1\xb2\xb1\xb1\xac\xab\xab\xac\xab\xab\xaa\xa9\xa9\xa7\xa6\xa6\xb7\xb6\xb6\xf0\xf0\xf0\xf3\xf3\xf3\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd3\xd3\xd5\xcf\xd2\xcd\xb6\xc2\xc9\xb2\xbd\xd6\xbd\xc9\xd4\xc3\xcc\xd5\xd6\xd5\xb7\xb5\xb5\xbc\xbc\xbb\xd8\xd7\xd7\xe3\xcb\xd7\xf2\xd5\xe3\xde\xc3\xd0\xce\xb9\xc3\xd7\xcf\xd3\xdf\xdf\xdf\xd7\xd6\xd6\xf9\xf9\xf9\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xd3\xd2\xd2\xae\xad\xad\xcc\xcb\xca\xb6\xb5\xb5\xa2\xa1\xa0\xc9\xc9\xc9\xd9\xdc\xdd\xf2\xf2\xf3uuu\x00\x00\x00\x1e\x1e\x1e-.-<><JIIZZZhhhwww\x87\x86\x86\x93\x93\x93\xa6\xa5\xa5\xcd\xce\xcd\xf4\xf4\xf4\xee\xee\xee\xef\xef\xef\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xef\xee\xef\xe4\xe4\xe3\xf4\xed\xf2\xe4\xb8\xdb\xd7\xbd\xd2\xfc\xe0\xf8\xd6\xa4\xcc\xf7\xef\xf6\xfc\xfe\xfc\xff\xff\xff\xe1\xe0\xe0\xab\xaa\xa9\xb0\xaf\xaf\xb0\xaf\xae\xb4\xb2\xb3\xcf\xd4\xca\xf0\xf8\xe8\xcd\xce\xca\x9f\x9d\x9e\xb8\xb7\xb6\xfd\xfe\xfd\xff\xfc\xff\xe1\xb9\xda\xd6\xbc\xd1\xfd\xff\xfe\xfa\xfa\xfa\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xe1\xe0\xe0\xac\xab\xaa\xaf\xae\xae\xae\xad\xad\xae\xad\xad\xac\xab\xab\xa9\xa8\xa8\xaa\xa9\xa9\xa3\xa2\xa2\xb8\xb8\xb8\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbd\xbd\xbd\xcc\xcb\xcc\xd3\xd5\xd4\xd6\xcd\xd2\xcf\xa7\xbb\xe2\xba\xcf\xe9\xbc\xd3\xd6\xb8\xc7\xdf\xe1\xdf\xb4\xb3\xb3\xbf\xbf\xbf\xe4\xe0\xe2\xce\xaa\xbc\xcc\xaa\xbb\xeb\xbb\xd3\xd9\xb7\xc8\xda\xd9\xd9\xc5\xc3\xc3\xe3\xe2\xe2\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xee\xee\xee\xf9\xf9\xf9\xff\xff\xff\xd1\xd1\xd1\x9a\x99\x99\x9e\x9e\x9d\xc0\xbf\xbf\xf0\xf0\xf0676\x05\x04\x05\x1e\x1a\x1d-',=6;POO```oon\x7e\x7e\x7e\x8e\x8e\x8e\x99\x98\x98\xab\xaa\xaa\xd1\xd1\xd1\xf5\xf5\xf5\xef\xef\xef\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xef\xef\xef\xe5\xe4\xe4\xee\xf0\xee\xd8\xc1\xd5\xcc\xaa\xc6\xd7\xce\xd5\xc9\xac\xc5\xd2\xbf\xcf\xe0\xe1\xdf\xfc\xfc\xfc\xdf\xdf\xde\xad\xac\xab\xaf\xae\xad\x9e\x9c\x9c\xc5\xc6\xc2\xe0\xe8\xd8\xf3\xf8\xf0\xdb\xda\xda\x9e\x9c\x9c\xb5\xb4\xb3\xf2\xf1\xf2\xf8\xfc\xf8\xda\xc7\xd6\xd8\xb3\xd2\xd2\xcc\xd1\xe9\xe9\xe8\xff\xff\xff\xfe\xfe\xfe\xf9\xf8\xf8\xde\xdd\xdd\xad\xac\xac\xb0\xaf\xae\xaf\xae\xae\xac\xaa\xab\xa8\xa7\xa7\xaa\xa9\xa9\xaa\xa9\xa9\xa4\xa3\xa3\xb8\xb8\xb7\xe4\xe4\xe4\xf0\xf0\xf0\xf5\xf5\xf5\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd2\xd2\xd5\xd4\xd5\xd5\xcf\xd2\xda\xd4\xd7\xe0\xd9\xdd\xe2\xdd\xe0\xe9\xea\xe9\xe7\xe7\xe7\xea\xea\xea\xed\xec\xec\xe7\xe2\xe4\xe5\xe2\xe3\xed\xe5\xe9\xe4\xdf\xe1\xe2\xe1\xe1\xe0\xdf\xdf\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xe6\xe6\xe6\xa8\xa7\xa7\xa6\xa5\xa5\xaa\xa9\xa9\xb5\xb4\xb4\xae\xae\xae\x0a\x0b\x0a\x17\x13\x16!\x03\x1c+\x01#=\x0b4URUfgfttt\x84\x84\x84\x95\x94\x94\x9e\x9d\x9d\xb0\xaf\xaf\xd3\xd3\xd3\xf5\xf5\xf5\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xef\xee\xef\xe5\xe6\xe4\xf0\xe9\xee\xe8B\xce\xedO\xd4\xeb\x92\xdf\xd70\xbc\xf1\xaa\xe7\xff\xff\xff\xee\xeb\xee\xd5\xd4\xd4\xaf\xae\xae\xaf\xae\xae\xa2\xa0\xa1\xca\xcd\xc5\xee\xf5\xe8\xf2\xf6\xf0\xcf\xd4\xc9\xa9\xa7\xa7\xc1\xc0\xc0\xe1\xe3\xe1\xf0\xeb\xef\xf7:\xda\xf0,\xd1\xfd\xf2\xfc\xfe\xff\xfe\xfc\xfb\xfc\xff\xff\xff\xeb\xeb\xeb\xd6\xd5\xd5\xb1\xaf\xaf\xac\xab\xab\xb4\xb4\xb1\xd9\xe0\xd0\xc1\xc5\xbd\xa6\xa5\xa5\xab\xaa\xaa\xa3\xa2\xa2\xbc\xbb\xbb\xda\xd9\xd9\xea\xe9\xe9\xf8\xf8\xf8\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xda\xdb\xda\xd5\xd7\xd6\xd7\xd9\xd8\xdc\xde\xdd\xe4\xe5\xe5\xe7\xe7\xe7\xe7\xe7\xe7\xef\xef\xef\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xee\xf0\xef\xe2\xe2\xe1\xe8\xe7\xe7\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xbf\xbe\xbe\x9f\x9e\x9e\xbb\xba\xba\xef\xee\xeewww\x00\x00\x00\x1f\x1f\x1f)&(625E@DUUUfeesss\x82\x82\x82\x91\x91\x91\x9e\x9d\x9d\xb2\xb1\xb1\xd5\xd6\xd6\xf4\xf4\xf4\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xf0\xf0\xf0\xf1\xf1\xf1\xef\xef\xef\xe2\xe3\xe1\xf1\xe7\xef\xe4\x83\xd4\xda\x97\xcf\xfd\xc2\xf3\xd3f\xc1\xf5\xdc\xf1\xff\xff\xff\xf1\xef\xf0\xd4\xd3\xd3\xae\xad\xad\xae\xac\xad\xba\xbb\xb5\xe6\xea\xe1\xf9\xf9\xfa\xee\xf2\xea\xba\xbd\xb5\xa7\xa6\xa6\xc1\xc0\xc0\xeb\xec\xeb\xf4\xef\xf3\xf3\x8f\xe2\xea\x9c\xdd\xff\xff\xff\xfe\xfd\xfe\xfe\xfd\xfe\xff\xff\xff\xec\xec\xec\xd2\xd1\xd1\xae\xad\xac\xaf\xae\xad\xc5\xca\xbf\xea\xf0\xe4\xe5\xe6\xe4\xa5\xa4\xa4\xaa\xa9\xa9\xa2\xa1\xa1\xbe\xbd\xbd\xde\xdd\xdd\xe9\xe9\xe9\xf7\xf7\xf7\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd2\xd2\xd2\xd5\xd5\xd5\xbf\xbe\xbe\xc5\xc4\xc4\xc8\xc7\xc7\xc2\xc1\xc1\xcb\xca\xca\xcc\xcb\xcb\xd6\xd5\xd5\xe8\xe8\xe8\xe9\xe8\xe9\xe7\xe8\xe7\xdf\xde\xde\xc2\xc0\xc0\xf4\xf3\xf3\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xe3\xe3\xe3\xcd\xcd\xcd\xc5\xc5\xc4\xe1\xe1\xe1<<<\x06\x06\x06   +,+=>=OPO[ZZjjjxxx\x87\x87\x86\x96\x96\x96\xa1\xa1\xa0\xb3\xb2\xb2\xd9\xd9\xd9\xf4\xf4\xf4\xf0\xf0\xf0\xf0\xf0\xf0\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xdc\xda\xda\xe8\xe9\xe8\xd7\xe3\xd8\xce\xd5\xcf\xda\xe1\xda\xdb\xe6\xdc\xfd\xfd\xfd\xff\xff\xff\xe9\xe8\xe8\xd1\xd0\xd0\xae\xae\xad\xab\xaa\xaa\xbb\xbc\xb7\xea\xee\xe7\xe3\xe9\xde\xcd\xd4\xc5\xad\xad\xac\xa3\xa2\xa2\xc1\xc0\xc0\xdc\xdb\xdb\xf0\xf2\xf0\xd7\xe8\xd9\xd4\xde\xd5\xdf\xdf\xdf\xd8\xd8\xd7\xe2\xe1\xe1\xff\xff\xff\xe3\xe2\xe2\xd3\xd3\xd2\xac\xaa\xaa\xac\xaf\xa7\xdb\xe0\xd6\xec\xed\xed\xd7\xdb\xd3\xa2\xa2\xa0\xa8\xa7\xa7\xa0\x9f\x9f\xba\xb9\xb9\xd1\xd1\xd0\xe8\xe8\xe8\xf7\xf7\xf7\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd0\xdc\xdc\xdc\xd1\xd1\xd1\xbf\xbe\xbe\xcf\xce\xce\xe2\xe2\xe2\xf0\xef\xef\xf8\xf8\xf8\xfb\xfb\xfb\xea\xea\xea\xdd\xdd\xdd\xe5\xe5\xe5\xc9\xc7\xc7\xe0\xe0\xe0\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xf1\xf1\xf1\xda\xda\xda\xd4\xd4\xd4\xe8\xe8\xe8\xc4\xc4\xc4\x09\x09\x09\x16\x16\x16  \x1f+++>>>TTTddduuu\x83\x83\x83\x93\x93\x93\xa4\xa3\xa3\xac\xac\xac\xc0\xbf\xbf\xda\xdb\xda\xf5\xf5\xf5\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf0\xef\xf0\xe4\xe3\xe3\xef\xee\xef\xdb\x8d\xd1\xd5s\xc9\xee\xdf\xec\xfa\xfb\xfa\xfe\xfc\xfe\xff\xff\xff\xee\xee\xee\xd7\xd6\xd6\xae\xad\xac\xa7\xa6\xa5\xc3\xc2\xc2\xf3\xf4\xf1\xc9\xd1\xc2\xa4\xa8\xa0\xae\xad\xad\xaa\xa9\xa8\xb9\xb8\xb8\xde\xde\xde\xf4\xf5\xf4\xf1e\xe0\xe9G\xd1\xf1\xe5\xef\xf2\xf5\xf2\xf3\xf2\xf3\xff\xff\xff\xed\xec\xec\xd8\xd8\xd8\xb1\xb0\xaf\xd1\xd8\xca\xdf\xe0\xdd\xe1\xe7\xdb\xd3\xdd\xcb\xa0\xa1\x9e\xac\xaa\xab\xa4\xa3\xa3\xb5\xb4\xb4\xd3\xd3\xd3\xed\xed\xed\xf6\xf6\xf6\xf5\xf5\xf5\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd1\xd7\xd7\xd7\xc5\xc5\xc4\x9f\x9e\x9e\xb9\xb8\xb8\xda\xda\xda\xcf\xcf\xcf\xb7\xb6\xb5\xb7\xb6\xb5\xd4\xd4\xd4\xe1\xe1\xe1\xd2\xd1\xd1\xd2\xd1\xd1\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xe9\xe9\xe9\xd7\xd7\xd7\xd1\xd1\xd1\xf3\xf3\xf3\x87\x87\x87\x00\x00\x00   ++*565<\x073H\x07<e`d\x7b\x7c\x7b\x88\x87\x87\x98\x97\x97\xa8\xa7\xa7\xb0\xb0\xb0\xc6\xc5\xc5\xdd\xde\xde\xf4\xf4\xf4\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf1\xf1\xf1\xf2\xf2\xf2\xf0\xef\xf0\xe5\xe7\xe4\xf0\xe2\xed\xddZ\xc9\xddk\xcd\xff\xfe\xff\xfd\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xe0\xe0\xe0\xac\xab\xab\xaf\xad\xad\xb4\xb2\xb2\xd1\xd8\xcb\xd3\xdd\xcb\xae\xaf\xab\xaf\xad\xae\xad\xac\xac\xb8\xb6\xb6\xf2\xf5\xf2\xff\xf5\xfe\xecO\xd5\xe7f\xd4\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xe1\xe0\xe1\xaf\xaf\xae\xde\xe1\xdc\xd6\xda\xd2\xcb\xd3\xc2\xa7\xaa\xa3\xa4\xa3\xa3\xab\xaa\xaa\xa4\xa4\xa3\xb4\xb3\xb3\xe9\xe9\xe9\xf5\xf5\xf5\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd3\xd3\xd3\xcf\xcf\xcf\xb6\xb6\xb6\xcd\xcd\xcd\xd1\xd1\xd1\xc8\xc8\xc8\xe1\xe0\xe0\xc6\xc5\xc5\xcb\xca\xca\xe9\xe9\xe9\xf6\xf6\xf6\xe5\xe4\xe4\xf7\xf7\xf7\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xf9\xf9\xf9\xe1\xe1\xe1\xd5\xd5\xd5\xd6\xd6\xd6\xf1\xf1\xf1>>>\x05\x05\x05###222?>?I.DW5Qieh\x7c\x7b\x7b\x89\x87\x88\x99\x97\x98\xa8\xa6\xa7\xb4\xb3\xb3\xcc\xcb\xcb\xdf\xdf\xdf\xf4\xf4\xf4\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf1\xf1\xf1\xe6\xe5\xe5\xf5\xf3\xf4\xf2\xe4\xef\xea\xdf\xe8\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xdf\xdf\xdf\xac\xac\xab\xb0\xaf\xaf\xae\xac\xac\xab\xab\xa9\xab\xac\xa9\xab\xab\xaa\xb1\xaf\xaf\xad\xac\xac\xb9\xb8\xb8\xf3\xf3\xf3\xff\xff\xff\xf1\xf1\xf0\xe9\xe8\xe8\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xdf\xdf\xdf\xb0\xaf\xaf\xdf\xe0\xdd\xd0\xd6\xc7\xb6\xba\xae\xa5\xa3\xa2\xac\xab\xab\xaa\xaa\xa9\xa5\xa4\xa4\xb5\xb5\xb4\xea\xea\xea\xf4\xf4\xf4\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd1\xd8\xd8\xd8\xd3\xd3\xd3\xd6\xd6\xd6\xdb\xdb\xdb\xe2\xe2\xe2\xe4\xe3\xe3\xea\xe9\xe9\xed\xee\xee\xf5\xf5\xf5\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xf2\xf2\xf2\xdb\xdb\xdb\xd2\xd2\xd2\xe4\xe4\xe4\xcd\xcd\xcd\x0d\x0d\x0d\x16\x18\x16%'%+-+:>;IQJXcYv\x7cw\x84\x8a\x85\x94\x9a\x95\xa3\xaa\xa4\xb3\xbb\xb4\xb0\xb1\xaf\xbd\xbb\xbb\xe5\xe5\xe5\xf4\xf4\xf4\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xd8\xd7\xd7\xe9\xe8\xe8\xff\xff\xff\xfd\xfd\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xdd\xdd\xdd\xa8\xa6\xa6\xad\xac\xac\xad\xab\xab\xae\xad\xad\xac\xaa\xab\xad\xac\xac\xad\xac\xab\xaa\xa8\xa8\xb5\xb4\xb4\xee\xed\xed\xff\xff\xff\xfe\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xdf\xdf\xdf\xa9\xa7\xa8\xae\xb1\xaa\xbe\xc5\xb7\xab\xac\xa7\xa7\xa6\xa6\xa8\xa7\xa6\xa8\xa7\xa6\xa1\xa0\xa0\xb4\xb3\xb2\xe5\xe5\xe5\xf5\xf5\xf5\xf5\xf5\xf5\xf7\xf7\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xd9\xd9\xd9\xcb\xcb\xcb\xcf\xce\xce\xcf\xcf\xcf\xd7\xd7\xd7\xd8\xd7\xd7\xd2\xd1\xd1\xe7\xe8\xe8\xff\xff\xff\xf9\xf9\xf9\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xe9\xe9\xe9\xd7\xd7\xd7\xd1\xd1\xd1\xf3\xf3\xf3\x8c\x8c\x8c\x00\x00\x00\x1e\x18\x1d(\x1f'5(2F5CR<NbH]v]r\x84i\x7f\x91s\x8b\xa0\x7f\x9a\xa9\x86\xa2\xac\x9e\xa9\xbc\xbe\xbc\xe8\xe8\xe8\xf3\xf3\xf3\xf2\xf2\xf2\xf2\xf2\xf2\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf7\xf7\xf7\xcb\xca\xc9\xde\xde\xde\xff\xff\xff\xfb\xfd\xfc\xfc\xfe\xfd\xfd\xfe\xfe\xfd\xfe\xfd\xfc\xfe\xfc\xff\xff\xff\xe1\xe3\xe1\xc2\xc4\xc2\xc1\xc3\xc1\xc3\xc4\xc2\xc2\xc3\xc1\xc9\xc9\xc8\xc7\xc8\xc7\xc9\xc9\xc9\xc7\xc7\xc6\xc8\xc8\xc8\xed\xed\xed\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xe3\xe3\xe3\xc5\xc4\xc4\xc1\xc0\xc0\xbc\xbb\xbb\xc1\xc1\xc1\xc7\xc6\xc6\xc0\xbf\xbf\xc3\xc2\xc2\xbf\xbe\xbe\xc1\xc1\xc0\xe3\xe3\xe3\xf6\xf6\xf6\xf5\xf5\xf5\xf7\xf7\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xd9\xd9\xd9\xe2\xe2\xe2\xe9\xe9\xe9\xef\xef\xef\xf3\xf3\xf3\xf7\xf7\xf7\xf2\xf3\xf3\xfd\xfe\xfe\xff\xff\xff\xe6\xe6\xe6\xf9\xf9\xf9\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf9\xf9\xf9\xe1\xe1\xe1\xd5\xd5\xd5\xd5\xd5\xd5\xf2\xf2\xf2CAC\x05\x00\x01%\x02\x1f+\x00#3\x00*C\x007V\x00G`\x00N\x7e\x00g\x8f\x00t\x9c\x00\x80\xad\x03\x8e\xb7\x00\x93\xbat\xad\xd2\xde\xd3\xe8\xe5\xe7\xf5\xf5\xf5\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xd8\xd8\xd7\xe8\xe4\xe7\xff\xf7\xff\xfd\xf7\xfd\xff\xf8\xff\xfe\xf9\xfe\xfe\xf9\xfe\xfe\xfb\xfe\xff\xfc\xff\xfd\xfa\xfd\xfd\xfb\xfd\xfd\xfa\xfd\xfa\xf6\xf9\xe8\xe2\xe6\xed\xe9\xec\xe4\xe2\xe3\xf6\xf5\xf6\xfc\xfc\xfc\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xfa\xfa\xfa\xf6\xf6\xf6\xe1\xe0\xe0\xe4\xe4\xe4\xdd\xdd\xdd\xee\xee\xee\xf4\xf4\xf4\xee\xee\xee\xf3\xf3\xf3\xf3\xf3\xf3\xf5\xf5\xf5\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbc\xbc\xbc\xcb\xcb\xcb\xd1\xd1\xd1\xd8\xd8\xd8\xdf\xde\xdf\xe7\xe4\xe6\xec\xea\xeb\xf0\xee\xef\xf4\xf1\xf3\xf0\xee\xef\xf5\xf3\xf4\xff\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xe2\xe2\xe2\xef\xef\xef\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf2\xf2\xf2\xdb\xdb\xdb\xd3\xd3\xd3\xe2\xe2\xe2\xd1\xd1\xd1\x0f\x0e\x0f\x16\x11\x16*!(7.6E;CUHRfUctcq\x8bo\x87\x9d\x7d\x97\xae\x89\xa7\xbe\x97\xb7\xcf\xa1\xc7\xd6\xc6\xd3\xe2\xe4\xe2\xe7\xe7\xe8\xf6\xf6\xf6\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf1\xee\xf1\xe9\xf6\xeb\xea\x8b\xd9\xdb\x1f\xba\xe3$\xc1\xc8*\xac\xe07\xc2\xda@\xbf\xceJ\xb6\xd4T\xbd\xd8a\xc3\xd3i\xc0\xd1s\xc0\xd0\x7d\xc0\xcd\x86\xbf\xe5\xa1\xd9\xff\xc1\xf7\xfd\xcb\xf5\xfd\xd8\xf7\xfe\xe8\xfb\xff\xf8\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xf7\xf7\xf7\xf5\xf5\xf5\xf6\xf6\xf6\xf3\xf3\xf3\xf3\xf3\xf3\xf6\xf6\xf6\xf7\xf7\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xda\xd9\xd9\xdd\xe1\xdd\xdc\xe7\xe0\xe2\xec\xe6\xe9\xf4\xed\xee\xf8\xf2\xf3\xfe\xf7\xec\xf8\xf1\xe7\xf4\xec\xf9\xfd\xf9\xff\xff\xff\xf6\xf6\xf6\xce\xce\xcd\xe1\xe1\xe0\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xea\xea\xea\xd7\xd7\xd7\xd1\xd1\xd1\xf2\xf2\xf2\x91\x91\x91\x00\x00\x00#$#021BDCTVTehfw\x7aw\x89\x8c\x89\x98\x9e\x99\xa9\xb1\xab\xba\xc3\xbc\xcb\xd4\xcd\xe0\xea\xe2\xdd\xdf\xdd\xd2\xd0\xd1\xea\xea\xea\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf4\xf4\xf5\xf5\xf5\xf4\xf2\xf4\xdf\xe5\xdf\xeb\xbb\xe2\xfc\x9d\xed\xf3\x9d\xe6\xea\x9f\xdd\xf5\xa5\xe8\xef\xa6\xe3\xe5\xa5\xd9\xe7\xab\xdd\xe9\xb1\xdf\xe8\xb6\xdf\xe5\xb9\xdd\xe5\xbe\xde\xe3\xc1\xdd\xef\xce\xe8\xfe\xe0\xfa\xfb\xe2\xf7\xff\xf0\xff\xe1\xd6\xdf\xc2\xbd\xc0\xd4\xd3\xd3\xca\xca\xc9\xcb\xca\xca\xcc\xcc\xcb\xc2\xc2\xc1\xdf\xdf\xdf\xff\xff\xff\xfb\xfb\xfb\xfa\xfa\xf9\xfe\xfe\xfd\xff\xff\xff\xde\xdd\xdd\xcc\xcb\xcb\xd3\xd3\xd2\xc4\xc3\xc3\xc7\xc6\xc6\xc2\xc1\xc1\xc0\xbf\xbf\xe5\xe5\xe5\xf6\xf6\xf6\xf5\xf5\xf5\xf7\xf7\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd3\xd3\xd4\xd8\xd5\xd0\xb0\xb8\xaa\x91\xb1\xb7\x9a\xad\xb2\xb2\xce\xd1\xb0\xcc\xd0\xaf\xcd\xd0\xc0\xdb\xe1\xc1\xdd\xe5\xd3\xdc\xe8\xf8\xf7\xf7\xfe\xff\xfe\xfe\xfe\xfe\xd7\xd7\xd6\xd7\xd7\xd6\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xe2\xe2\xe2\xd5\xd5\xd5\xd5\xd5\xd5\xf3\xf3\xf3HHH\x06\x06\x06'''556GFGXWXihi\x7a\x79\x7a\x8b\x8a\x8b\x9c\x9b\x9c\xae\xac\xad\xbf\xbd\xbe\xcf\xcd\xcf\xe5\xe3\xe5\xdb\xd9\xda\xc4\xc3\xc3\xec\xec\xec\xf5\xf5\xf5\xf4\xf4\xf4\xf4\xf4\xf4\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf5\xf5\xf5\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf8\xf8\xf8\xcc\xcb\xcb\xdd\xde\xdd\xe8\xf3\xea\xdd\xeb\xdf\xe4\xee\xe5\xe2\xee\xe4\xf0\xf6\xf1\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xdf\xe2\xdf\xe3\xe4\xe3\xff\xff\xff\xdd\xde\xdd\xd8\xd8\xd8\xff\xff\xff\xdd\xdd\xdd\xd4\xd3\xd3\xff\xff\xff\xe7\xe6\xe7\xdd\xdc\xdc\xff\xff\xff\xef\xee\xee\xe3\xe2\xe2\xff\xff\xff\xff\xff\xff\xcf\xcd\xcf\xe5\xe3\xe5\xff\xff\xff\xd4\xd3\xd4\xe2\xe1\xe2\xf8\xf7\xf8\xcf\xce\xce\xdf\xde\xdf\xf9\xf8\xf9\xf5\xf5\xf5\xf7\xf7\xf7\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcb\xd5\xd4\xd5\xd0\xd4\xcd\xb0\x92\x91\xc8w\xa0\xb6v\x98\xc0\x7b\x9e\xd5\x8a\xae\xd4\x89\xad\xf0\x9d\xc8\xfc\xa2\xd2\xfb\xb0\xd8\xf6\xf7\xf7\xf2\xf3\xf2\xfc\xfc\xfc\xff\xff\xff\xf1\xf1\xf1\xcf\xcf\xcf\xec\xec\xec\xff\xff\xff\xfe\xfe\xfe\xf2\xf2\xf2\xdc\xdc\xdc\xd3\xd3\xd3\xe1\xe1\xe1\xd4\xd4\xd4\x12\x12\x12\x16\x16\x16+++;;;LLL^^^ooo\x80\x80\x80\x91\x91\x91\xa2\xa2\xa2\xb4\xb4\xb4\xc5\xc5\xc5\xd5\xd5\xd5\xeb\xeb\xeb\xe3\xe3\xe2\xcd\xcc\xcc\xeb\xec\xec\xf6\xf6\xf6\xf5\xf5\xf5\xf5\xf5\xf5\xf6\xf6\xf6\xf6\xf6\xf6\xf7\xf7\xf7\xf7\xf7\xf7\xf6\xf6\xf6\xf7\xf7\xf7\xf6\xf6\xf6\xf6\xf6\xf6\xf8\xf7\xf8\xd5\xd4\xd4\xd6\xd4\xd5\xbd\xb9\xbb\xb8\xb4\xb6\xb3\xb0\xb2\xb0\xac\xae\xc5\xc1\xc3\xd2\xcf\xd1\xd6\xd4\xd5\xea\xe8\xe9\xe8\xe6\xe8\xe8\xe6\xe7\xec\xea\xeb\xcc\xca\xcb\xd7\xd8\xd4\xd0\xd4\xcb\xd5\xd9\xd0\xe5\xe9\xe2\xb8\xbb\xb4\xbd\xbf\xb9\xe8\xed\xe5\xbb\xbe\xb7\xba\xbd\xb6\xe8\xec\xe4\xc3\xc7\xbf\xbc\xbf\xb8\xe5\xe9\xe2\xc4\xc7\xc0\xb9\xbc\xb5\xe7\xe9\xe5\xe0\xe3\xdd\xc6\xcc\xc1\xd8\xdc\xd3\xde\xe3\xdb\xa6\xa9\xa2\xbc\xbf\xb9\xde\xe2\xda\xac\xaf\xa9\xbc\xbf\xb8\xf0\xf2\xf0\xf6\xf6\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcb\xd4\xd4\xd5\xd4\xd4\xce\xaa\xa0\x99\xa3\x8a\xa4\x98\x83\x95\x9f\x87\x9b\xcc\xb0\xca\xd4\xb7\xd3\xcd\xb2\xcc\xcc\xaf\xca\xd5\xbe\xd5\xff\xff\xff\xfb\xfb\xfb\xf1\xf2\xf2\xf8\xf8\xf8\xff\xff\xff\xf9\xf9\xf9\xd7\xd7\xd7\xdd\xdd\xdc\xfe\xfe\xfe\xec\xec\xec\xd7\xd7\xd7\xd1\xd1\xd1\xf1\xf1\xf1\x96\x96\x96\x00\x00\x00\x22\x22\x22000AAARRRcccttt\x86\x86\x86\x97\x97\x97\xa8\xa8\xa8\xb9\xb9\xb9\xca\xca\xca\xdb\xdb\xdb\xf1\xf1\xf1\xe5\xe5\xe5\xc9\xc8\xc7\xec\xed\xec\xf7\xf7\xf7\xf6\xf6\xf6\xf6\xf6\xf6\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf6\xf6\xf6\xf7\xf7\xf7\xf6\xf6\xf6\xf6\xf6\xf6\xf8\xf8\xf8\xd2\xd1\xd1\xd5\xd4\xd4\xc5\xc4\xc4\xc8\xc7\xc7\xc2\xc1\xc1\xc4\xc3\xc3\xc4\xc3\xc3\xbf\xbf\xbe\xc8\xc7\xc7\xef\xee\xee\xed\xed\xec\xec\xec\xeb\xf7\xf7\xf7\xa6\xa3\xa5\xbf\xc4\xba\xba\xc4\xb2\xb5\xbd\xae\xdb\xe4\xd4\xa7\xae\x9f\xa5\xac\x9e\xdc\xe5\xd6\xa9\xb1\xa2\xa3\xaa\x9b\xdc\xe5\xd6\xab\xb3\xa4\x9f\xa6\x98\xdc\xe5\xd5\xae\xb5\xa7\x9b\xa3\x94\xe1\xe5\xdd\xda\xe0\xd4\xae\xb7\xa6\xbf\xc7\xb8\xd4\xdc\xcd\x99\xa0\x92\xac\xb3\xa5\xd1\xda\xcb\x9b\xa2\x95\xa8\xb0\xa1\xee\xf1\xed\xf7\xf6\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcb\xd4\xd4\xd5\xd2\xd4\xcd\xaa\x98\x91\xab\x7d\x9c\x9e\x7a\x91\xa2\x7a\x92\x9dx\x90\xaa\x83\x9d\xb3\x8e\xa7\xac\x84\x9f\xc2\xa2\xb8\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xf2\xf3\xf3\xf2\xf3\xf2\xff\xff\xff\xff\xff\xff\xe7\xe6\xe6\xcb\xca\xca\xdc\xdc\xdc\xda\xda\xda\xd3\xd3\xd3\xf4\xf4\xf4MMM\x05\x05\x05'''555FFFXXXiii\x7a\x7a\x7a\x8b\x8b\x8b\x9c\x9c\x9c\xad\xad\xad\xbf\xbf\xbf\xd0\xd0\xd0\xe1\xe1\xe1\xf5\xf5\xf5\xf0\xef\xef\xde\xdd\xdc\xeb\xeb\xeb\xf8\xf8\xf8\xf6\xf6\xf6\xf6\xf6\xf6\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf7\xf6\xf6\xf6\xf7\xf7\xf7\xf6\xf6\xf6\xf7\xf7\xf7\xf6\xf6\xf6\xda\xd9\xd9\xdc\xdc\xdc\xc5\xc4\xc4\xbd\xbc\xbc\xbe\xbd\xbd\xbf\xbf\xbe\xba\xb9\xb9\xc0\xbf\xbf\xc6\xc6\xc5\xcc\xcc\xcb\xc9\xc8\xc8\xc5\xc5\xc4\xc7\xc7\xc6\x98\x96\x97\xc7\xcb\xc2\xaa\xb1\xa3\xaa\xb0\xa3\xdc\xe3\xd5\xaa\xb1\xa3\xaa\xb1\xa4\xdc\xe4\xd6\xab\xb2\xa5\xa6\xac\x9f\xdc\xe4\xd6\xae\xb5\xa7\xa3\xa9\x9d\xdc\xe4\xd6\xb1\xb8\xaa\x9f\xa6\x98\xe1\xe5\xdd\xd8\xde\xd3\x9c\xa3\x95\xb6\xbd\xb0\xd5\xdd\xcf\x9c\xa2\x95\xaf\xb5\xa8\xd1\xd9\xcc\x9d\xa3\x97\xab\xb1\xa4\xee\xf1\xed\xf7\xf6\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd3\xd9\xd9\xd6\xc3\xc0\xb5\xaf\xab\xab\xb3\xaf\xae\xb4\xb1\xb0\xb2\xaf\xae\xc2\xbe\xbd\xd6\xd2\xd1\xd3\xcf\xce\xdb\xd7\xd6\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf9\xf9\xf9\xdd\xde\xde\xe1\xe2\xe1\xfc\xfc\xfc\xff\xff\xff\xe9\xe9\xe8\xba\xba\xba\xc2\xc2\xc2\xe4\xe4\xe4\xd8\xd8\xd8\x15\x15\x15\x15\x15\x15+++;;;MMM^^^ooo\x80\x80\x80\x91\x91\x91\xa3\xa3\xa3\xb4\xb4\xb4\xc5\xc5\xc5\xd6\xd6\xd6\xe6\xe6\xe6\xf8\xf8\xf8\xff\xff\xff\xfd\xfd\xfd\xf0\xf0\xf0\xf7\xf7\xf7\xf6\xf6\xf6\xf6\xf6\xf6\xf7\xf7\xf7\xf7\xf7\xf7\xf8\xf8\xf8\xf8\xf8\xf8\xf7\xf7\xf7\xf8\xf8\xf8\xf8\xf8\xf8\xf7\xf8\xf8\xf7\xf7\xf7\xfd\xfc\xfc\xf1\xf1\xf1\xc1\xc0\xc0\xc8\xc7\xc7\xc4\xc3\xc3\xce\xcd\xcd\xc5\xc4\xc4\xc4\xc3\xc3\xc6\xc5\xc5\xc6\xc5\xc5\xbe\xbd\xbd\xc6\xc5\xc5\xf0\xf0\xef\xa5\xa3\xa4\xc5\xca\xc0\xb6\xbe\xae\xb4\xbb\xad\xe3\xec\xdd\xb1\xb9\xaa\xb1\xb8\xab\xe4\xec\xde\xb2\xb9\xab\xac\xb3\xa5\xe4\xec\xdd\xb4\xbc\xad\xaa\xb1\xa3\xe2\xeb\xdc\xb2\xb9\xab\xa8\xb0\xa1\xe8\xed\xe5\xdf\xe5\xda\xa7\xaf\xa0\xc0\xc7\xb9\xdc\xe4\xd5\xa3\xaa\x9c\xb6\xbd\xb0\xd8\xe0\xd3\xa3\xaa\x9d\xb1\xb8\xaa\xf0\xf2\xee\xf6\xf6\xf7\xf6\xf6\xf6\xff\xff\xff\xdd\xdd\xdd\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xd9\xd9\xda\xe3\xe4\xe5\xed\xed\xed\xf3\xf3\xf3\xf9\xf9\xf9\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf2\xf2\xf2\xdd\xdd\xdd\xc1\xc1\xc1\xc3\xc4\xc3\xf4\xf5\xf5\xf4\xf4\xf4\xd8\xd8\xd8\xbc\xbc\xbc\xdd\xdc\xdc\x9b\x9b\x9b\x00\x00\x00!!!/..???OOOaaarrr\x83\x83\x83\x93\x93\x93\xa4\xa4\xa4\xb5\xb5\xb5\xc6\xc6\xc6\xd8\xd8\xd8\xed\xed\xed\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xf1\xf1\xf1\xf8\xf8\xf8\xf7\xf7\xf7\xf7\xf7\xf7\xf8\xf8\xf8\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf8\xf8\xf9\xf9\xf9\xff\xff\xff\xef\xef\xef\xeb\xeb\xeb\xff\xff\xff\xdb\xdb\xda\xd2\xd2\xd1\xd1\xd0\xd0\xd2\xd2\xd1\xde\xdd\xdd\xd3\xd3\xd3\xd8\xd7\xd7\xd8\xd8\xd8\xda\xda\xda\xce\xcd\xcd\xd3\xd3\xd2\xd5\xd6\xd3\xd4\xd5\xd2\xd5\xd6\xd3\xcf\xd0\xcd\xd3\xd4\xd1\xd0\xd1\xce\xca\xcb\xc7\xd4\xd5\xd2\xda\xdb\xd8\xd3\xd4\xd1\xce\xd0\xcc\xd8\xd9\xd6\xd7\xd8\xd5\xd3\xd4\xd1\xd7\xd7\xd6\xd0\xd0\xce\xd5\xd6\xd3\xd8\xd9\xd6\xd6\xd7\xd5\xcb\xcc\xc8\xcb\xcc\xc9\xcc\xcd\xca\xc8\xc9\xc6\xda\xdc\xd9\xf5\xf6\xf5\xf4\xf4\xf4\xf6\xf6\xf6\xff\xff\xff\xdc\xdc\xdc\xbd\xbd\xbd\xcc\xcc\xcc\xd2\xd2\xd2\xdc\xdc\xdc\xcb\xcb\xcb\xbf\xbf\xbf\xc3\xc2\xc2\xc6\xc5\xc5\xd1\xd1\xd1\xce\xcd\xcd\xd6\xd6\xd5\xd8\xd8\xd8\xd5\xd4\xd4\xd8\xd7\xd7\xdc\xdc\xdc\xd5\xd5\xd5\xc7\xc6\xc6\xb3\xb2\xb2\xa1\xa0\xa0\x8a\x8a\x8a\x83\x83\x83\xc1\xc1\xc1\xe0\xe0\xe0\xd8\xd8\xd8\xec\xec\xecMMM\x04\x04\x04###...===HHHZYZhhhxxx\x86\x86\x86\x93\x93\x93\xa1\xa0\xa0\xaf\xaf\xaf\xc5\xc5\xc4\xf5\xf5\xf5\xf0\xf0\xf0\xef\xef\xef\xff\xff\xff\xf0\xf1\xf1\xf9\xf9\xf9\xf8\xf8\xf8\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xf8\xf8\xf8\xf9\xf9\xf9\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfd\xfe\xfd\xfd\xfe\xfc\xfc\xfd\xfd\xfd\xfd\xfe\xfd\xfe\xfb\xfa\xfb\xfe\xfd\xfe\xfd\xfd\xfe\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfd\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfd\xfe\xfd\xfe\xfd\xfc\xfd\xf8\xf8\xf8\xf6\xf5\xf6\xf3\xf3\xf3\xf1\xf1\xf1\xf1\xf1\xf1\xf2\xf2\xf2\xf4\xf4\xf4\xf6\xf5\xf6\xf7\xf7\xf7\xff\xff\xff\xdc\xdc\xdc\xbb\xbb\xbb\xca\xca\xca\xd1\xd0\xd1\xd8\xd8\xd8\xde\xde\xde\xe3\xe3\xe3\xe9\xe9\xe9\xec\xec\xec\xf1\xf1\xf1\xf5\xf5\xf5\xf8\xf8\xf8\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xf7\xf7\xf7\xe0\xe0\xe0\xc9\xc9\xc9\xb3\xb3\xb3\x9f\x9e\x9e\x83\x83\x83kkk\x90\x90\x90\xdc\xdc\xdc\xdc\xdc\xdc\x11\x11\x11\x0c\x0c\x0c$$$444GGGYYYkkk\x7d\x7d\x7d\x8e\x8e\x8e\xa0\xa0\xa1\xb3\xb3\xb3\xc5\xc5\xc5\xd7\xd7\xd7\xe8\xe8\xe8\xf8\xf8\xf8\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xf1\xf1\xf1\xf9\xf9\xf9\xf8\xf8\xf8\xf8\xf8\xf8\xf9\xf9\xf9\xf9\xf9\xf9\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfc\xfc\xfb\xfb\xfb\xfa\xfb\xfb\xfa\xfc\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfb\xfc\xfc\xfc\xfc\xfc\xfb\xfc\xfc\xfb\xfc\xfc\xfb\xfc\xfc\xfb\xfc\xfb\xfb\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfc\xfb\xfc\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfc\xfb\xfb\xfb\xfb\xf7\xf8\xf7\xf4\xf5\xf5\xf3\xf4\xf3\xf2\xf3\xf2\xf1\xf2\xf1\xf1\xf2\xf1\xf2\xf3\xf3\xf4\xf4\xf4\xf5\xf5\xf5\xfd\xfd\xfd\xdf\xdf\xdf\xc4\xc4\xc4\xd1\xd1\xd1\xd6\xd6\xd7\xdc\xdc\xdc\xe2\xe2\xe2\xe7\xe7\xe7\xec\xec\xec\xf0\xf0\xf0\xf3\xf3\xf3\xf6\xf6\xf6\xf8\xf8\xf8\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfc\xfb\xfc\xfc\xfc\xf2\xf2\xf2\xdf\xdf\xdf\xcd\xcd\xcd\xbb\xbb\xbb\xa8\xa8\xa8\x97\x97\x97\x85\x85\x85ddd\x94\x95\x94\xa9\xa9\xa9'''BBBNNN\x5c\x5c\x5ckkk\x79\x79\x79\x87\x87\x87\x95\x95\x95\xa4\xa4\xa4\xb2\xb2\xb2\xc0\xc0\xc0\xce\xcf\xcf\xdd\xdd\xdd\xeb\xeb\xeb\xf9\xf9\xf9\xfb\xfc\xfc\xfb\xfb\xfb\xfa\xfb\xfb\xf3\xf4\xf4\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xf0\xf0\xf0\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xed\xed\xed\xed\xed\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xee\xef\xef\xef\xee\xee\xee\xed\xed\xed\xee\xee\xee\xef\xef\xef\xed\xed\xed\xed\xed\xed\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xed\xee\xee\xee\xee\xee\xed\xee\xee\xed\xed\xed\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xef\xf0\xf0\xe7\xe7\xe7\xe8\xe8\xe8\xef\xef\xef\xee\xee\xee\xef\xef\xef\xee\xef\xee\xef\xee\xef\xee\xee\xee\xee\xee\xee\xed\xee\xed\xee\xed\xee\xed\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xee\xee\xee\xee\xee\xee\xed\xed\xed\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xef\xef\xef\xf0\xf0\xf0\xe8\xe8\xe8\xe8\xe8\xe8\xe7\xe7\xe7\xe8\xe8\xe8\xe8\xe8\xe8\xe7\xe7\xe7\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe7\xe7\xe7\xea\xe9\xea\xe8\xe8\xe8\xe5\xe5\xe5\xe8\xe8\xe8\xe9\xe9\xe9\xe4\xe5\xe4\xe6\xe6\xe6\xea\xe9\xea\xe6\xe6\xe6\xe4\xe4\xe4\xee\xee\xee\xed\xee\xee\xe6\xe6\xe6\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xea\xea\xea\xea\xea\xea\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe9\xe9\xe9\xe9\xe9\xe9\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe8\xe9\xe9\xe9\xe8\xe8\xe8\xe7\xe7\xe7\xe8\xe8\xe8\xe8\xe8\xe8\xe7\xe7\xe7\xe8\xe8\xe8\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf2\xf2\xf2\xe8\xe9\xe9\xc5\xce\xc9\xdc\xde\xdd\xed\xec\xed\xdd\xe3\xe0\xda\xdf\xdc\xf4\xf3\xf3\xea\xed\xeb\xd0\xda\xd4\xf2\xf1\xf2\xf2\xf3\xf2\xbb\xbb\xbb\xbb\xbb\xbb\xf6\xf6\xf6\xf1\xf1\xf1\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf3\xf3\xf3\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xf3\xf3\xf3\xf4\xf4\xf4\xf4\xf4\xf4\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xd8\xd8\xd8\xcb\xcc\xcc\xac\xaf\xad\xa8\xa9\xa9\xca\xca\xca\xc8\xc9\xc8\xa5\xa7\xa6\xc7\xc7\xc7\xce\xcf\xcf\xac\xae\xad\xba\xba\xba\xd0\xd1\xd1\x93\x93\x93\x93\x93\x93\xd6\xd6\xd6\xd8\xd8\xd8\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xd9\xd9\xd9\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda\xd9\xd9\xd9\xda\xda\xda\xda\xda\xda"""

rfxview_width=100
rfxview_height=95
rfxview_data="""\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xc5\xc5\xc5\xb1\xb1\xb1\xb7\xb7\xb7\xd4\xd4\xd4\xcd\xcd\xcd\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xca\xca\xca\xcf\xcf\xcf\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc"""+\
"""\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcd\xcd\xcd\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xc0\xc0\xc0\xaf\xaf\xaf\xcc\xcc\xcc\xd0\xd0\xd0\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xc8\xc8\xc8\xb7\xb7\xb7\xb0\xb0\xb0\xcb\xcb\xcb\xd0\xd0\xd0\xcb\xcb\xcb\xc3\xc3\xc3\xbd\xbd\xbd\xbd\xbd\xbd\xcf\xcf\xcf\xce\xce\xce\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xc9\xc9\xc9\xcf\xcf\xcf\xcc\xcc\xcc\x95\x95\x95\x8e\x8e\x8e\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcd\xcd\xcd\xc2\xc2\xc2\xce\xce\xce\xcb\xcb\xcb\xcc\xcc\xcc\xcb"""+\
"""\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xc6\xc6\xc6\xce\xce\xce\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xc4\xc4\xc4\xba\xba\xba\xa7\xa7\xa7\x8f\x8f\x8f\xc3\xc3\xc3\xce\xce\xce\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xca\xca\xca\xcc\xcc\xcc\xcd\xcd\xcd\xa4\xa4\xa4\x8e\x8e\x8e\xc2\xc2\xc2\xcb\xcb\xcb\xd3\xd3\xd3\xb1\xb1\xb1\x85\x85\x85\x99\x99\x99\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xc0\xc0\xc0\xda\xda\xda\x9e\x9e\x9e\x5c\x5c\x5cNNN\x98\x98\x98\xd3\xd3\xd3\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xca\xca\xca\xd2\xd2\xd2\xa9\xa9\xa9nnn\x8f\x8f\x8f\xd7\xd7\xd7\xbc\xbc\xbc\x9b"""+\
"""\x9b\x9b\xd8\xd8\xd8\x9b\x9b\x9bfff\xb7\xb7\xb7\xd1\xd1\xd1\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xc6\xc6\xc6\xc0\xc0\xc0TTT\x7d\x7d\x7dggg\x80\x80\x80\xd2\xd2\xd2\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcd\xcd\xcd\xc1\xc1\xc1\xd5\xd5\xd5\xcd\xcd\xcd\xa1\xa1\xa1ggg\x7f\x7f\x7f\xc3\xc3\xc3\xe3\xe3\xe3\x83\x83\x83WWWiii\x95\x95\x95\xd3\xd3\xd3\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xce\xce\xce\xa8\xa8\xa8hhhXXX\x84\x84\x84___sss\xd3\xd3\xd3\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcd\xcd\xcd\x9b\x9b\x9b\x93\x93\x93\xdd\xdd\xdd\xa2\xa2\xa2\xa0"""+\
"""\xa0\xa0\xda\xda\xda\x8d\x8d\x8dddd\xad\xad\xad\xd3\xd3\xd3\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcf\xcf\xcf\xb4\xb4\xb4\xa1\xa1\xa1kkk\x84\x84\x84www```\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xce\xce\xce\xb8\xb8\xb8\x8c\x8c\x8c:::LLLPPPaaa\xab\xab\xaboooWWWkkk\x5c\x5c\x5cttt\xd3\xd3\xd3\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xca\xca\xca\xd1\xd1\xd1\xa1\xa1\xa1tttrrr\x92\x92\x92WWW\x83\x83\x83\xd5\xd5\xd5\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xca\xca\xca\xd4\xd4\xd4\x9f\x9f\x9fIII\xb2\xb2\xb2\xd7\xd7\xd7\x8d\x8d\x8d\xbb"""+\
"""\xbb\xbb\xd3\xd3\xd3\x7d\x7d\x7dwww\xa2\xa2\xa2\xd4\xd4\xd4\xca\xca\xca\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xca\xca\xca\xd0\xd0\xd0\xb2\xb2\xb2rrr\x81\x81\x81\x79\x79\x79NNNooo\xd1\xd1\xd1\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc"""+\
"""\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcb\xcb\xcb\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xca\xca\xca\xd0\xd0\xd0\xb2\xb2\xb2xxx\x7c\x7c\x7clllKKKsss\xa5\xa5\xa5uuu\x7b\x7b\x7bnnnFFF\x89\x89\x89\xd4\xd4\xd4\xca\xca\xca\xcb\xcb\xcb\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc\xcc"""+\
"""\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcc\xcc\xcc\xc5\xc5\xc5\x7f\x7f\x7fWWWKKKlll\xc2\xc2\xc2\xcd\xcd\xcd\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcd\xcd\xcd\xbb\xbb\xbb\xa7\xa7\xa7\xb8\xb8\xb8\xcd\xcd\xcd\xc0\xc0\xc0\xca"""+\
"""\xca\xca\xcd\xcd\xcd\xbf\xbf\xbf\xa8\xa8\xa8\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcc\xcc\xcc\x8b\x8b\x8bVVVLLL^^^\xb5\xb5\xb5\xcf\xcf\xcf\xc9\xc9\xc9\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xcb\xcb\xcb\xcb\xcb"""+\
"""\xcb\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcc\xcc\xcc\x8e\x8e\x8e[[[PPP]]]\xb5\xb5\xb5\xc9\xc9\xc9\x7c\x7c\x7cWWWOOOlll\xc3\xc3\xc3\xcd\xcd\xcd\xcb\xcb\xcb\xcb\xcb\xcb\xca\xca\xca\xca\xca\xca\xcb\xcb\xcb"""+\
"""\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xcd\xcd\xcd\xd0\xd0\xd0\xca\xca\xca\xaa\xaa\xaa\xa8\xa8\xa8\xc9\xc9\xc9\xd0\xd0\xd0\xcd\xcd\xcd\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xd1\xd1\xd1\xd6\xd6\xd6\xd2\xd2\xd2\xcd\xcd\xcd\xd0\xd0\xd0\xce"""+\
"""\xce\xce\xcd\xcd\xcd\xd0\xd0\xd0\xd5\xd5\xd5\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xcf\xcf\xcf\xb0\xb0\xb0\xa5\xa5\xa5\xc3\xc3\xc3\xd1\xd1\xd1\xcd\xcd\xcd\xce\xce\xce\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xce\xce"""+\
"""\xce\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xcd\xcd\xcd\xcd\xcd\xcd\xce\xce\xce\xce\xce\xce\xce\xce\xce\xcd\xcd\xcd\xce\xce\xce\xcf\xcf\xcf\xb0\xb0\xb0\xa4\xa4\xa4\xc2\xc2\xc2\xd1\xd1\xd1\xcf\xcf\xcf\xcb\xcb\xcb\xa9\xa9\xa9\xa8\xa8\xa8\xca\xca\xca\xd0\xd0\xd0\xcc\xcc\xcc\xca\xca\xca\xca\xca\xca\xc9\xc9\xc9\xc9\xc9\xc9\xca\xca\xca"""+\
"""\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc8\xc8\xc8\xc8\xc8\xc8\xc3\xc3\xc3\xc1\xc1\xc1\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc0\xc0\xc0\xc1\xc1\xc1\xc3\xc3\xc3\xc2\xc2\xc2\xc2"""+\
"""\xc2\xc2\xc3\xc3\xc3\xc1\xc1\xc1\xc0\xc0\xc0\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc7\xc7\xc7\xc9\xc9\xc9\xc4\xc4\xc4\xc1\xc1\xc1\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3"""+\
"""\xc3\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc3\xc3\xc3\xc3\xc3\xc3\xc2\xc2\xc2\xc3\xc3\xc3\xc2\xc2\xc2\xc2\xc2\xc2\xc7\xc7\xc7\xc9\xc9\xc9\xc4\xc4\xc4\xc1\xc1\xc1\xc2\xc2\xc2\xc3\xc3\xc3\xc8\xc8\xc8\xc8\xc8\xc8\xc3\xc3\xc3\xc1\xc1\xc1\xc7\xc7\xc7\xcb\xcb\xcb\xcc\xcc\xcc\xd1\xd1\xd1\xd0\xd0\xd0\xcc\xcc\xcc"""+\
"""\xde\xde\xde\xdd\xdd\xdd\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdd\xdd\xdd\xdc\xdc\xdc\xde\xde\xde\xde\xde\xde\xdd\xdd\xdd\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdd\xdd\xdd\xde"""+\
"""\xde\xde\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdd\xdd\xdd\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdc\xdc\xdc\xdc\xdc\xdc\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdd\xdd\xdd\xdf\xdf\xdf\xde\xde\xde\xdf\xdf"""+\
"""\xdf\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xde\xde\xde\xdd\xdd\xdd\xdc\xdc\xdc\xde\xde\xde\xdf\xdf\xdf\xde\xde\xde\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xe1\xe1\xe1\xc5\xc5\xc5\xcd\xcd\xcd\xb9\xb9\xb9\x7b\x7b\x7b\x80\x80\x80\xb8\xb8\xb8"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd1\xd1\xd1\xcc\xcc\xcc\xaf\xaf\xaf\x5c\x5c\x5cfff\xb0\xb0\xb0"""+\
"""\xe8\xe8\xe8\xe4\xe4\xe4\xff\xff\xff\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xff\xff\xff\xec\xec\xec\xe1\xe1\xe1\xff\xff\xff\xf8\xf8\xf8\xe3\xe3\xe3\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xdc\xdc\xdc\xf6"""+\
"""\xf6\xf6\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xf8\xf8\xf8\xe0\xe0\xe0\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xe5\xe5\xe5\xd0\xd0\xd0\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xff\xff\xff\xef\xef\xef\xe5\xe5\xe5\xff\xff\xff\xfb\xfb\xfb\xfd\xfd"""+\
"""\xfd\xfd\xfd\xfd\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xe0\xe0\xe0\xf9\xf9\xf9\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xff\xff\xff\xd2\xd2\xd2\xcb\xcb\xcb\xb0\xb0\xb0dddmmm\xb1\xb1\xb1"""+\
"""\xba\xba\xba\x87\x87\x87\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xea\xea\xea\xda\xda\xda\xff\xff\xff\xea\xea\xeawww\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfa\xfa\xfa\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfa\xfa\xfa\xff\xff\xff\xfd\xfd\xfd\xf9\xf9\xf9\xfd\xfd\xfd\xff\xff\xff\x7d\x7d\x7d\xd5"""+\
"""\xd5\xd5\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xfd\xfd\xfd\xfa\xfa\xfa\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xfa\xfa\xfa\xfb\xfb\xfb\xf6\xf6\xf6vvv\xf3\xf3\xf3\xff\xff\xff\xd9\xd9\xd9\xf1\xf1\xf1\xff\xff\xff\xed\xed\xed\x94\x94\x94\xc8\xc8\xc8\xf9\xf9\xf9\xf9\xf9\xf9\xff\xff\xff\xfe\xfe\xfe\xf8\xf8\xf8\xe1\xe1\xe1\xc4\xc4\xc4\x8a\x8a\x8a\xff\xff\xff\xfb\xfb\xfb\xff\xff"""+\
"""\xff\xef\xef\xef\xda\xda\xda\xff\xff\xff\xf8\xf8\xf8\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xf9\xf9\xf9\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xe1\xe1\xe1\xeb\xeb\xeb\x81\x81\x81\xe0\xe0\xe0\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xbb\xbb\xbb\xce\xce\xce\xb0\xb0\xb0ccclll\xb2\xb2\xb2"""+\
"""\xd2\xd2\xd2\x82\x82\x82\x91\x91\x91\xc7\xc7\xc7\xd0\xd0\xd0\x83\x83\x83\xd3\xd3\xd3\xff\xff\xff\xca\xca\xca\xb5\xb5\xb5\xe3\xe3\xe3\xb6\xb6\xb6www\xe5\xe5\xe5\x9d\x9d\x9d\x9f\x9f\x9f\xd0\xd0\xd0\xa6\xa6\xa6\xcc\xcc\xcc\xff\xff\xff\xdb\xdb\xdb\x95\x95\x95\xad\xad\xad\xba\xba\xba\xcc\xcc\xcc\xc3\xc3\xc3\xaa\xaa\xaa\xc6\xc6\xc6\xc2\xc2\xc2\xd0\xd0\xd0\xf7\xf7\xf7\xff\xff\xff\x8f\x8f\x8f\x79"""+\
"""\x79\x79\x9a\x9a\x9a\xb7\xb7\xb7\x89\x89\x89\xb9\xb9\xb9\xbd\xbd\xbd\xaa\xaa\xaa\xbc\xbc\xbc\xb5\xb5\xb5\xa4\xa4\xa4\xcb\xcb\xcb\xbf\xbf\xbf\x8d\x8d\x8d\xbe\xbe\xbe\x88\x88\x88\x90\x90\x90\xb8\xb8\xb8\x7a\x7a\x7a\xce\xce\xce\xff\xff\xff\xcc\xcc\xccuuu\xf1\xf1\xf1\xb8\xb8\xb8\xa7\xa7\xa7\xca\xca\xca\x8d\x8d\x8d\x9f\x9f\x9fooo\xc3\xc3\xc3\x7e\x7e\x7e\x91\x91\x91\xd3\xd3\xd3\xff\xff"""+\
"""\xff\xb6\xb6\xb6\x86\x86\x86\xdb\xdb\xdb\xb4\xb4\xb4\xa4\xa4\xa4\xf9\xf9\xf9\xff\xff\xff\xa0\xa0\xa0\xc3\xc3\xc3\x9b\x9b\x9b\xcb\xcb\xcb\xc7\xc7\xc7\xe9\xe9\xe9\xbe\xbe\xbe\x83\x83\x83\xe2\xe2\xe2\xff\xff\xff\x89\x89\x89\xb2\xb2\xb2\x95\x95\x95\x8c\x8c\x8c\xa9\xa9\xa9\xe0\xe0\xe0\x8f\x8f\x8f\xae\xae\xae\xff\xff\xff\xde\xde\xdeooo\xd9\xd9\xd9\xae\xae\xaeccclll\xb2\xb2\xb2"""+\
"""\xc7\xc7\xc7\x9a\x9a\x9a\xcd\xcd\xcd\x7f\x7f\x7f\x9c\x9c\x9c\xcb\xcb\xcb\xd4\xd4\xd4\xff\xff\xff\xbf\xbf\xbf\x8b\x8b\x8b\x95\x95\x95\xe4\xe4\xe4\x8f\x8f\x8f\x8f\x8f\x8f\xbe\xbe\xbe\xc7\xc7\xc7\xcd\xcd\xcd\x95\x95\x95\xa6\xa6\xa6\xff\xff\xff\xfd\xfd\xfd\x87\x87\x87\x88\x88\x88www\xe0\xe0\xe0\xd5\xd5\xd5\x94\x94\x94\xa3\xa3\xa3\x9c\x9c\x9c\x86\x86\x86\xfd\xfd\xfd\xff\xff\xff\x87\x87\x87\xdf"""+\
"""\xdf\xdf\x97\x97\x97\x80\x80\x80\xcd\xcd\xcd\x8e\x8e\x8e\xda\xda\xda\xac\xac\xac\x80\x80\x80\xb7\xb7\xb7\x9b\x9b\x9b\xb3\xb3\xb3\x9d\x9d\x9d\xb2\xb2\xb2\xcf\xcf\xcf\x92\x92\x92\xd0\xd0\xd0\x96\x96\x96\x94\x94\x94\xe6\xe6\xe6\xff\xff\xff\xda\xda\xda\x9c\x9c\x9c\xb6\xb6\xb6\xa9\xa9\xa9\xd6\xd6\xd6\x7c\x7c\x7c\x90\x90\x90\xf8\xf8\xf8\x8b\x8b\x8b\xcf\xcf\xcf\xa0\xa0\xa0\xb9\xb9\xb9\xaf\xaf\xaf\xff\xff"""+\
"""\xff\xc0\xc0\xc0\xa6\xa6\xa6\x84\x84\x84\xee\xee\xee\x89\x89\x89\xca\xca\xca\xff\xff\xff\x8f\x8f\x8f\xc0\xc0\xc0\x88\x88\x88\xbd\xbd\xbdwww\xb1\xb1\xb1\x99\x99\x99\xca\xca\xca\xdd\xdd\xdd\xff\xff\xff\x99\x99\x99\xcf\xcf\xcf\x97\x97\x97\xd1\xd1\xd1\x85\x85\x85\x89\x89\x89\xc9\xc9\xc9\xc6\xc6\xc6\xff\xff\xff\xe9\xe9\xe9ttt\xd8\xd8\xd8\xae\xae\xaeccclll\xb2\xb2\xb2"""+\
"""\xb5\xb5\xb5\x92\x92\x92\xba\xba\xba\x8f\x8f\x8f\x7f\x7f\x7f\xb9\xb9\xb9\xe8\xe8\xe8\xff\xff\xff\xbb\xbb\xbb\x91\x91\x91\x96\x96\x96\x97\x97\x97\x80\x80\x80\x95\x95\x95\x8a\x8a\x8a\xe2\xe2\xe2\x80\x80\x80\x88\x88\x88\x94\x94\x94\xff\xff\xff\xff\xff\xff\xaf\xaf\xaf\x9a\x9a\x9a\x8d\x8d\x8d\xe9\xe9\xe9\x8d\x8d\x8d\x88\x88\x88\x89\x89\x89\xe0\xe0\xe0\x81\x81\x81\xde\xde\xde\xff\xff\xff\x91\x91\x91\xb9"""+\
"""\xb9\xb9\xc7\xc7\xc7\x95\x95\x95\xc0\xc0\xc0\xbb\xbb\xbb\xa4\xa4\xa4\xc0\xc0\xc0\xb6\xb6\xb6\x87\x87\x87\x7e\x7e\x7e\xc5\xc5\xc5\x9e\x9e\x9e\x98\x98\x98\xe2\xe2\xe2\x84\x84\x84\xc3\xc3\xc3\x92\x92\x92\x8b\x8b\x8b\xc4\xc4\xc4\xff\xff\xff\xd3\xd3\xd3\x83\x83\x83\xda\xda\xda\x8d\x8d\x8d\xc9\xc9\xc9\xb3\xb3\xb3\x80\x80\x80\xfa\xfa\xfa\x7e\x7e\x7e\xac\xac\xac\x9b\x9b\x9b\xab\xab\xab\xaa\xaa\xaa\xff\xff"""+\
"""\xff\xc9\xc9\xc9\x8a\x8a\x8a\xa0\xa0\xa0\xb4\xb4\xb4\xb0\xb0\xb0\xe7\xe7\xe7\xff\xff\xff\x99\x99\x99\x8f\x8f\x8f\x7a\x7a\x7a\xdf\xdf\xdf\xa1\xa1\xa1\x93\x93\x93\x7d\x7d\x7d\xc4\xc4\xc4\xec\xec\xec\xff\xff\xff\x9f\x9f\x9f\xa8\xa8\xa8\x8e\x8e\x8e\xc2\xc2\xc2\x8a\x8a\x8a\x86\x86\x86\x9f\x9f\x9f\xe0\xe0\xe0\xff\xff\xff\xed\xed\xed\x7d\x7d\x7d\xd6\xd6\xd6\xaf\xaf\xafccclll\xb2\xb2\xb2"""+\
"""\xed\xed\xed\xe9\xe9\xe9\xea\xea\xea\xef\xef\xef\xe7\xe7\xe7\xd2\xd2\xd2\xfd\xfd\xfd\xfe\xfe\xfe\xee\xee\xee\xea\xea\xea\xf6\xf6\xf6\xd2\xd2\xd2\xe7\xe7\xe7\xfb\xfb\xfb\xd0\xd0\xd0\xf0\xf0\xf0\xec\xec\xec\xe0\xe0\xe0\xe7\xe7\xe7\xff\xff\xff\xff\xff\xff\xf8\xf8\xf8\xf8\xf8\xf8\xf6\xf6\xf6\xfe\xfe\xfe\xeb\xeb\xeb\xe0\xe0\xe0\xe7\xe7\xe7\xe7\xe7\xe7\xf2\xf2\xf2\xff\xff\xff\xff\xff\xff\xf4\xf4\xf4\xdb"""+\
"""\xdb\xdb\xf6\xf6\xf6\xec\xec\xec\xe9\xe9\xe9\xff\xff\xff\xe1\xe1\xe1\xeb\xeb\xeb\xff\xff\xff\xda\xda\xda\xec\xec\xec\xd8\xd8\xd8\x89\x89\x89\xa7\xa7\xa7\xb6\xb6\xb6\xef\xef\xef\xea\xea\xea\xec\xec\xec\xea\xea\xea\xe7\xe7\xe7\xff\xff\xff\xf3\xf3\xf3\xe2\xe2\xe2\xfd\xfd\xfd\xe9\xe9\xe9\xe5\xe5\xe5\xf9\xf9\xf9\xe3\xe3\xe3\xfc\xfc\xfc\xe7\xe7\xe7\xe3\xe3\xe3\xeb\xeb\xeb\xe9\xe9\xe9\xef\xef\xef\xff\xff"""+\
"""\xff\xfb\xfb\xfb\xde\xde\xde\xf9\xf9\xf9\xe0\xe0\xe0\xf0\xf0\xf0\xff\xff\xff\xff\xff\xff\xf4\xf4\xf4\xd7\xd7\xd7\xf0\xf0\xf0\xec\xec\xec\xeb\xeb\xeb\xff\xff\xff\xdf\xdf\xdf\xd8\xd8\xd8\xff\xff\xff\xff\xff\xff\xf4\xf4\xf4\xdf\xdf\xdf\xe9\xe9\xe9\xec\xec\xec\xe9\xe9\xe9\xf3\xf3\xf3\xce\xce\xce\xf6\xf6\xf6\xff\xff\xff\xff\xff\xff\xca\xca\xca\xcd\xcd\xcd\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xde\xde\xde\xf6\xf6\xf6\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xf4\xf4\xf4\xb0\xb0\xb0\xd1\xd1\xd1\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff"""+\
"""\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xe4\xe4\xe4\xe1\xe1\xe1\xdb\xdb\xdb\xdd\xdd\xdd\xd0\xd0\xd0\xd9\xd9\xd9\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xf5\xf5\xf5\xbe\xbe\xbe\xde\xde\xde\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xf3\xf3\xf3\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xec\xec\xec\xdf"""+\
"""\xdf\xdf\xde\xde\xde\xdd\xdd\xdd\xd4\xd4\xd4\xd1\xd1\xd1\xf9\xf9\xf9\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xf8\xf8\xf8\xfa\xfa\xfa\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc"""+\
"""\xfc\xfe\xfe\xfe\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xd0\xd0\xd0\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\x95\x95\x95\x85\x85\x85\xea\xea\xea\xd3\xd3\xd3\xba\xba\xbattt\xea\xea\xea\xff\xff\xff\xff\xff\xff\x93\x93\x93\xb8\xb8\xb8\xb3\xb3\xb3\xd4\xd4\xd4\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xc8\xc8\xc8\xe8\xe8\xe8\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xf8\xf8\xf8\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xca\xca\xcab"""+\
"""bb\xe5\xe5\xe5\xd5\xd5\xd5\xcb\xcb\xcb\x79\x79\x79\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xb6\xb6\xb6\x98\x98\x98\xbe\xbe\xbe\xcc\xcc\xcc\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xc6\xc6\xc6\xc2\xc2\xc2\xff\xff"""+\
"""\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xa2\xa2\xa2\xf2\xf2\xf2\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf5\xf5\xf5\xa3\xa3\xa3\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfewww\xda\xda\xda\xff\xff\xff\xff\xff\xff\xf2\xf2\xf2\xee\xee\xee\xff\xff\xff\xff\xff\xff\x81\x81\x81\xf2\xf2\xf2\xea\xea\xea\x7d\x7d\x7d\xff\xff\xff\xfa\xfa\xfa\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xe3\xe3\xe3\xb8\xb8\xb8\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xf1\xf1\xf1\xce\xce\xce\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\x94"""+\
"""\x94\x94\xac\xac\xac\xff\xff\xff\xfd\xfd\xfd\xfa\xfa\xfa\xe8\xe8\xe8\xfd\xfd\xfd\xff\xff\xff\x96\x96\x96\xcd\xcd\xcd\xcf\xcf\xcf\x89\x89\x89\xff\xff\xff\xf9\xf9\xf9\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xee\xee\xee\xe7\xe7\xe7\xf6\xf6\xf6\xd1\xd1\xd1\xe4\xe4\xe4\xff\xff\xff\xff\xff\xff\xe8\xe8\xe8\x9f\x9f\x9f\xb6\xb6\xb6\x88\x88\x88\xda\xda"""+\
"""\xda\xf6\xf6\xf6\xda\xda\xda\xf1\xf1\xf1\xc3\xc3\xc3\xa9\xa9\xa9\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xdc\xdc\xdc\xd5\xd5\xd5\xf7\xf7\xf7\xd4\xd4\xd4\xc2\xc2\xc2\xfa\xfa\xfa\x84\x84\x84\xd2\xd2\xd2\xd9\xd9\xd9\xf3\xf3\xf3\xe2\xe2\xe2\xff\xff\xff\xff\xff\xff\xa6\xa6\xa6\xc4\xc4\xc4\x85\x85\x85\xbf\xbf\xbf\xeb\xeb\xeb\xfa\xfa\xfa\xc0\xc0\xc0\xcf\xcf\xcf\xb0\xb0\xb0ccclll\xb2\xb2\xb2"""+\
"""\xe6\xe6\xe6\xfb\xfb\xfb\xfd\xfd\xfd\xff\xff\xff\xdc\xdc\xdcttt\xf9\xf9\xf9\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xe8\xe8\xe8\x83\x83\x83\xff\xff\xff\xdb\xdb\xdbvvv\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf7\xf7\xf7\xa5\xa5\xa5\xff\xff\xff\xff\xff\xff\xe2\xe2\xe2\xc3\xc3\xc3\xa6\xa6\xa6\xd6\xd6\xd6\xf1\xf1\xf1\xff\xff\xff\xfd\xfd\xfd\xfc"""+\
"""\xfc\xfcuuu\xd8\xd8\xd8\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\x7d\x7d\x7d\xb6\xb6\xb6\x9a\x9a\x9a\xf6\xf6\xf6\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xec\xec\xec\x7b\x7b\x7b\xdd\xdd\xdd\x9a\x9a\x9a\xd4\xd4\xd4\x7d\x7d\x7d\xe9\xe9\xe9\xff\xff\xff\xe1\xe1\xe1\x86\x86\x86\xc2\xc2\xc2\x96\x96\x96\x8d\x8d"""+\
"""\x8d\xc0\xc0\xc0\xb9\xb9\xb9\x8f\x8f\x8f\xa1\xa1\xa1\xa1\xa1\xa1\xff\xff\xff\xff\xff\xff\xbf\xbf\xbf\xb5\xb5\xb5\xa9\xa9\xa9\x9a\x9a\x9a\x89\x89\x89\x8f\x8f\x8f\xb7\xb7\xb7\x9d\x9d\x9d\xcf\xcf\xcfxxx\xc6\xc6\xc6\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\x88\x88\x88\xc5\xc5\xc5\x8f\x8f\x8f\xa7\xa7\xa7\x8f\x8f\x8f\xac\xac\xac\xa8\xa8\xa8\xd2\xd2\xd2\xb0\xb0\xb0ccckkk\xb1\xb1\xb1"""+\
"""\xe4\xe4\xe4\xfc\xfc\xfc\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xa2\xa2\xa2\xec\xec\xec\xff\xff\xff\xfb\xfb\xfb\xfc\xfc\xfc\xff\xff\xff\xb8\xb8\xb8\x95\x95\x95\xff\xff\xff\x99\x99\x99\xc5\xc5\xc5\xf5\xf5\xf5\xc6\xc6\xc6\xe2\xe2\xe2\xda\xda\xda\xdf\xdf\xdf\xeb\xeb\xeb\xfc\xfc\xfc\xa4\xa4\xa4\xff\xff\xff\xff\xff\xff\xe1\xe1\xe1\xc3\xc3\xc3\xa7\xa7\xa7\xd5\xd5\xd5\xf1\xf1\xf1\xff\xff\xff\xfb\xfb\xfb\xff"""+\
"""\xff\xff\xb5\xb5\xb5\xcd\xcd\xcd\xff\xff\xff\xf9\xf9\xf9\xfd\xfd\xfd\xff\xff\xff\xe6\xe6\xe6vvv\xfb\xfb\xfbuuu\xf8\xf8\xf8\xe2\xe2\xe2\xc8\xc8\xc8\xe4\xe4\xe4\xd8\xd8\xd8\xe1\xe1\xe1\xed\xed\xed\xf1\xf1\xf1\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\x9c\x9c\x9c\x7d\x7d\x7dmmm\xf0\xf0\xf0\x8d\x8d\x8d\xda\xda\xda\xff\xff\xff\xe5\xe5\xe5\x90\x90\x90\xbc\xbc\xbc\xad\xad\xad\xad\xad"""+\
"""\xad\xa0\xa0\xa0\xa7\xa7\xa7\x8b\x8b\x8b\xa0\xa0\xa0\xaa\xaa\xaa\xff\xff\xff\xff\xff\xff\x9f\x9f\x9f\xaa\xaa\xaa\xd3\xd3\xd3\x89\x89\x89\x9e\x9e\x9e\xb1\xb1\xb1\xac\xac\xac\x8c\x8c\x8c\xf1\xf1\xf1\xa8\xa8\xa8\x79\x79\x79\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x92\x92\x92\xc8\xc8\xc8\x91\x91\x91\xd4\xd4\xd4\x80\x80\x80\x80\x80\x80\xbc\xbc\xbc\xd0\xd0\xd0\xb0\xb0\xb0ccclll\xb2\xb2\xb2"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xc7\xc7\xc7\xe4\xe4\xe4\xff\xff\xff\xff\xff\xff\xf4\xf4\xf4\xf0\xf0\xf0\xff\xff\xff\xaa\xaa\xaa\xb6\xb6\xb6\xcb\xcb\xcb\xd0\xd0\xd0\xff\xff\xff\xd2\xd2\xd2\x91\x91\x91\xeb\xeb\xeb\xb7\xb7\xb7\x9f\x9f\x9f\xd4\xd4\xd4\xf1\xf1\xf1\xaf\xaf\xaf\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xf1\xf1\xf1\xcc\xcc\xcc\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xd9"""+\
"""\xd9\xd9\xcf\xcf\xcf\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xea\xea\xea\xff\xff\xff\xc7\xc7\xc7\xa3\xa3\xa3\xfc\xfc\xfc\x9e\x9e\x9e\xde\xde\xde\xc1\xc1\xc1\x9c\x9c\x9c\xec\xec\xec\xae\xae\xae\xa3\xa3\xa3\xd9\xd9\xd9\x8f\x8f\x8f\xf5\xf5\xf5\xff\xff\xff\xef\xef\xef\xd1\xd1\xd1\xc8\xc8\xc8\xcd\xcd\xcd\xb2\xb2\xb2\xd2\xd2\xd2\xff\xff\xff\xff\xff\xff\xf8\xf8\xf8\x9f\x9f\x9f\xb3\xb3\xb3\xbd\xbd\xbd\xb8\xb8"""+\
"""\xb8\xaf\xaf\xaf\x9d\x9d\x9d\xa7\xa7\xa7\xb9\xb9\xb9\xa4\xa4\xa4\xff\xff\xff\xff\xff\xff\xf1\xf1\xf1\xad\xad\xad\xc8\xc8\xc8\xdf\xdf\xdf\xab\xab\xab\xc1\xc1\xc1\xba\xba\xba\xa8\xa8\xa8\xef\xef\xef\xdb\xdb\xdb\xa5\xa5\xa5\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xbd\xbd\xbd\xad\xad\xad\xad\xad\xad\xca\xca\xca\xb2\xb2\xb2\xb9\xb9\xb9\x90\x90\x90\xd7\xd7\xd7\xaf\xaf\xafccclll\xb2\xb2\xb2"""+\
"""\xfd\xfd\xfd\xfb\xfb\xfb\xff\xff\xff\xbf\xbf\xbf\x96\x96\x96\xd3\xd3\xd3\xc7\xc7\xc7\xc5\xc5\xc5\x79\x79\x79\xe3\xe3\xe3\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xca\xca\xca\xc1\xc1\xc1\xf6\xf6\xf6\xc4\xc4\xc4\x8a\x8a\x8a\xf4\xf4\xf4\xcd\xcd\xcd\xe3\xe3\xe3\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfa\xfa\xfa\xf5\xf5\xf5\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xe2\xe2\xe2\x89"""+\
"""\x89\x89\xce\xce\xce\xc7\xc7\xc7\xcf\xcf\xcf\x84\x84\x84\xbb\xbb\xbb\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xf7\xf7\xf7\xc1\xc1\xc1\xcb\xcb\xcb\xf6\xf6\xf6\xb2\xb2\xb2\x95\x95\x95\xfd\xfd\xfd\xe8\xe8\xe8\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfa\xfa\xfa\xfc\xfc\xfc\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xe1\xe1\xe1\x89\x89\x89\xf3\xf3\xf3\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1"""+\
"""\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xdb\xdb\xdb\xc9\xc9\xc9\xc8\xc8\xc8\xca\xca\xca\xc1\xc1\xc1\xc8\xc8\xc8\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xcd\xcd\xcd\xdf\xdf\xdf\xff\xff\xff\xf3\xf3\xf3\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xea\xea\xea\xc8"""+\
"""\xc8\xc8\xca\xca\xca\xc9\xc9\xc9\xc7\xc7\xc7\xbd\xbd\xbd\xf5\xf5\xf5\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfa\xfa\xfa\xca\xca\xca\xe9\xe9\xe9\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc"""+\
"""\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xf7\xf7\xf7\xed\xed\xed\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xfa\xfa\xfa\xec\xec\xec\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xe6\xe6\xe6\xf7\xf7\xf7\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xf2\xf2\xf2\xf0\xf0\xf0\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xe0\xe0\xe0\xf9\xf9\xf9\xfe\xfe\xfe\xfe\xfe\xfe\xff"""+\
"""\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xec\xec\xec\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xed\xed\xed\xf8\xf8\xf8\xff\xff\xff\xf2\xf2\xf2\xe3\xe3\xe3\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xe8\xe8\xe8\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe"""+\
"""\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xef\xef\xef\xe6\xe6\xe6\xff\xff\xff\xf8\xf8\xf8\xec\xec\xec\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf8\xf8\xf8\xea\xea\xea\xf1\xf1\xf1\xe5\xe5\xe5\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xeb\xeb\xeb\xf8\xf8\xf8\xd4\xd4\xd4\xca\xca\xca\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1"""+\
"""\xf1\xf1\xf1\x83\x83\x83\xf5\xf5\xf5\xfa\xfa\xfa\xfa\xfa\xfa\xfe\xfe\xfe\xf2\xf2\xf2\xdd\xdd\xdd\xff\xff\xff\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\x84\x84\x84\xce\xce\xce\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xff\xff\xff\xb1\xb1\xb1\xa1\xa1\xa1\xff\xff\xff\xf9\xf9\xf9\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xd0\xd0\xd0\xf5\xf5\xf5\xfe\xfe\xfe\xfc\xfc\xfc\xfb"""+\
"""\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\x7b\x7b\x7b\xec\xec\xec\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xf9\xf9\xf9\xff\xff\xff\x99\x99\x99\xb8\xb8\xb8\xff\xff\xff\xec\xec\xec\xd5\xd5\xd5\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\x7b\x7b\x7b\xe6\xe6\xe6\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa"""+\
"""\xfa\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xff\xff\xff\xe7\xe7\xe7\xd9\xd9\xd9\xff\xff\xff\xe3\xe3\xe3\x7d\x7d\x7d\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xf9\xf9\xf9\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xef\xef\xef\x7c\x7c\x7c\xe8\xe8\xe8\xd8\xd8\xd8\xff\xff\xff\xf5\xf5\xf5\xff\xff\xff\x9e\x9e\x9e\xb9\xb9\xb9\xdf\xdf\xdf\xca\xca\xca\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xca\xca\xca\x7a\x7a\x7a\xd1\xd1\xd1\xc9\xc9\xc9\xe6\xe6\xe6\xff\xff\xff\xbe\xbe\xbe\x84\x84\x84\xe6\xe6\xe6\xb6\xb6\xb6\xa9\xa9\xa9\xf4\xf4\xf4\xff\xff\xff\x96\x96\x96xxx\x99\x99\x99\xe6\xe6\xe6\xa1\xa1\xa1\xa6\xa6\xa6\xff\xff\xff\xf9\xf9\xf9\xd2\xd2\xd2\x92\x92\x92\xa0\xa0\xa0\xe3\xe3\xe3\x90\x90\x90\xbd\xbd\xbd\x93\x93\x93\xad\xad\xad\xb0\xb0\xb0\xbb\xbb\xbb\xa8\xa8\xa8\xdd\xdd\xdd\xc5"""+\
"""\xc5\xc5\xbb\xbb\xbb\x96\x96\x96\xdf\xdf\xdf\xc8\xc8\xc8ppp\xea\xea\xea\xff\xff\xff\xff\xff\xff\xe5\xe5\xe5\x99\x99\x99\xb5\xb5\xb5\xba\xba\xba\xd8\xd8\xd8\x9b\x9b\x9b\x87\x87\x87\xa3\xa3\xa3\xd4\xd4\xd4\xb5\xb5\xb5\xe4\xe4\xe4\xab\xab\xab\xc0\xc0\xc0\x8f\x8f\x8f\x91\x91\x91\xab\xab\xab\xff\xff\xff\xef\xef\xef\x97\x97\x97\x94\x94\x94\xb7\xb7\xb7\xa5\xa5\xa5\x9d\x9d\x9d\xc4\xc4\xc4\xb6\xb6"""+\
"""\xb6\xbc\xbc\xbc\xa7\xa7\xa7\xc6\xc6\xc6\xce\xce\xce\xbe\xbe\xbe\xc0\xc0\xc0\xe5\xe5\xe5\xb2\xb2\xb2\x7b\x7b\x7b\xe9\xe9\xe9\x9f\x9f\x9f\xaa\xaa\xaa\xce\xce\xce\xd2\xd2\xd2\xf4\xf4\xf4\xff\xff\xff\xcb\xcb\xcb\xcf\xcf\xcf\xeb\xeb\xeb\x8b\x8b\x8b\xce\xce\xce\xbb\xbb\xbb\xdd\xdd\xdd\xa5\xa5\xa5\xa5\xa5\xa5\xaf\xaf\xaf\x82\x82\x82\xa6\xa6\xa6\xd1\xd1\xd1\xae\xae\xaebbbkkk\xb1\xb1\xb1"""+\
"""\xfe\xfe\xfe\x91\x91\x91\xc5\xc5\xc5kkk\xd9\xd9\xd9\xff\xff\xff\xc5\xc5\xc5\xa6\xa6\xa6\x8d\x8d\x8d\xe2\xe2\xe2\x99\x99\x99\xba\xba\xba\xff\xff\xff\x8c\x8c\x8c\xd7\xd7\xd7\x95\x95\x95eee\xc4\xc4\xc4\xb8\xb8\xb8\xff\xff\xff\xcf\xcf\xcf\xa2\xa2\xa2\xd2\xd2\xd2\x89\x89\x89\x99\x99\x99\xc8\xc8\xc8\xb8\xb8\xb8\x80\x80\x80\xff\xff\xff\x79\x79\x79\xda\xda\xda\x80\x80\x80\xc7\xc7\xc7\xa2"""+\
"""\xa2\xa2\xa6\xa6\xa6\xc9\xc9\xc9\x7c\x7c\x7c\xe8\xe8\xe8\x8c\x8c\x8c\xe9\xe9\xe9\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\x88\x88\x88\x8b\x8b\x8buuu\xe7\xe7\xe7\xa4\xa4\xa4\xbf\xbf\xbf\x9d\x9d\x9d\xb7\xb7\xb7\x89\x89\x89\x98\x98\x98\xea\xea\xea\xf1\xf1\xf1\x89\x89\x89\xd4\xd4\xd4\x85\x85\x85\xff\xff\xff\xf3\xf3\xf3\x7e\x7e\x7e\xe6\xe6\xe6\x81\x81\x81\x84\x84\x84\xe2\xe2\xe2ttt\xfa\xfa"""+\
"""\xfa\x86\x86\x86\xb0\xb0\xb0\x83\x83\x83\xdb\xdb\xdb\xc6\xc6\xc6\x87\x87\x87\x9a\x9a\x9a\xe5\xe5\xe5\x8c\x8c\x8c\x90\x90\x90\xba\xba\xba\xc5\xc5\xc5\x97\x97\x97\x86\x86\x86\xf9\xf9\xf9\xff\xff\xff\xad\xad\xadvvv\xeb\xeb\xeb\x91\x91\x91\xc0\xc0\xc0\x97\x97\x97\xb3\xb3\xb3\xa8\xa8\xa8\xb9\xb9\xb9\xaf\xaf\xaf\xb4\xb4\xb4\xd2\xd2\xd2\xca\xca\xca\xb1\xb1\xb1ccclll\xb2\xb2\xb2"""+\
"""\xc9\xc9\xc9qqq\xd6\xd6\xd6\xa7\xa7\xa7\x94\x94\x94\xff\xff\xff\xcb\xcb\xcb\x89\x89\x89\xa4\xa4\xa4\xaf\xaf\xaf\xb2\xb2\xb2\xd8\xd8\xd8\xff\xff\xff\x94\x94\x94\xb7\xb7\xb7\xc3\xc3\xc3\x83\x83\x83\x98\x98\x98\xde\xde\xde\xff\xff\xff\xe0\xe0\xe0www\x9a\x9a\x9a\x8a\x8a\x8a\x7d\x7d\x7d\xbd\xbd\xbd\xd1\xd1\xd1\x79\x79\x79\xff\xff\xffnnn\xed\xed\xed\xa4\xa4\xa4\xad\xad\xad\xcb"""+\
"""\xcb\xcbsss\xe6\xe6\xe6\x89\x89\x89\x9d\x9d\x9d\x7a\x7a\x7a\xc0\xc0\xc0\xc0\xc0\xc0\xff\xff\xff\xff\xff\xff\xb4\xb4\xb4\x8f\x8f\x8f\x89\x89\x89\xe5\xe5\xe5\xa3\xa3\xa3\xb4\xb4\xb4\x92\x92\x92\xad\xad\xad\x8b\x8b\x8b\x94\x94\x94\x8b\x8b\x8b\xe8\xe8\xe8\x82\x82\x82\xc9\xc9\xc9\x7d\x7d\x7d\xff\xff\xff\xf6\xf6\xf6\x7f\x7f\x7f\xc9\xc9\xc9\xac\xac\xac\x81\x81\x81\xe9\xe9\xe9\x8f\x8f\x8f\xc3\xc3"""+\
"""\xc3\xa6\xa6\xa6\xf8\xf8\xf8www\xe4\xe4\xe4\xc5\xc5\xc5\x89\x89\x89\x8a\x8a\x8a\x9e\x9e\x9e\x7e\x7e\x7e\x8c\x8c\x8c\x97\x97\x97\xdc\xdc\xdc\xd9\xd9\xd9\x7e\x7e\x7e\xd1\xd1\xd1\xff\xff\xff\xdf\xdf\xdf\x8d\x8d\x8d\xae\xae\xae\x8d\x8d\x8d\xb8\xb8\xb8\x8b\x8b\x8b\xd8\xd8\xd8\x79\x79\x79\xdf\xdf\xdf\xa4\xa4\xa4\xab\xab\xab\xc8\xc8\xc8\xcb\xcb\xcb\xaf\xaf\xafbbbkkk\xb1\xb1\xb1"""+\
"""\xce\xce\xce\xde\xde\xde\xea\xea\xea\xe8\xe8\xe8\xf8\xf8\xf8\xff\xff\xff\xfa\xfa\xfa\xd7\xd7\xd7\xf7\xf7\xf7\xdb\xdb\xdb\xe9\xe9\xe9\xff\xff\xff\xff\xff\xff\xf1\xf1\xf1\xd7\xd7\xd7\xf2\xf2\xf2\xf9\xf9\xf9\xc3\xc3\xc3\xec\xec\xec\xff\xff\xff\xff\xff\xff\xde\xde\xde\xcd\xcd\xcd\xef\xef\xef\xe6\xe6\xe6\xc9\xc9\xc9\xf2\xf2\xf2\xdc\xdc\xdc\xf8\xf8\xf8\xdd\xdd\xdd\xf4\xf4\xf4\xf7\xf7\xf7\xf3\xf3\xf3\xff"""+\
"""\xff\xff\xcb\xcb\xcb\xde\xde\xde\xfb\xfb\xfb\xcb\xcb\xcb\xe0\xe0\xe0\xde\xde\xde\xb2\xb2\xb2\xff\xff\xff\xfd\xfd\xfd\xf7\xf7\xf7\xf3\xf3\xf3\xf3\xf3\xf3\xfc\xfc\xfc\xe7\xe7\xe7\xe6\xe6\xe6\xe2\xe2\xe2\xe6\xe6\xe6\xe3\xe3\xe3\xf3\xf3\xf3\xc4\xc4\xc4\xf1\xf1\xf1\xe2\xe2\xe2\xe8\xe8\xe8\xde\xde\xde\xfe\xfe\xfe\xf6\xf6\xf6ppp\xd9\xd9\xd9\xf7\xf7\xf7\xdd\xdd\xdd\xf3\xf3\xf3\xf9\xf9\xf9\xd7\xd7"""+\
"""\xd7\xf0\xf0\xf0\xff\xff\xff\xee\xee\xee\xfc\xfc\xfc\xec\xec\xec\xe4\xe4\xe4\xef\xef\xef\xca\xca\xca\xe3\xe3\xe3\xf5\xf5\xf5\xc4\xc4\xc4\xee\xee\xee\xe8\xe8\xe8\xed\xed\xed\xfc\xfc\xfc\xff\xff\xff\xe8\xe8\xe8\xec\xec\xec\xf4\xf4\xf4\xdf\xdf\xdf\xe7\xe7\xe7\xe8\xe8\xe8\x99\x99\x99\xa3\xa3\xa3\x9c\x9c\x9c\xdb\xdb\xdb\xeb\xeb\xeb\xc6\xc6\xc6\xcc\xcc\xcc\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1"""+\
"""\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd"""+\
"""\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf3\xf3\xf3\xa6\xa6\xa6\xf7\xf7\xf7\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xc3\xc3\xc3\xb2\xb2\xb2\xec\xec\xec\xff\xff\xff\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfa\xfa\xfa\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xff\xff\xff\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xd0\xd0\xd0\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xf5\xf5\xf5\xc0\xc0\xc0\xc4\xc4\xc4\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf2\xf2\xf2\xc8\xc8\xc8\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfa\xfa\xfa\xc5\xc5\xc5\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xc9\xc9\xc9\xef\xef\xef\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf5\xf5\xf5\xb0\xb0\xb0\xfa\xfa\xfa\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xd3\xd3\xd3\xe2\xe2\xe2\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\x80\x80\x80\x97\x97\x97\xf2\xf2\xf2\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xe8\xe8\xe8\xde\xde\xde\xed\xed\xed\xea\xea\xea\xe6\xe6\xe6\xf2\xf2\xf2\xec\xec\xec\xe9\xe9\xe9\xf9\xf9\xf9\xe2\xe2\xe2\xd6\xd6\xd6\xf1\xf1\xf1\xa4\xa4\xa4\xe9\xe9\xe9\xdd\xdd\xdd\xec\xec\xec\xe0\xe0\xe0\xe2\xe2\xe2\xf2\xf2\xf2\xe4\xe4\xe4\xfa\xfa\xfa\xa5\xa5\xa5\xe4\xe4\xe4\xda\xda\xda\xfc\xfc\xfc\xe3\xe3\xe3\xe5\xe5\xe5\xfa\xfa\xfa\xe0\xe0\xe0\xd5\xd5\xd5\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd8\xd8\xd8\xf4\xf4\xf4\xf6\xf6\xf6\xe9\xe9\xe9\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xc7\xc7\xc7\xbb\xbb\xbb\xf8\xf8\xf8\xe4\xe4\xe4\xf8\xf8\xf8\x7c\x7c\x7c\xe0\xe0\xe0\xe5\xe5\xe5\xf8\xf8\xf8\xe3\xe3\xe3\xf8\xf8\xf8\xe6\xe6\xe6\xd3\xd3\xd3\xf5\xf5\xf5\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xdf\xdf\xdf\xe8\xe8\xe8\xec\xec\xec\xd1\xd1\xd1\xf8\xf8\xf8\xad\xad\xad\xdb\xdb\xdb\xf5\xf5\xf5\xda\xda\xda\xfa\xfa\xfa\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf2\xf2\xf2\xe4\xe4\xe4\xfc\xfc\xfc\xf5\xf5\xf5\xd9\xd9\xd9\xf7\xf7\xf7\xef\xef\xef\xdb\xdb\xdb\xfc\xfc\xfc\xe6\xe6\xe6\xe3\xe3\xe3\xf4\xf4\xf4\xe8\xe8\xe8\xe7\xe7\xe7\xef\xef\xef\xe8\xe8\xe8\xd8\xd8\xd8\xc6\xc6\xc6\xcd\xcd\xcd\xaf\xaf\xafbbbkkk\xb1\xb1\xb1ddd\x9e\x9e\x9e\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xcc\xcc\xcc\xbd\xbd\xbd\x98\x98\x98\xa4\xa4\xa4\xa3\xa3\xa3\xa4\xa4\xa4\xa8\xa8\xa8\xca\xca\xca\x8c\x8c\x8c\xc0\xc0\xc0\x82\x82\x82\x8e\x8e\x8e\xaa\xaa\xaa\x83\x83\x83\xd8\xd8\xd8\x7f\x7f\x7f\xf4\xf4\xf4\x91\x91\x91\x95\x95\x95\xd9\xd9\xd9\x93\x93\x93\xb1\xb1\xb1\x82\x82\x82\xd8\xd8\xd8\x86\x86\x86\xba\xba\xba\xbc\xbc\xbc\x9c\x9c\x9c\xa7\xa7\xa7\x87\x87\x87\x87\x87\x87\xc7\xc7\xc7\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\x87\x87\x87\xbe\xbe\xbe\x96\x96\x96\xdf\xdf\xdf\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xa0\xa0\xa0\xa5\xa5\xa5\xd5\xd5\xd5\x8f\x8f\x8f\xbe\xbe\xbe\x87\x87\x87\xad\xad\xad\xe5\xe5\xe5\xaf\xaf\xaf\x7f\x7f\x7f\xad\xad\xad\x87\x87\x87\x8e\x8e\x8e\xa9\xa9\xa9\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\x99\x99\x99\xb7\xb7\xb7\x8b\x8b\x8b\x8e\x8e\x8e\xa6\xa6\xa6\x8c\x8c\x8c\xbc\xbc\xbc\xab\xab\xab\xb9\xb9\xb9\x98\x98\x98\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xc9\xc9\xc9\x97\x97\x97\xa9\xa9\xa9\xbe\xbe\xbe\xc0\xc0\xc0\xaa\xaa\xaa\xbe\xbe\xbe\xbc\xbc\xbc\xa6\xa6\xa6\xbc\xbc\xbc\xa4\xa4\xa4\x9c\x9c\x9c\xa2\xa2\xa2\xa3\xa3\xa3\xa9\xa9\xa9\x8b\x8b\x8b\x94\x94\x94uuu\xdb\xdb\xdb\xae\xae\xaeccclll\xb2\xb2\xb2mmm\xab\xab\xab\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\x9b\x9b\x9b\xc0\xc0\xc0\xaf\xaf\xaf\xa5\xa5\xa5\xa3\xa3\xa3\xa9\xa9\xa9\x9c\x9c\x9c\xbd\xbd\xbd\x80\x80\x80\xb6\xb6\xb6\x9c\x9c\x9c\xb3\xb3\xb3\x9e\x9e\x9e\x95\x95\x95\xe6\xe6\xe6\x7c\x7c\x7c\xf2\xf2\xf2nnn\xf4\xf4\xf4\xb8\xb8\xb8\x90\x90\x90\xa6\xa6\xa6\x93\x93\x93\xe5\xe5\xe5\x83\x83\x83\x84\x84\x84\xc8\xc8\xc8\xbe\xbe\xbe\x87\x87\x87\xa7\xa7\xa7\xa9\xa9\xa9\xb6\xb6\xb6\xff\xff\xff\xf9\xf9\xf9\xff\xff\xff\x82\x82\x82\xcf\xcf\xcf\x95\x95\x95\x85\x85\x85\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xaa\xaa\xaa\xb3\xb3\xb3\xc5\xc5\xc5\x89\x89\x89\xb3\xb3\xb3ssslll\xe9\xe9\xe9xxx\xeb\xeb\xeb\xdd\xdd\xdd\x90\x90\x90\xbe\xbe\xbe\x9c\x9c\x9c\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\x9b\x9b\x9b\xb6\xb6\xb6\x9b\x9b\x9b\xbe\xbe\xbe\x9d\x9d\x9d\xa0\xa0\xa0\xab\xab\xab\x89\x89\x89\xf4\xf4\xf4\x79\x79\x79\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xb7\xb7\xb7\x97\x97\x97\x87\x87\x87\x8a\x8a\x8a\xff\xff\xff\xb6\xb6\xb6\x92\x92\x92\xff\xff\xff\x8c\x8c\x8c\xbb\xbb\xbb\xce\xce\xce\x7b\x7b\x7b\xa5\xa5\xa5\xa4\xa4\xa4\xa9\xa9\xa9\x99\x99\x99\xc3\xc3\xc3hhh\xdc\xdc\xdc\xae\xae\xaeccclll\xb2\xb2\xb2\x85\x85\x85\xab\xab\xab\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xde\xde\xde\x88\x88\x88xxx\xc4\xc4\xc4\x98\x98\x98\x93\x93\x93\xb2\xb2\xb2\x90\x90\x90\x99\x99\x99\xa7\xa7\xa7\xa9\xa9\xa9\xb5\xb5\xb5\xb6\xb6\xb6\x9a\x9a\x9a\xc1\xc1\xc1\x9f\x9f\x9f\xa9\xa9\xa9\x9e\x9e\x9e\xd8\xd8\xd8\x8c\x8c\x8c\x97\x97\x97\xa7\xa7\xa7\x9c\x9c\x9c\xc0\xc0\xc0\x97\x97\x97\xd4\xd4\xd4\xa5\xa5\xa5\xc8\xc8\xc8\xce\xce\xce\xa5\xa5\xa5\xb1\xb1\xb1\xbf\xbf\xbf\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x98\x98\x98\xc1\xc1\xc1\xd8\xd8\xd8\xad\xad\xad\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xc8\xc8\xc8\x9c\x9c\x9c\x94\x94\x94\x98\x98\x98\x9d\x9d\x9d\xaa\xaa\xaa\xa3\xa3\xa3\xad\xad\xad\x9e\x9e\x9e\x98\x98\x98\xde\xde\xde\x9d\x9d\x9d\xbe\xbe\xbe\xa8\xa8\xa8\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xa9\xa9\xa9\xb6\xb6\xb6\xa4\xa4\xa4\xbd\xbd\xbd\xad\xad\xad\xaa\xaa\xaa\xb9\xb9\xb9\xaf\xaf\xaf\xb9\xb9\xb9\xd9\xd9\xd9\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x93\x93\x93\x96\x96\x96\xa9\xa9\xa9\x9e\x9e\x9e\x87\x87\x87\xe7\xe7\xe7\x81\x81\x81\xa3\xa3\xa3\xe1\xe1\xe1\xa3\xa3\xa3\xc2\xc2\xc2\xe4\xe4\xe4\x92\x92\x92\x92\x92\x92\xb9\xb9\xb9\xa3\xa3\xa3\xc2\xc2\xc2\x82\x82\x82\xd8\xd8\xd8\xae\xae\xaeccclll\xb2\xb2\xb2\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\x8a\x8a\x8a\xbe\xbe\xbe\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xf9\xf9\xf9\xfa\xfa\xfa\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfb\xfb\xfb\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xf8\xf8\xf8\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfa\xfa\xfa\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xf9\xf9\xf9\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xfb\xfb\xfb\xfa\xfa\xfa\xff\xff\xff\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xe2\xe2\xe2\xec\xec\xec\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xd0\xd0\xd0\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xf2\xf2\xf2\xf4\xf4\xf4\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xfb\xfb\xfb\xf5\xf5\xf5\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xf7\xf7\xf7\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xf5\xf5\xf5\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\x82\x82\x82\xa8\xa8\xa8\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf3\xf3\xf3\xe2\xe2\xe2\x83\x83\x83\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xe5\xe5\xe5\x88\x88\x88\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf3\xf3\xf3\x81\x81\x81\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfa\xfa\xfa\xc4\xc4\xc4\xcf\xcf\xcf\xb0\xb0\xb0ccclll\xb2\xb2\xb2\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x8b\x8b\x8b\xb5\xb5\xb5\xc5\xc5\xc5\x98\x98\x98\xb8\xb8\xb8\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xd7\xd7\xd7\xb5\xb5\xb5\xcc\xcc\xcc\xbb\xbb\xbb\xcd\xcd\xcd\xb1\xb1\xb1\xcf\xcf\xcf\x93\x93\x93\xd6\xd6\xd6\xff\xff\xff\xff\xff\xff\xcb\xcb\xcb\xa8\xa8\xa8\xab\xab\xab\xb2\xb2\xb2\xba\xba\xba\xf2\xf2\xf2\xa8\xa8\xa8\xc1\xc1\xc1\x7f\x7f\x7f\xc6\xc6\xc6\x80\x80\x80\x9e\x9e\x9e\xd4\xd4\xd4\xdb\xdb\xdb\xb0\xb0\xb0\xd1\xd1\xd1\xe9\xe9\xe9\xb3\xb3\xb3xxx\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xff\xff\xff\xe2\xe2\xe2\xa9\xa9\xa9\xbd\xbd\xbd\xca\xca\xca\xd0\xd0\xd0\xdd\xdd\xdd\xac\xac\xac\xbf\xbf\xbf\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\x7a\x7a\x7a\x9b\x9b\x9b\xce\xce\xce\xdc\xdc\xdc\xb1\xb1\xb1\xce\xce\xce\xab\xab\xab\xc6\xc6\xc6\xb3\xb3\xb3\xdc\xdc\xdc\xd4\xd4\xd4\xc9\xc9\xc9\xab\xab\xab\xa6\xa6\xa6\xd3\xd3\xd3\xce\xce\xce\xdc\xdc\xdc\xaf\xaf\xaf\xbe\xbe\xbe\xbd\xbd\xbd\x99\x99\x99\xec\xec\xec\xff\xff\xff\xfb\xfb\xfb\xb0\xb0\xb0\xcc\xcc\xcc\xb5\xb5\xb5\xe1\xe1\xe1\xd3\xd3\xd3\xee\xee\xee\xcb\xcb\xcb\x9f\x9f\x9f\xf5\xf5\xf5\xfe\xfe\xfe\xff\xff\xff\xa0\xa0\xa0\x80\x80\x80\xdc\xdc\xdc\xae\xae\xaeccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x8b\x8b\x8b\xbf\xbf\xbf\x9b\x9b\x9b\xb5\xb5\xb5\x8a\x8a\x8a\xff\xff\xff\xfe\xfe\xfe\xf9\xf9\xf9xxx\xf7\xf7\xf7\x7e\x7e\x7e\x82\x82\x82\xc2\xc2\xc2\x8d\x8d\x8d\xa7\xa7\xa7\x9e\x9e\x9e\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xaa\xaa\xaa\xa3\xa3\xa3\x9a\x9a\x9a\xbd\xbd\xbd\x8d\x8d\x8d\x94\x94\x94\xaf\xaf\xaf\xb7\xb7\xb7\x8f\x8f\x8f\xdb\xdb\xdb\x8e\x8e\x8e\xc7\xc7\xc7\x83\x83\x83\x8a\x8a\x8a\xf7\xf7\xf7iii\x8c\x8c\x8c\xe9\xe9\xe9\x84\x84\x84\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\x84\x84\x84\x8e\x8e\x8e\x80\x80\x80\xda\xda\xda\x8f\x8f\x8f\xb1\xb1\xb1\xb0\xb0\xb0\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\x86\x86\x86\xca\xca\xca\x7e\x7e\x7e\x88\x88\x88\xf4\xf4\xf4\x7d\x7d\x7d\x95\x95\x95\x96\x96\x96lll\xd0\xd0\xd0\xaa\xaa\xaa\x9f\x9f\x9f\xb5\xb5\xb5\xb0\xb0\xb0\x88\x88\x88\xd3\xd3\xd3\x90\x90\x90\xae\xae\xae\xba\xba\xba\x87\x87\x87\xc8\xc8\xc8\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\x88\x88\x88\xbf\xbf\xbf\x90\x90\x90\xab\xab\xab\x8e\x8e\x8e\xbb\xbb\xbb\x9c\x9c\x9c\xa9\xa9\xa9\xe6\xe6\xe6\xff\xff\xff\xff\xff\xff\xab\xab\xab\x8d\x8d\x8d\xdb\xdb\xdb\xae\xae\xaeccclll\xb2\xb2\xb2\xe0\xe0\xe0\xd4\xd4\xd4\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\x7d\x7d\x7d\xb4\xb4\xb4\x9b\x9b\x9b\xbd\xbd\xbd\x83\x83\x83\xff\xff\xff\xfd\xfd\xfd\xff\xff\xffvvv\xd5\xd5\xd5\xab\xab\xab\x8b\x8b\x8b\x9b\x9b\x9b\x82\x82\x82\xa3\xa3\xa3\xaa\xaa\xaa\xff\xff\xff\xf9\xf9\xf9\xff\xff\xff\xa9\xa9\xa9\xa6\xa6\xa6\x9a\x9a\x9a\xc1\xc1\xc1\x8f\x8f\x8f\x7e\x7e\x7e\xac\xac\xac\xf0\xf0\xf0\x7e\x7e\x7e\xc0\xc0\xc0\x8d\x8d\x8d\xc7\xc7\xc7\x87\x87\x87\x84\x84\x84\xdb\xdb\xdb\x9a\x9a\x9aooo\xb4\xb4\xb4\x7a\x7a\x7a\xd4\xd4\xd4\xdb\xdb\xdb\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xa6\xa6\xa6\x8a\x8a\x8a\x7d\x7d\x7d\xe1\xe1\xe1\x83\x83\x83\xb1\xb1\xb1\xe6\xe6\xe6\xfe\xfe\xfe\xff\xff\xff\xf8\xf8\xf8\x82\x82\x82\xcb\xcb\xcb\x82\x82\x82\x82\x82\x82\xda\xda\xda\x9f\x9f\x9f\xde\xde\xdesss\x95\x95\x95\xad\xad\xad\xc8\xc8\xc8\x7b\x7b\x7b\xe2\xe2\xe2\xf8\xf8\xf8lll\xdf\xdf\xdf\x8a\x8a\x8a\xa6\xa6\xa6\xf3\xf3\xf3\x81\x81\x81\xd8\xd8\xd8\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\x83\x83\x83\x9c\x9c\x9c\x7c\x7c\x7c\xea\xea\xea\x85\x85\x85\x84\x84\x84\x84\x84\x84\xdf\xdf\xdf\xf1\xf1\xf1\xfe\xfe\xfe\xff\xff\xff\xaa\xaa\xaa\x7e\x7e\x7e\xdc\xdc\xdc\xae\xae\xaeccclll\xb2\xb2\xb2\xe1\xe1\xe1\xd6\xd6\xd6\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xcc\xcc\xcc\xdb\xdb\xdb\xd6\xd6\xd6\xdf\xdf\xdf\xd1\xd1\xd1\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xeb\xeb\xeb\xca\xca\xca\xf2\xf2\xf2\xeb\xeb\xeb\xbc\xbc\xbc\xdb\xdb\xdb\xd8\xd8\xd8\xd8\xd8\xd8\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xdf\xdf\xdf\xda\xda\xda\xd5\xd5\xd5\xe0\xe0\xe0\xd5\xd5\xd5\xe6\xe6\xe6\xae\xae\xae\xee\xee\xee\xd9\xd9\xd9\xd0\xd0\xd0\xd5\xd5\xd5\xdc\xdc\xdc\xda\xda\xda\xea\xea\xea\xca\xca\xca\xf7\xf7\xf7\xe3\xe3\xe3\xb6\xb6\xb6\xdc\xdc\xdc\xbd\xbd\xbd\xbe\xbe\xbe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xf1\xf1\xf1\xec\xec\xec\xeb\xeb\xeb\xfb\xfb\xfb\xea\xea\xea\xae\xae\xae\xeb\xeb\xeb\xff\xff\xff\xff\xff\xff\xf8\xf8\xf8\xcf\xcf\xcf\xde\xde\xde\xd8\xd8\xd8\xea\xea\xea\xcb\xcb\xcb\xf2\xf2\xf2\xfe\xfe\xfe\xe5\xe5\xe5\xf1\xf1\xf1\xed\xed\xed\xff\xff\xff\xb9\xb9\xb9\xcc\xcc\xcc\xff\xff\xff\xe4\xe4\xe4\xf9\xf9\xf9\xef\xef\xef\xae\xae\xae\xe8\xe8\xe8\xd2\xd2\xd2\xe6\xe6\xe6\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xdb\xdb\xdb\xbf\xbf\xbf\xdf\xdf\xdf\xe3\xe3\xe3\xe1\xe1\xe1\xf8\xf8\xf8\xbf\xbf\xbf\xc8\xc8\xc8\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xed\xed\xed\xac\xac\xac\xd2\xd2\xd2\xb0\xb0\xb0ccclll\xb2\xb2\xb2\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xd2\xd2\xd2\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfa\xfa\xfa\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xd0\xd0\xd0\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xff\xff\xff\xd0\xd0\xd0\xd6\xd6\xd6\xff\xff\xff\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xe5\xe5\xe5\xb1\xb1\xb1\xee\xee\xee\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xc8\xc8\xc8\xfb\xfb\xfb\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xee\xee\xee\xc2\xc2\xc2\xe6\xe6\xe6\xd4\xd4\xd4\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xcb\xcb\xcb\xf2\xf2\xf2\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf6\xf6\xf6\xe8\xe8\xe8\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xff\xff\xff\xaf\xaf\xaf\xa5\xa5\xa5\xff\xff\xff\xfa\xfa\xfa\xfd\xfd\xfd\xfe\xfe\xfe\x84\x84\x84\xc8\xc8\xc8\xef\xef\xef\xe4\xe4\xe4\xfa\xfa\xfa\xf5\xf5\xf5\xde\xde\xde\xf8\xf8\xf8\xff\xff\xff\xff\xff\xff\xf1\xf1\xf1\xf2\xf2\xf2\xda\xda\xda\xf6\xf6\xf6\xec\xec\xec\xe5\xe5\xe5\xed\xed\xed\xe9\xe9\xe9\xfb\xfb\xfb\xe8\xe8\xe8\xe6\xe6\xe6\xf0\xf0\xf0\x7a\x7a\x7a\xeb\xeb\xeb\xe0\xe0\xe0\xff\xff\xff\xe1\xe1\xe1\xf7\xf7\xf7\xde\xde\xde\xe3\xe3\xe3\xb2\xb2\xb2\xed\xed\xed\xf0\xf0\xf0\xf6\xf6\xf6\xf1\xf1\xf1\xff\xff\xff\xbe\xbe\xbe\xe1\xe1\xe1\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xc6\xc6\xc6\xb4\xb4\xb4\xad\xad\xad\xff\xff\xff\xfa\xfa\xfa\xff\xff\xff\xf9\xf9\xf9qqq\xd8\xd8\xd8\xac\xac\xac\xb5\xb5\xb5\xa0\xa0\xa0\x87\x87\x87\x9a\x9a\x9a\xf2\xf2\xf2\xff\xff\xff\xba\xba\xba\xa7\xa7\xa7\xea\xea\xea\x87\x87\x87\xc8\xc8\xc8\x7f\x7f\x7f\x98\x98\x98\x9a\x9a\x9a\x92\x92\x92\xaa\xaa\xaa\x89\x89\x89\x85\x85\x85\xb8\xb8\xb8\x9c\x9c\x9c\xbb\xbb\xbb\x9a\x9a\x9a\xc8\xc8\xc8\xb4\xb4\xb4\xbf\xbf\xbf\x95\x95\x95\xb6\xb6\xb6\x85\x85\x85\xc5\xc5\xc5\x84\x84\x84\xca\xca\xca\xd3\xd3\xd3\xff\xff\xff\xca\xca\xca\x9f\x9f\x9f\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xec\xec\xec\xb1\xb1\xb1\xa9\xa9\xa9\xff\xff\xff\xfa\xfa\xfa\xfd\xfd\xfd\xff\xff\xff\x89\x89\x89\xc8\xc8\xc8\x82\x82\x82\xf8\xf8\xf8\x7d\x7d\x7d\x86\x86\x86\xe5\xe5\xe5\xff\xff\xff\xff\xff\xff\xdc\xdc\xdcggg\xc2\xc2\xc2\x81\x81\x81\xc9\xc9\xc9\x92\x92\x92\xb6\xb6\xb6\xb3\xb3\xb3\xa0\xa0\xa0\xa0\xa0\xa0\xb6\xb6\xb6\xc4\xc4\xc4\x94\x94\x94\x9c\x9c\x9c\xbf\xbf\xbf\x87\x87\x87\x8d\x8d\x8d\xf2\xf2\xf2\xff\xff\xff\x80\x80\x80\xba\xba\xba\x8f\x8f\x8f\xff\xff\xff\x7b\x7b\x7b\x9c\x9c\x9c\xff\xff\xff\xff\xff\xff\xd4\xd4\xd4\x92\x92\x92\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xf1\xf1\xf1\xb2\xb2\xb2\xb4\xb4\xb4\xa0\xa0\xa0\xdf\xdf\xdf\xff\xff\xff\xfa\xfa\xfa\x85\x85\x85\xe5\xe5\xe5\xa4\xa4\xa4\xba\xba\xba\xd3\xd3\xd3\x93\x93\x93\xdb\xdb\xdb\xff\xff\xff\xff\xff\xff\xdf\xdf\xdf\xbd\xbd\xbd\xb4\xb4\xb4\x95\x95\x95\xc5\xc5\xc5\x9d\x9d\x9d\xb4\xb4\xb4\xb4\xb4\xb4\xaa\xaa\xaa\xa4\xa4\xa4\x8d\x8d\x8d\xbf\xbf\xbf\xd3\xd3\xd3\x98\x98\x98\xbc\xbc\xbc\xa3\xa3\xa3\xac\xac\xac\x79\x79\x79\xe6\xe6\xe6\x93\x93\x93\xc8\xc8\xc8\x86\x86\x86\xfc\xfc\xfc\xb6\xb6\xb6\xb4\xb4\xb4\xd4\xd4\xd4\xdc\xdc\xdc\xc2\xc2\xc2\xb8\xb8\xb8\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xd7\xd7\xd7\xf2\xf2\xf2\xff\xff\xff\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xf4\xf4\xf4\xfe\xfe\xfe\xfb\xfb\xfb\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xf5\xf5\xf5\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xf9\xf9\xf9\xff\xff\xff\xb7\xb7\xb7\x89\x89\x89\xff\xff\xff\xfa\xfa\xfa\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xf6\xf6\xf6\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xff\xff\xff\xd3\xd3\xd3\x98\x98\x98\xf8\xf8\xf8\xfe\xfe\xfe\xf6\xf6\xf6\xc4\xc4\xc4\xf9\xf9\xf9\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xe9\xe9\xe9\xdc\xdc\xdc\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xe6\xe6\xe6\xda\xda\xda\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfb\xfb\xfb\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xf8\xf8\xf8\xf3\xf3\xf3\xf3\xf3\xf3\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfb\xfb\xfb\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfc\xfc\xfc\xff\xff\xff\xd7\xd7\xd7\xa0\xa0\xa0\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xa0\xa0\xa0\xd5\xd5\xd5\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\x9b\x9b\x9b\xa1\xa1\xa1\xb8\xb8\xb8\xbe\xbe\xbe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xb5\xb5\xb5\xbb\xbb\xbb\xff\xff\xff\xfb\xfb\xfb\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xbc\xbc\xbc\xc3\xc3\xc3\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xd9\xd9\xd9\xa2\xa2\xa2\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xa8\xa8\xa8\xc0\xc0\xc0\xe5\xe5\xe5\x88\x88\x88\xfc\xfc\xfc\xc6\xc6\xc6\xd9\xd9\xd9\xfe\xfe\xfe\xca\xca\xca\xdb\xdb\xdb\x9d\x9d\x9d\xb9\xb9\xb9\xd4\xd4\xd4\xfa\xfa\xfa\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x8a\x8a\x8a\xdd\xdd\xdd\xff\xff\xffxxx\xf8\xf8\xf8\xff\xff\xff\xfd\xfd\xfd\x84\x84\x84\xe3\xe3\xe3\xdd\xdd\xdd\xc5\xc5\xc5\xf7\xf7\xf7\xfe\xfe\xfe\xff\xff\xff\xba\xba\xba\x7a\x7a\x7a\xc0\xc0\xc0\xfa\xfa\xfa\xd6\xd6\xd6\xcc\xcc\xcc\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xce\xce\xce\xc1\xc1\xc1\xcf\xcf\xcf\xc1\xc1\xc1\xee\xee\xee\xd9\xd9\xd9\xd8\xd8\xd8\xeb\xeb\xeb\xc7\xc7\xc7\xb8\xb8\xb8\xe5\xe5\xe5\xcc\xcc\xcc\xb4\xb4\xb4\xe9\xe9\xe9\xef\xef\xef\xc2\xc2\xc2\xef\xef\xef\xf0\xf0\xf0\x8b\x8b\x8b\xab\xab\xab\xff\xff\xff\xff\xff\xff\xbc\xbc\xbc\x9f\x9f\x9f\xfb\xfb\xfb\xc7\xc7\xc7\xd7\xd7\xd7\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\x8c\x8c\x8c\xc3\xc3\xc3\x7f\x7f\x7f\xbf\xbf\xbf\xf0\xf0\xf0\xe9\xe9\xe9\xc3\xc3\xc3\xf5\xf5\xf5\xff\xff\xff\xff\xff\xff\xda\xda\xda\xb9\xb9\xb9\xd1\xd1\xd1\xd3\xd3\xd3\xeb\xeb\xeb\xd9\xd9\xd9\xb6\xb6\xb6\xd1\xd1\xd1\xfd\xfd\xfd\xcb\xcb\xcb\xc4\xc4\xc4\xf5\xf5\xf5\xd1\xd1\xd1\xd7\xd7\xd7\xd6\xd6\xd6\xcb\xcb\xcb\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xef\xef\xef\x7b\x7b\x7b\xae\xae\xae\xa0\xa0\xa0\x98\x98\x98\xd9\xd9\xd9\x8a\x8a\x8a\x8a\x8a\x8a\xd6\xd6\xd6\xd4\xd4\xd4\x9a\x9a\x9auuu\xf2\xf2\xf2\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xf7\xf7\xf7\x80\x80\x80\xff\xff\xff\xec\xec\xecppp\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\x86\x86\x86\xb7\xb7\xb7\xae\xae\xae\xbb\xbb\xbb\x94\x94\x94\xff\xff\xff\xff\xff\xff\xb8\xb8\xb8\x99\x99\x99\x91\x91\x91\x7a\x7a\x7a\xab\xab\xab\x84\x84\x84\xf2\xf2\xf2\xff\xff\xff\xff\xff\xffqqq\xb7\xb7\xb7\x8c\x8c\x8c\xa1\xa1\xa1\xa8\xa8\xa8\xcd\xcd\xcd\x84\x84\x84\xb0\xb0\xb0\x89\x89\x89\xb1\xb1\xb1vvv\x86\x86\x86\xb7\xb7\xb7nnn\xa7\xa7\xa7\x94\x94\x94\x94\x94\x94\xc7\xc7\xc7\xb0\xb0\xb0\xac\xac\xac\xff\xff\xff\xff\xff\xff\xb0\xb0\xb0\xab\xab\xab\x9e\x9e\x9e\xdb\xdb\xdb\x7c\x7c\x7c\xdf\xdf\xdf\xff\xff\xff\xfc\xfc\xfc\x80\x80\x80\xd1\xd1\xd1\x8f\x8f\x8f\xa8\xa8\xa8\x92\x92\x92\xaa\xaa\xaa\x88\x88\x88\xcb\xcb\xcb\xff\xff\xff\xff\xff\xff\x8c\x8c\x8c\xa7\xa7\xa7\xd2\xd2\xd2\x9c\x9c\x9c\xa2\xa2\xa2\x9a\x9a\x9a\x9c\x9c\x9c\x95\x95\x95\xb4\xb4\xb4\xa2\xa2\xa2\x8d\x8d\x8d\xab\xab\xab\x9d\x9d\x9d\x90\x90\x90\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xff\xff\xff\xb3\xb3\xb3\xac\xac\xac\x99\x99\x99\x7b\x7b\x7b\xdd\xdd\xdd\xab\xab\xab```\xb6\xb6\xb6\xff\xff\xff\x9c\x9c\x9cQQQ\xbf\xbf\xbf\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xcb\xcb\xcb\x86\x86\x86\xff\xff\xff\xa4\xa4\xa4\xbc\xbc\xbc\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\x8a\x8a\x8a\xa3\xa3\xa3\x95\x95\x95\xe0\xe0\xe0\x92\x92\x92\xff\xff\xff\xff\xff\xff\xb2\xb2\xb2\xae\xae\xae\xd6\xd6\xd6]]]\xa3\xa3\xa3\xed\xed\xed\xf2\xf2\xf2\xff\xff\xff\xff\xff\xff\x7a\x7a\x7a\xcf\xcf\xcf\x98\x98\x98\xbb\xbb\xbb\x90\x90\x90\xa4\xa4\xa4\x82\x82\x82\xa9\xa9\xa9\xa0\xa0\xa0\xde\xde\xde\x84\x84\x84\x97\x97\x97\xe7\xe7\xe7uuurrr\xf2\xf2\xf2\xa7\xa7\xa7\x95\x95\x95\xb4\xb4\xb4\x9f\x9f\x9f\xff\xff\xff\xff\xff\xff\xb6\xb6\xb6\xa9\xa9\xa9\x7c\x7c\x7c\xe1\xe1\xe1\x99\x99\x99\xd6\xd6\xd6\xff\xff\xff\xff\xff\xff\x82\x82\x82\xc6\xc6\xc6\x9a\x9a\x9a\xc6\xc6\xc6\x7c\x7c\x7c\x84\x84\x84\xe9\xe9\xe9\xe9\xe9\xe9\xfe\xfe\xfe\xff\xff\xff\x93\x93\x93\xd6\xd6\xd6\xb7\xb7\xb7\x8a\x8a\x8a\x97\x97\x97\x9e\x9e\x9e\xbc\xbc\xbc\x8f\x8f\x8f\xd4\xd4\xd4\x8b\x8b\x8b\xe6\xe6\xe6\x8e\x8e\x8e\xab\xab\xab\xf2\xf2\xf2\xca\xca\xca\xcd\xcd\xcd\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xc9\xc9\xc9\xd6\xd6\xd6\xe1\xe1\xe1\xb6\xb6\xb6\xe4\xe4\xe4\xb4\xb4\xb4\xdc\xdc\xdc\xea\xea\xea\x86\x86\x86\xd2\xd2\xd2\xc4\xc4\xc4\xca\xca\xca\xa6\xa6\xa6\xf5\xf5\xf5\xff\xff\xff\xff\xff\xff\xc0\xc0\xc0\xb5\xb5\xb5\xd0\xd0\xd0\xd2\xd2\xd2\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xaf\xaf\xaf\xd3\xd3\xd3\xc2\xc2\xc2\xc4\xc4\xc4\xf3\xf3\xf3\xff\xff\xff\xff\xff\xff\xe4\xe4\xe4\xb0\xb0\xb0\xd5\xd5\xd5\xef\xef\xef\x93\x93\x93\xc3\xc3\xc3\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xb1\xb1\xb1\xd2\xd2\xd2\xba\xba\xba\xcd\xcd\xcd\xba\xba\xba\xa9\xa9\xa9\xb5\xb5\xb5\xb1\xb1\xb1\x7f\x7f\x7f\xcc\xcc\xcc\xde\xde\xdewww\xc0\xc0\xc0\xec\xec\xec\xb6\xb6\xb6\x9f\x9f\x9f\xf0\xf0\xf0\xaa\xaa\xaa\x9e\x9e\x9e\xca\xca\xca\xff\xff\xff\xff\xff\xff\xe1\xe1\xe1\xad\xad\xad\xe0\xe0\xe0\xb6\xb6\xb6\xd8\xd8\xd8\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xb4\xb4\xb4\xbb\xbb\xbb\xbe\xbe\xbe\xc6\xc6\xc6\xca\xca\xca\xb0\xb0\xb0\xa6\xa6\xa6\xf7\xf7\xf7\xff\xff\xff\xff\xff\xff\xb7\xb7\xb7\xda\xda\xda\xc2\xc2\xc2\xa9\xa9\xa9\xb6\xb6\xb6\xb7\xb7\xb7\xcc\xcc\xcc\xbc\xbc\xbc\xba\xba\xba\x8c\x8c\x8c\x98\x98\x98\xd2\xd2\xd2\x92\x92\x92\xd3\xd3\xd3\xd5\xd5\xd5\xcb\xcb\xcb\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd9\xd9\xd9\x86\x86\x86\xff\xff\xff\xe8\xe8\xe8\x7f\x7f\x7f\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xac\xac\xac\x9f\x9f\x9f\xcc\xcc\xcc\xf7\xf7\xf7\xff\xff\xff\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xff\xff\xff\xfd\xfd\xfd\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfb\xfb\xfb\xff\xff\xff\xfd\xfd\xfd\xfb\xfb\xfb\xfe\xfe\xfe\xfb\xfb\xfb\xf5\xf5\xf5\xfb\xfb\xfb\xfb\xfb\xfb\xf6\xf6\xf6\xfa\xfa\xfa\xfe\xfe\xfe\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xfd\xfd\xfd\xff\xff\xff\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xf9\xf9\xf9\xfe\xfe\xfe\xfc\xfc\xfc\xfa\xfa\xfa\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfd\xfd\xfd\xff\xff\xff\xf4\xf4\xf4\xe5\xe5\xe5\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xec\xec\xec\xf2\xf2\xf2\xff\xff\xff\xfb\xfb\xfb\xdc\xdc\xdc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xe7\xe7\xe7\xf1\xf1\xf1\xe5\xe5\xe5\xf7\xf7\xf7\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xe0\xe0\xe0\xf1\xf1\xf1\xe4\xe4\xe4\xfc\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xe4\xe4\xe4\xf0\xf0\xf0\xff\xff\xff\xee\xee\xee\xe8\xe8\xe8\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xff\xff\xff\xee\xee\xee\xe5\xe5\xe5\xff\xff\xff\xf6\xf6\xf6\xe3\xe3\xe3\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xeb\xeb\xeb\xea\xea\xea\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf3\xf3\xf3\xcd\xcd\xcd\xbe\xbe\xbe\xda\xda\xda\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xf8\xf8\xf8\xff\xff\xff\xe0\xe0\xe0\x7d\x7d\x7d\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\x9c\x9c\x9c\xb3\xb3\xb3\xff\xff\xff\xf8\xf8\xf8\xd1\xd1\xd1\xff\xff\xff\xfc\xfc\xfc\xfa\xfa\xfa\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xf6\xf6\xf6\xff\xff\xff\x98\x98\x98\xbe\xbe\xbe\x8f\x8f\x8f\xd5\xd5\xd5\xff\xff\xff\xfd\xfd\xfd\xf9\xf9\xf9\xfd\xfd\xfd\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xf8\xf8\xf8\xff\xff\xff\xd5\xd5\xd5\xed\xed\xedxxx\xf5\xf5\xf5\xf8\xf8\xf8\xff\xff\xff\x98\x98\x98\xb2\xb2\xb2\xff\xff\xff\xc7\xc7\xc7\x88\x88\x88\xff\xff\xff\xf9\xf9\xf9\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xfa\xfa\xfa\xff\xff\xff\xfd\xfd\xfd\xf9\xf9\xf9\xff\xff\xff\xfb\xfb\xfb\xf8\xf8\xf8\xff\xff\xff\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xff\xff\xff\xc8\xc8\xc8\x86\x86\x86\xff\xff\xff\xf1\xf1\xf1uuu\xfb\xfb\xfb\xfb\xfb\xfb\xf9\xf9\xf9\xff\xff\xff\xf8\xf8\xf8\xff\xff\xff\xb8\xb8\xb8\x97\x97\x97\xff\xff\xff\xf8\xf8\xf8\xf9\xf9\xf9\xfa\xfa\xfa\xff\xff\xff\xf2\xf2\xf2\xc0\xc0\xc0vvv\xb4\xb4\xb4vvv\xb7\xb7\xb7\xff\xff\xff\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xc7\xc7\xc7\xac\xac\xac\xbf\xbf\xbf\x81\x81\x81\x92\x92\x92\xc8\xc8\xc8\xd3\xd3\xd3\x88\x88\x88\xca\xca\xca\xd7\xd7\xd7\x85\x85\x85\xb1\xb1\xb1\xff\xff\xff\xec\xec\xec\xa7\xa7\xa7\xc8\xc8\xc8\x90\x90\x90\x8f\x8f\x8f\xef\xef\xef\xff\xff\xff\xdb\xdb\xdb\xac\xac\xac\xc9\xc9\xc9\xae\xae\xae\xc1\xc1\xc1\x9e\x9e\x9e\xd2\xd2\xd2\xff\xff\xff\xe0\xe0\xe0\xaf\xaf\xaf\xbf\xbf\xbf\x9c\x9c\x9c\xca\xca\xca\xc9\xc9\xc9\xc3\xc3\xc3\xac\xac\xac\xce\xce\xce\xac\xac\xac\xe3\xe3\xe3\x8c\x8c\x8c\xd5\xd5\xd5\xb1\xb1\xb1\xc3\xc3\xc3\xb0\xb0\xb0qqq\x91\x91\x91\xc9\xc9\xc9\x96\x96\x96\xea\xea\xea\x96\x96\x96\xa9\xa9\xa9\xff\xff\xff\xed\xed\xed\x86\x86\x86\xa7\xa7\xa7\xbd\xbd\xbd\xad\xad\xad\xd2\xd2\xd2\x95\x95\x95\x8d\x8d\x8d\xd0\xd0\xd0\xc4\xc4\xc4\x93\x93\x93\xb5\xb5\xb5\xd8\xd8\xd8\x89\x89\x89\xc6\xc6\xc6\xff\xff\xff\xd9\xd9\xd9nnn\x81\x81\x81\xce\xce\xce\x8e\x8e\x8e\xdf\xdf\xdf\xba\xba\xba\xa7\xa7\xa7\xda\xda\xda\xc5\xc5\xc5\xac\xac\xac\xb3\xb3\xb3\x9a\x9a\x9a\xcf\xcf\xcf\xd4\xd4\xd4\xbe\xbe\xbe\xe1\xe1\xe1\xff\xff\xff\xf8\xf8\xf8\xf5\xf5\xf5\x86\x86\x86\xff\xff\xff\xcf\xcf\xcf\x90\x90\x90\xff\xff\xff\xec\xec\xec\xd0\xd0\xd0\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xf9\xf9\xf9\xf8\xf8\xf8\xd5\xd5\xd5\x94\x94\x94\xcb\xcb\xcb\x81\x81\x81\x93\x93\x93\xd7\xd7\xd7\x8f\x8f\x8f\xbe\xbe\xbe\xba\xba\xba\xaf\xaf\xaf\xff\xff\xff\xf0\xf0\xf0\x7b\x7b\x7b\xbc\xbc\xbc\xa7\xa7\xa7\x99\x99\x99\xd5\xd5\xd5\xff\xff\xff\xdc\xdc\xdc\xa6\xa6\xa6\x93\x93\x93\xb1\xb1\xb1\xc1\xc1\xc1\x9e\x9e\x9e\xd3\xd3\xd3\xff\xff\xff\xe1\xe1\xe1\xad\xad\xad\x88\x88\x88\xcc\xcc\xcc\x7c\x7c\x7c\xda\xda\xda\xd6\xd6\xd6\x93\x93\x93\xa9\xa9\xa9\x90\x90\x90\xd2\xd2\xd2\x91\x91\x91\xd7\xd7\xd7\xaf\xaf\xaf\x8d\x8d\x8d\xa5\xa5\xa5\xc4\xc4\xc4\xa8\xa8\xa8\x96\x96\x96\xa2\xa2\xa2\x93\x93\x93\xc3\xc3\xc3\xc2\xc2\xc2\xff\xff\xff\xf2\xf2\xf2\x7e\x7e\x7e\xfa\xfa\xfa\xc4\xc4\xc4\x83\x83\x83\xbb\xbb\xbb\x99\x99\x99\xb2\xb2\xb2\xa7\xa7\xa7\x9f\x9f\x9f\xb7\xb7\xb7\xb3\xb3\xb3\x92\x92\x92\xca\xca\xca\xcc\xcc\xcc\xff\xff\xff\xd1\xd1\xd1\x99\x99\x99\xd2\xd2\xd2\x8a\x8a\x8a\xa3\xa3\xa3\x8f\x8f\x8f\xc4\xc4\xc4\xcb\xcb\xcbTTT\xbf\xbf\xbf\xff\xff\xff\xc8\xc8\xc8===\xd3\xd3\xd3\xf7\xf7\xf7hhh\xbc\xbc\xbc\xff\xff\xff\xff\xff\xff\xdd\xdd\xdd\x9a\x9a\x9a\xff\xff\xff\xb3\xb3\xb3\xdc\xdc\xdc\xdd\xdd\xdd\x9d\x9d\x9d\xdc\xdc\xdc\xca\xca\xca\xb1\xb1\xb1ccclll\xb2\xb2\xb2hhh\xad\xad\xad\xd3\xd3\xd3\x8b\x8b\x8b\xb9\xb9\xb9\x8f\x8f\x8f\x7d\x7d\x7d\xc2\xc2\xc2\xbc\xbc\xbc\x80\x80\x80\x8b\x8b\x8b\xa3\xa3\xa3\xff\xff\xff\xec\xec\xec\x7a\x7a\x7a\xb2\xb2\xb2\xa4\xa4\xa4\x92\x92\x92\xcf\xcf\xcf\xff\xff\xff\xa0\xa0\xa0\x7f\x7f\x7f\x8c\x8c\x8c\x99\x99\x99\xb8\xb8\xb8\x91\x91\x91\xcb\xcb\xcb\xff\xff\xff\xac\xac\xac\x80\x80\x80\x79\x79\x79\xf6\xf6\xf6vvv\xec\xec\xec\x8e\x8e\x8e\x83\x83\x83\x98\x98\x98\x86\x86\x86\xc7\xc7\xc7\x8e\x8e\x8e\x9e\x9e\x9e\x80\x80\x80\x89\x89\x89\xa0\xa0\xa0\xa6\xa6\xa6\xc6\xc6\xc6\xb4\xb4\xb4\x95\x95\x95\x96\x96\x96\x96\x96\x96\xdf\xdf\xdf\xff\xff\xff\xed\xed\xed\x7a\x7a\x7a\xe9\xe9\xe9www\x84\x84\x84\x9f\x9f\x9f\x98\x98\x98\xa8\xa8\xa8\xae\xae\xae\xaa\xaa\xaa\x90\x90\x90\xe1\xe1\xe1vvv\xb2\xb2\xb2\xe6\xe6\xe6\xff\xff\xff\xda\xda\xda\x8a\x8a\x8a\xcb\xcb\xcb\xc1\xc1\xc1\x88\x88\x88\xb6\xb6\xb6\x99\x99\x99\xc8\xc8\xc8\xa6\xa6\xa6ooo\xc8\xc8\xc8\xbd\xbd\xbdxxx\x82\x82\x82\xd8\xd8\xd8\xbf\xbf\xbf\x84\x84\x84\xff\xff\xff\xff\xff\xff\xa7\xa7\xa7\x92\x92\x92\xcc\xcc\xcc\xd2\xd2\xd2\xff\xff\xff\xb8\xb8\xb8\xc6\xc6\xc6\xdf\xdf\xdf\xca\xca\xca\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xcf\xcf\xcf\xd5\xd5\xd5\xf7\xf7\xf7\xe5\xe5\xe5\xe8\xe8\xe8\xee\xee\xee\xe8\xe8\xe8\xcf\xcf\xcf\xff\xff\xff\xde\xde\xde\xd7\xd7\xd7\xf1\xf1\xf1\xff\xff\xff\xf7\xf7\xf7\xe4\xe4\xe4\xe9\xe9\xe9\xea\xea\xea\xe6\xe6\xe6\xf2\xf2\xf2\xff\xff\xff\xf1\xf1\xf1\xde\xde\xde\xe5\xe5\xe5\xe3\xe3\xe3\xec\xec\xec\xe5\xe5\xe5\xf1\xf1\xf1\xff\xff\xff\xf4\xf4\xf4\xde\xde\xde\xe2\xe2\xe2\xf7\xf7\xf7\xf5\xf5\xf5\xfe\xfe\xfe\xea\xea\xea\xdf\xdf\xdf\xe4\xe4\xe4\xe4\xe4\xe4\xed\xed\xed\xe5\xe5\xe5\xee\xee\xee\xde\xde\xde\xe4\xe4\xe4\xf0\xf0\xf0\xdd\xdd\xdd\xf1\xf1\xf1\xf2\xf2\xf2\xe6\xe6\xe6\xf7\xf7\xf7\xcb\xcb\xcb\xf2\xf2\xf2\xff\xff\xff\xf7\xf7\xf7\xe1\xe1\xe1\xfa\xfa\xfa\xe1\xe1\xe1\xe3\xe3\xe3\xe3\xe3\xe3\xe8\xe8\xe8\xee\xee\xee\xd7\xd7\xd7\x8a\x8a\x8a\xa7\xa7\xa7\xb3\xb3\xb3\xf2\xf2\xf2\xcc\xcc\xcc\xfb\xfb\xfb\xfe\xfe\xfe\xfe\xfe\xfe\xe2\xe2\xe2\xe6\xe6\xe6\xf9\xf9\xf9\xe1\xe1\xe1\xfa\xfa\xfa\xe4\xe4\xe4\xe5\xe5\xe5\xff\xff\xff\xda\xda\xda\xdd\xdd\xdd\xf1\xf1\xf1\xeb\xeb\xeb\xe6\xe6\xe6\xe3\xe3\xe3\xea\xea\xea\xf8\xf8\xf8\xfe\xfe\xfe\xff\xff\xff\xe5\xe5\xe5\xd9\xd9\xd9\xf3\xf3\xf3\xfe\xfe\xfe\xff\xff\xff\x94\x94\x94\xe4\xe4\xe4\xd8\xd8\xd8\xca\xca\xca\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf9\xf9\xf9\xb2\xb2\xb2\xc9\xc9\xc9\xfa\xfa\xfa\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xe8\xe8\xe8\xfe\xfe\xfe\xd3\xd3\xd3\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xf9\xf9\xf9\xfb\xfb\xfb\xfe\xfe\xfe\xfd\xfd\xfd\xfb\xfb\xfb\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfb\xfb\xfb\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfc\xfc\xfc\xff\xff\xff\xd4\xd4\xd4\xdd\xdd\xdd\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xc3\xc3\xc3\xf8\xf8\xf8\xff\xff\xff\xff\xff\xff\xe5\xe5\xe5\xce\xce\xce\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfb\xfb\xfb\xfc\xfc\xfc\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xaf\xaf\xaf\xe1\xe1\xe1\xe1\xe1\xe1\xe2\xe2\xe2\xdc\xdc\xdc\xc9\xc9\xc9\xd7\xd7\xd7\xca\xca\xca\xf1\xf1\xf1\xd5\xd5\xd5\xe6\xe6\xe6\xd8\xd8\xd8\xcc\xcc\xcc\xe0\xe0\xe0\xdc\xdc\xdc\xe3\xe3\xe3\xc0\xc0\xc0\xd7\xd7\xd7\xff\xff\xff\xd3\xd3\xd3\xcf\xcf\xcf\xeb\xeb\xeb\xd5\xd5\xd5\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\x98\x98\x98\x9a\x9a\x9a\xa3\xa3\xa3\xaf\xaf\xaf\x86\x86\x86\xab\xab\xab\x88\x88\x88\x9d\x9d\x9d\xb1\xb1\xb1\x80\x80\x80\xe2\xe2\xe2\xb7\xb7\xb7\x7c\x7c\x7c\xc7\xc7\xc7\x93\x93\x93\x9f\x9f\x9f\x95\x95\x95\x92\x92\x92\xb8\xb8\xb8\xa0\xa0\xa0\x80\x80\x80\xe5\xe5\xe5\xd4\xd4\xd4\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xc5\xc5\xc5\x99\x99\x99\xa6\xa6\xa6\xb1\xb1\xb1\x8f\x8f\x8f\xc7\xc7\xc7\x96\x96\x96\xb8\xb8\xb8\xaa\xaa\xaa\x82\x82\x82\xe1\xe1\xe1qqq\xe3\xe3\xe3\xc4\xc4\xc4\x96\x96\x96\xa5\xa5\xa5\xba\xba\xba\x90\x90\x90\xd2\xd2\xd2\x93\x93\x93\xd4\xd4\xd4\xfc\xfc\xfc\xf5\xf5\xf5\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xcd\xcd\xcd\xb5\xb5\xb5\xbd\xbd\xbd\xc1\xc1\xc1\xb3\xb3\xb3\xcd\xcd\xcd\xb3\xb3\xb3\xc7\xc7\xc7\xbc\xbc\xbc\xb1\xb1\xb1\xbf\xbf\xbf\xa3\xa3\xa3\xd7\xd7\xd7\xbe\xbe\xbe\xb7\xb7\xb7\xba\xba\xba\xc6\xc6\xc6\xb5\xb5\xb5\xc0\xc0\xc0\x8a\x8a\x8a\x98\x98\x98\xd5\xd5\xd5\xbf\xbf\xbf\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xac\xac\xac\x9e\x9e\x9e\xc7\xc7\xc7\xf3\xf3\xf3\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfc\xfc\xfc\xe6\xe6\xe6\xf7\xf7\xf7\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0bbbkkk\xb1\xb1\xb1\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcc\xcc\xcc\xb1\xb1\xb1ccclll\xb2\xb2\xb2\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb0\xb0\xb0ccclll\xb1\xb1\xb1\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xfb\xfb\xfb\xfd\xfd\xfd\xfc\xfc\xfc\xfc\xfc\xfc\xfd\xfd\xfd\xfc\xfc\xfc\xfa\xfa\xfa\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd1\xd1\xd1\xcb\xcb\xcb\xb2\xb2\xb2___hhh\xb2\xb2\xb2\xfb\xfb\xfb\xe8\xe8\xe8\xc9\xc9\xc9\xd7\xd7\xd7\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd2\xd2\xd2\xcb\xcb\xcb\xa1\xa1\xa1nnnwww\xa3\xa3\xa3\xff\xff\xff\x9f\x9f\x9f\x94\x94\x94\x82\x82\x82\xf9\xf9\xf9\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfb\xfb\xfb\xff\xff\xff\xb0\xb0\xb0\x89\x89\x89\xc3\xc3\xc3\xb4\xb4\xb4\xb9\xb9\xb9\xb2\xb2\xb2\x99\x99\x99ttt\xde\xde\xde\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xec\xec\xec\xd1\xd1\xd1\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xf1\xf1\xf1\xf0\xf0\xf0\xff\xff\xff\xff\xff\xff\xd2\xd2\xd2\xc7\xc7\xc7\x9c\x9c\x9c\x9f\x9f\x9f\xae\xae\xae\x9c\x9c\x9c\xff\xff\xff\xa7\xa7\xa7\xbc\xbc\xbc\x8c\x8c\x8c\xf3\xf3\xf3\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xd0\xd0\xd0\x1c\x1c\x1c\xd6\xd6\xd6\xfe\xfe\xfe\xf3\xf3\xf3\xf4\xf4\xf4\xec\xec\xec\xa8\xa8\xa8\xa9\xa9\xa9\xff\xff\xff\xf2\xf2\xf2\xf5\xf5\xf5\xff\xff\xff\xfc\xfc\xfc\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xda\xda\xda\xc4\xc4\xc4\xf6\xf6\xf6\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xf8\xf8\xf8\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfd\xfd\xfd\xf6\xf6\xf6\xef\xef\xef\xfa\xfa\xfa\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xf1\xf1\xf1\xf8\xf8\xf8\xf3\xf3\xf3\xc3\xc3\xc3\xa3\xa3\xa3\xef\xef\xef\xff\xff\xff\xd2\xd2\xd2\xc9\xc9\xc9\x9f\x9f\x9f\x9b\x9b\x9b\xaa\xaa\xaa\x9d\x9d\x9d\xe3\xe3\xe3\xb3\xb3\xb3\xc2\xc2\xc2\xa3\xa3\xa3\xf0\xf0\xf0\xff\xff\xff\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfa\xfa\xfa\xff\xff\xff\x9c\x9c\x9c777\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf1\xf1\xf1\xfd\xfd\xfd\xbc\xbc\xbc\xf1\xf1\xf1\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfc\xfc\xfc\xff\xff\xff\xd8\xd8\xd8\x7f\x7f\x7f\xd3\xd3\xd3\xa1\xa1\xa1\xf6\xf6\xf6\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfa\xfa\xfa\xf6\xf6\xf6\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xe5\xe5\xe5\x95\x95\x95\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfd\xfe\xfe\xfe\x7e\x7e\x7e\xc0\xc0\xc0\xa6\xa6\xa6\xe8\xe8\xe8\xff\xff\xff\xfd\xfd\xfd\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xe8\xe8\xe8\xc2\xc2\xc2\xff\xff\xff\xf3\xf3\xf3\xb3\xb3\xb3\xf4\xf4\xf4\xff\xff\xff\xd1\xd1\xd1\xc7\xc7\xc7\x9e\x9e\x9e\x9b\x9b\x9b\xaa\xaa\xaa\x9d\x9d\x9d\xfd\xfd\xfd\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xfb\xfb\xfb\xff\xff\xffeeejjj\xff\xff\xff\xfc\xfc\xfc\xfd\xfd\xfd\xfa\xfa\xfa\xff\xff\xff\xdd\xdd\xdd\xb0\xb0\xb0\xff\xff\xff\xe9\xe9\xe9\xd5\xd5\xd5\xef\xef\xef\xff\xff\xff\xfa\xfa\xfa\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfd\xfd\xfd\xfa\xfa\xfa\xfc\xfc\xfc\xfc\xfc\xfc\xff\xff\xff\xbe\xbe\xbe\x9b\x9b\x9b\xff\xff\xff\x96\x96\x96\xbb\xbb\xbb\xff\xff\xff\xfc\xfc\xfc\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xeb\xeb\xeb\xcc\xcc\xcc\xff\xff\xff\xfb\xfb\xfb\xff\xff\xff\xd3\xd3\xd3\xab\xab\xab\xff\xff\xff\xf8\xf8\xf8\xfc\xfc\xfc\xff\xff\xff\xfe\xfe\xfe\xff\xff\xff\xfc\xfc\xfc\xfa\xfa\xfa\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xff\xff\xff\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xfe\xff\xff\xff\xf2\xf2\xf2\x7d\x7d\x7d\xff\xff\xff\x89\x89\x89\xd9\xd9\xd9\xff\xff\xff\xfd\xfd\xfd\xff\xff\xff\xfe\xfe\xfe\xfd\xfd\xfd\xff\xff\xff\xb1\xb1\xb1\xef\xef\xef\xa3\xa3\xa3\xa1\xa1\xa1\xfc\xfc\xfc\xff\xff\xff\xd2\xd2\xd2\xc8\xc8\xc8\x9f\x9f\x9f\x9c\x9c\x9c\xab\xab\xab\x9d\x9d\x9d"""

app = MyApp()
app.MainLoop()

